@@ -3,160 +3,57 @@
 /**
  * Rfc822Header.class.php
  *
- * This file contains functions needed to handle headers in mime messages.
+ * Copyright (c) 2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * @copyright 2003-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: Rfc822Header.class.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * This contains functions needed to handle mime messages.
+ *
+ * $Id: Rfc822Header.class.php,v 1.36 2004/01/11 02:55:17 indiri69 Exp $
  * @package squirrelmail
- * @subpackage mime
- * @since 1.3.2
  */
 
 /**
- * MIME header class
  * input: header_string or array
- * You must call parseHeader() function after creating object in order to fill object's
- * parameters.
- * @todo FIXME: there is no constructor function and class should ignore all input args.
  * @package squirrelmail
- * @subpackage mime
- * @since 1.3.0
  */
 class Rfc822Header {
-    /**
-     * All headers, unparsed
-     * @var array
-     */
-    var $raw_headers = array();
-    /**
-     * Date header
-     * @var mixed
-     */
-    var $date = -1;
-    /**
-     * Original date header as fallback for unparsable dates
-     * @var mixed
-     */
-    var $date_unparsed = '';
-    /**
-     * Subject header
-     * @var string
-     */
-    var $subject = '';
-    /**
-     * From header
-     * @var array
-     */
-    var $from = array();
-    /**
-     * @var mixed
-     */
-    var $sender = '';
-    /**
-     * Reply-To header
-     * @var array
-     */
-    var $reply_to = array();
-    /**
-     * Mail-Followup-To header
-     * @var array
-     */
-    var $mail_followup_to = array();
-    /**
-     * To header
-     * @var array
-     */
-    var $to = array();
-    /**
-     * Cc header
-     * @var array
-     */
-    var $cc = array();
-    /**
-     * Bcc header
-     * @var array
-     */
-    var $bcc = array();
-    /**
-     * In-reply-to header
-     * @var string
-     */
-    var $in_reply_to = '';
-    /**
-     * Message-ID header
-     * @var string
-     */
-    var $message_id = '';
-    /**
-     * References header
-     * @var string
-     */
-    var $references = '';
-    /**
-     * @var mixed
-     */
-    var $mime = false;
-    /**
-     * @var mixed
-     */
-    var $content_type = '';
-    /**
-     * @var mixed
-     */
-    var $disposition = '';
-    /**
-     * X-Mailer header
-     * @var string
-     */
-    var $xmailer = '';
-    /**
-     * Priority header
-     * @var integer
-     */
-    var $priority = 3;
-    /**
-     * @var mixed
-     */
-    var $dnt = '';
-    /**
-     * @var mixed
-     */
-    var $encoding = '';
-    /**
-     * @var mixed
-     */
-    var $mlist = array();
-    /**
-     * SpamAssassin 'x-spam-status' header
-     * @var mixed
-     */
-    var $x_spam_status = array();
-    /**
-     * Extra header
-     * only needed for constructing headers in delivery class
-     * @var array
-     */
-    var $more_headers = array();
-
-    /**
-     * @param mixed $hdr string or array with message headers
-     */
+    var $date = '',
+        $subject = '',
+        $from = array(),
+        $sender = '',
+        $reply_to = array(),
+        $mail_followup_to = array(),
+        $to = array(),
+        $cc = array(),
+        $bcc = array(),
+        $in_reply_to = '',
+        $message_id = '',
+        $references = '',
+        $mime = false,
+        $content_type = '',
+        $disposition = '',
+        $xmailer = '',
+        $priority = 3,
+        $dnt = '',
+        $encoding = '',
+        $content_id = '',
+        $content_desc = '',
+        $mlist = array(),
+        $more_headers = array(); /* only needed for constructing headers
+                                    in smtp.php */
     function parseHeader($hdr) {
         if (is_array($hdr)) {
             $hdr = implode('', $hdr);
         }
-        /* First we replace \r\n by \n and unfold the header */
-        /* FIXME: unfolding header with multiple spaces "\n( +)" */
-        $hdr = trim(str_replace(array("\r\n", "\n\t", "\n "),array("\n", ' ', ' '), $hdr));
+        /* First we unfold the header */
+        $hdr = trim(str_replace(array("\r\n\t", "\r\n "),array(' ', ' '), $hdr));
 
         /* Now we can make a new header array with */
         /* each element representing a headerline  */
-        $hdr = explode("\n" , $hdr);
+        $hdr = explode("\r\n" , $hdr);
         foreach ($hdr as $line) {
             $pos = strpos($line, ':');
             if ($pos > 0) {
-                $this->raw_headers[] = $line;
                 $field = substr($line, 0, $pos);
                 if (!strstr($field,' ')) { /* valid field */
                         $value = trim(substr($line, $pos+1));
@@ -164,15 +61,11 @@ class Rfc822Header {
                 }
             }
         }
-        if (!is_object($this->content_type)) {
+        if ($this->content_type == '') {
             $this->parseContentType('text/plain; charset=us-ascii');
         }
     }
 
-    /**
-     * @param string $value
-     * @return string
-     */
     function stripComments($value) {
         $result = '';
         $cnt = strlen($value);
@@ -215,11 +108,6 @@ class Rfc822Header {
         return $result;
     }
 
-    /**
-     * Parse header field according to field type
-     * @param string $field field name
-     * @param string $value field value
-     */
     function parseField($field, $value) {
         $field = strtolower($field);
         switch($field) {
@@ -228,7 +116,6 @@ class Rfc822Header {
                 $d = strtr($value, array('  ' => ' '));
                 $d = explode(' ', $d);
                 $this->date = getTimeStamp($d);
-                $this->date_unparsed = strtr($value,'<>','  ');
                 break;
             case 'subject':
                 $this->subject = $value;
@@ -284,14 +171,22 @@ class Rfc822Header {
                 $value = $this->stripComments($value);
                 $this->parseDisposition($value);
                 break;
+            case 'content-transfer-encoding':
+                $this->encoding = $value;
+                break;
+            case 'content-description':
+                $this->content_desc = $value;
+                break;
+            case 'content-id':
+                $value = $this->stripComments($value);
+                $this->content_id = $value;
+                break;
             case 'user-agent':
             case 'x-mailer':
                 $this->xmailer = $value;
                 break;
             case 'x-priority':
-            case 'importance':
-            case 'priority':
-                $this->priority = $this->parsePriority($value);
+                $this->priority = $value;
                 break;
             case 'list-post':
                 $value = $this->stripComments($value);
@@ -325,24 +220,14 @@ class Rfc822Header {
                 $value = $this->stripComments($value);
                 $this->mlist('id', $value);
                 break;
-            case 'x-spam-status':
-            case 'x-spam-score':
-                $this->x_spam_status = $this->parseSpamStatus($value);
-                break;
-            case 'x-sm-flag-reply':
-                $this->x_sm_flag_reply = $value;
-                break;
             default:
                 break;
         }
     }
 
-    /**
-     * @param string $address
-     * @return array
-     */
     function getAddressTokens($address) {
         $aTokens = array();
+        $aAddress = array();
         $aSpecials = array('(' ,'<' ,',' ,';' ,':');
         $aReplace =  array(' (',' <',' ,',' ;',' :');
         $address = str_replace($aSpecials,$aReplace,$address);
@@ -465,14 +350,6 @@ class Rfc822Header {
         }
         return $aTokens;
     }
-
-    /**
-     * @param array $aStack
-     * @param array $aComment
-     * @param string $sEmail
-     * @param string $sGroup
-     * @return object AddressStructure object
-     */
     function createAddressObject(&$aStack,&$aComment,&$sEmail,$sGroup='') {
         //$aStack=explode(' ',implode('',$aStack));
         if (!$sEmail) {
@@ -489,7 +366,7 @@ class Rfc822Header {
             $sComment = trim(implode(' ',$aComment));
             $sPersonal .= $sComment;
         }
-        $oAddr = new AddressStructure();
+        $oAddr =& new AddressStructure();
         if ($sPersonal && substr($sPersonal,0,2) == '=?') {
             $oAddr->personal = encodeHeader($sPersonal);
         } else {
@@ -509,8 +386,21 @@ class Rfc822Header {
         return $oAddr;
     }
 
-    /**
-     * recursive function for parsing address strings and storing them in an address stucture object.
+    /*
+     * parseAddress: recursive function for parsing address strings and store
+     *               them in an address stucture object.
+     *               input: $address = string
+     *                      $ar      = boolean (return array instead of only the
+     *                                 first element)
+     *                      $addr_ar = array with parsed addresses // obsolete
+     *                      $group   = string // obsolete
+     *                      $host    = string (default domainname in case of
+     *                                 addresses without a domainname)
+     *                      $lookup  = callback function (for lookup address
+     *                                 strings which are probably nicks
+     *                                 (without @ ) )
+     *               output: array with addressstructure objects or only one
+     *                       address_structure object.
      *  personal name: encoded: =?charset?Q|B?string?=
      *                 quoted:  "string"
      *                 normal:  string
@@ -518,14 +408,8 @@ class Rfc822Header {
      *               : mailbox@host
      *  This function is also used for validating addresses returned from compose
      *  That's also the reason that the function became a little bit huge
-     * @param string $address
-     * @param boolean $ar return array instead of only the first element
-     * @param array $addr_ar (obsolete) array with parsed addresses
-     * @param string $group (obsolete)
-     * @param string $host default domainname in case of addresses without a domainname
-     * @param string $lookup (since) callback function for lookup of address strings which are probably nicks (without @)
-     * @return mixed array with AddressStructure objects or only one address_structure object.
      */
+
     function parseAddress($address,$ar=false,$aAddress=array(),$sGroup='',$sHost='',$lookup=false) {
         $aTokens = $this->getAddressTokens($address);
         $sPersonal = $sEmail = $sComment = $sGroup = '';
@@ -546,7 +430,7 @@ class Rfc822Header {
                 if ($sGroup) {
                     $aAddress[] = $this->createAddressObject($aStack,$aComment,$sEmail,$sGroup);
                     $oAddr = end($aAddress);
-                    if(!$oAddr || ((isset($oAddr)) && !strlen($oAddr->mailbox) && !$oAddr->personal)) {
+                    if(!$oAddr || ((isset($oAddr)) && !$oAddr->mailbox && !$oAddr->personal)) {
                         $sEmail = $sGroup . ':;';
                     }
                     $aAddress[] = $this->createAddressObject($aStack,$aComment,$sEmail,$sGroup);
@@ -587,13 +471,8 @@ class Rfc822Header {
                          $aAddrBookAddress = $this->parseAddress($aAddr['email'],true);
                      } else {
                          $iPosAt = strpos($aAddr['email'], '@');
-                         if ($iPosAt === FALSE) {
-                             $oAddr->mailbox = $aAddr['email'];
-                             $oAddr->host = FALSE;
-                         } else {
-                             $oAddr->mailbox = substr($aAddr['email'], 0, $iPosAt);
-                             $oAddr->host = substr($aAddr['email'], $iPosAt+1);
-                         }
+                         $oAddr->mailbox = substr($aAddr['email'], 0, $iPosAt);
+                         $oAddr->host = substr($aAddr['email'], $iPosAt+1);
                          if (isset($aAddr['name'])) {
                              $oAddr->personal = $aAddr['name'];
                          } else {
@@ -602,18 +481,18 @@ class Rfc822Header {
                      }
                  }
             }
-            if (!$grouplookup && !strlen($oAddr->mailbox)) {
+            if (!$grouplookup && !$oAddr->mailbox) {
                 $oAddr->mailbox = trim($sEmail);
-                if ($sHost && strlen($oAddr->mailbox)) {
+                if ($sHost && $oAddr->mailbox) {
                     $oAddr->host = $sHost;
                 }
             } else if (!$grouplookup && !$oAddr->host) {
-                if ($sHost && strlen($oAddr->mailbox)) {
+                if ($sHost && $oAddr->mailbox) {
                     $oAddr->host = $sHost;
                 }
             }
           }
-          if (!$aAddrBookAddress && strlen($oAddr->mailbox)) {
+          if (!$aAddrBookAddress && $oAddr->mailbox) {
               $aProcessedAddress[] = $oAddr;
           } else {
               $aProcessedAddress = array_merge($aProcessedAddress,$aAddrBookAddress);
@@ -622,46 +501,10 @@ class Rfc822Header {
         if ($ar) {
             return $aProcessedAddress;
         } else {
-            if (isset($aProcessedAddress[0]))
-                return $aProcessedAddress[0];
-            else
-                return '';
+            return $aProcessedAddress[0];
         }
     }
 
-    /**
-     * Normalise the different Priority headers into a uniform value,
-     * namely that of the X-Priority header (1, 3, 5). Supports:
-     * Priority, X-Priority, Importance.
-     * X-MS-Mail-Priority is not parsed because it always coincides
-     * with one of the other headers.
-     *
-     * NOTE: this is actually a duplicate from the function in
-     * functions/imap_messages. I'm not sure if it's ok here to call
-     * that function?
-     * @param string $sValue literal priority name
-     * @return integer
-     */
-    function parsePriority($sValue) {
-        // don't use function call inside array_shift.
-        $aValue = preg_split('/\s/',trim($sValue));
-        $value = strtolower(array_shift($aValue));
-
-        if ( is_numeric($value) ) {
-            return $value;
-        }
-        if ( $value == 'urgent' || $value == 'high' ) {
-            return 1;
-        } elseif ( $value == 'non-urgent' || $value == 'low' ) {
-            return 5;
-        }
-        // default is normal priority
-        return 3;
-    }
-
-    /**
-     * @param string $value content type header
-     */
     function parseContentType($value) {
         $pos = strpos($value, ';');
         $props = '';
@@ -682,11 +525,7 @@ class Rfc822Header {
         $this->content_type = $content_type;
     }
 
-    /**
-     * RFC2184
-     * @param array $aParameters
-     * @return array
-     */
+    /* RFC2184 */
     function processParameters($aParameters) {
         $aResults = array();
         $aCharset = array();
@@ -713,21 +552,13 @@ class Rfc822Header {
             $value = substr($value,strlen($charset)+1);
             $language = substr($value,0,strpos($value,"'"));
             $value = substr($value,strlen($charset)+1);
-            /* FIXME: What's the status of charset decode with language information ????
-             * Maybe language information contains only ascii text and charset_decode() 
-             * only runs sm_encode_html_special_chars() on it. If it contains 8bit information, you 
-             * get html encoded text in charset used by selected translation.
-             */
+            // FIX ME What's the status of charset decode with language information ????
             $value = charset_decode($charset,$value);
             $aResults[$key] = $value;
         }
         return $aResults;
     }
 
-    /**
-     * @param string $value
-     * @return array
-     */
     function parseProperties($value) {
         $propArray = explode(';', $value);
         $propResultArray = array();
@@ -737,7 +568,7 @@ class Rfc822Header {
             if ($pos > 0)  {
                 $key = trim(substr($prop, 0, $pos));
                 $val = trim(substr($prop, $pos+1));
-                if (strlen($val) > 0 && $val{0} == '"') {
+                if ($val{0} == '"') {
                     $val = substr($val, 1, -1);
                 }
                 $propResultArray[$key] = $val;
@@ -746,10 +577,6 @@ class Rfc822Header {
         return $this->processParameters($propResultArray);
     }
 
-    /**
-     * Fills disposition object in rfc822Header object
-     * @param string $value
-     */
     function parseDisposition($value) {
         $pos = strpos($value, ';');
         $props = '';
@@ -765,11 +592,6 @@ class Rfc822Header {
         $this->disposition = $disp;
     }
 
-    /**
-     * Fills mlist array keys in rfc822Header object 
-     * @param string $field
-     * @param string $value
-     */
     function mlist($field, $value) {
         $res_a = array();
         $value_a = explode(',', $value);
@@ -787,90 +609,19 @@ class Rfc822Header {
         $this->mlist[$field] = $res_a;
     }
 
-    /**
-     * Parses the X-Spam-Status or X-Spam-Score header
-     * @param string $value
-     */
-    function parseSpamStatus($value) {
-        // Header value looks like this:
-        // No, score=1.5 required=5.0 tests=MSGID_FROM_MTA_ID,NO_REAL_NAME,UPPERCASE_25_50 autolearn=disabled version=3.1.0-gr0
-        // Update circa 2018, this header can also be simply:
-        // No, score=1.5
-        // So we make the rest of the line optional (there are likely other permutations, so
-        // each element is made optional except the first two... maybe even that's not flexible enough)
-        //
-        // Also now allow parsing of X-Spam-Score header, whose value is just a float
-
-        $spam_status = array();
-
-        if (preg_match ('/^(?:(No|Yes),\s+score=)?(-?\d+\.\d+)(?:\s+required=(-?\d+\.\d+))?(?:\s+tests=(.*?))?(?:\s+autolearn=(.*?))?(?:\s+version=(.+?))?$/i', $value, $matches)) {
-
-            // full header
-            $spam_status['bad_format'] = 0;
-            $spam_status['value'] = $matches[0];
-
-            // is_spam
-            if (!empty($matches[1])) {
-                if (strtolower($matches[1]) == 'yes')
-                    $spam_status['is_spam'] = true;
-                else
-                    $spam_status['is_spam'] = false;
-            }
-
-            // score
-            if (isset($matches[2]))
-                $spam_status['score'] = $matches[2];
-
-            // required
-            if (isset($matches[3]))
-               $spam_status['required'] = $matches[3];
-
-            // tests
-            if (isset($matches[4])) {
-                $tests = array();
-                $tests = explode(',', $matches[4]);
-                foreach ($tests as $test) {
-                    $spam_status['tests'][] = trim($test);
-                }
-            }
-
-            // autolearn
-            if (isset($matches[5]))
-                $spam_status['autolearn'] = $matches[5];
-
-            // version
-            if (isset($matches[6]))
-                $spam_status['version'] = $matches[6];
-
-        } else {
-            $spam_status['bad_format'] = 1;
-            $spam_status['value'] = $value;
-        }
-        return $spam_status;
-    }
-
-    /**
-     * function to get the address strings out of the header.
+    /*
+     * function to get the addres strings out of the header.
+     * Arguments: string or array of strings !
      * example1: header->getAddr_s('to').
      * example2: header->getAddr_s(array('to', 'cc', 'bcc'))
-     * @param mixed $arr string or array of strings
-     * @param string $separator
-     * @param boolean $encoded (since 1.4.0) return encoded or plain text addresses
-     * @param boolean $unconditionally_quote (since 1.4.21/1.5.2) When TRUE, always
-     *                                                      quote the personal part,
-     *                                                      whether or not it is
-     *                                                      encoded, otherwise quoting
-     *                                                      is only added if the
-     *                                                      personal part is not encoded
-     * @return string
      */
-    function getAddr_s($arr, $separator = ',',$encoded=false,$unconditionally_quote=FALSE) {
+    function getAddr_s($arr, $separator = ',',$encoded=false) {
         $s = '';
 
         if (is_array($arr)) {
             foreach($arr as $arg) {
-                if ($this->getAddr_s($arg, $separator, $encoded, $unconditionally_quote)) {
-                    $s .= $separator;
+                if ($this->getAddr_s($arg, $separator, $encoded)) {
+                    $s .= $separator . $result;
                 }
             }
             $s = ($s ? substr($s, 2) : $s);
@@ -880,9 +631,9 @@ class Rfc822Header {
                 foreach ($addr as $addr_o) {
                     if (is_object($addr_o)) {
                         if ($encoded) {
-                            $s .= $addr_o->getEncodedAddress($unconditionally_quote) . $separator;
+                            $s .= $addr_o->getEncodedAddress() . $separator;
                         } else {
-                            $s .= $addr_o->getAddress(TRUE, FALSE, $unconditionally_quote) . $separator;
+                            $s .= $addr_o->getAddress() . $separator;
                         }
                     }
                 }
@@ -890,9 +641,9 @@ class Rfc822Header {
             } else {
                 if (is_object($addr)) {
                     if ($encoded) {
-                        $s .= $addr->getEncodedAddress($unconditionally_quote);
+                        $s .= $addr->getEncodedAddress();
                     } else {
-                        $s .= $addr->getAddress(TRUE, FALSE, $unconditionally_quote);
+                        $s .= $addr->getAddress();
                     }
                 }
             }
@@ -900,13 +651,6 @@ class Rfc822Header {
         return $s;
     }
 
-    /**
-     * function to get the array of addresses out of the header.
-     * @param mixed $arg string or array of strings
-     * @param array $excl_arr array of excluded email addresses
-     * @param array $arr array of added email addresses
-     * @return array
-     */
     function getAddr_a($arg, $excl_arr = array(), $arr = array()) {
         if (is_array($arg)) {
             foreach($arg as $argument) {
@@ -942,120 +686,49 @@ class Rfc822Header {
         return $arr;
     }
 
-    /**
-//FIXME: This needs some documentation (inside the function too)!  Don't code w/out comments!
-     * Looking at the code years after it was written,
-     * this is my (Paul) best guess as to what this
-     * function does (note that docs previously claimed
-     * that this function returns boolean or an array,
-     * but it no longer appears to return an array - an
-     * integer instead):
-     *
-     * Inspects the TO and CC (or FROM) headers of the
-     * message represented by this object, looking for
-     * the address(es) given by $address
-     *
-     * If $address is a string:
-     *    Serves as a test (returns boolean) as to
-     *    whether or not the given address is found
-     *    anywhere in the TO or CC (or FROM) headers
-     *
-     * If $address is an array:
-     *    Looks through this list of addresses and
-     *    returns the array index (an integer even
-     *    if the array is given with keys of a
-     *    different type) of the first matching
-     *    $address found in this message's
-     *    TO or CC (or FROM) headers, unless there
-     *    is an exact match (meaning that the "personal
-     *    information" in addition to the email
-     *    address also matches), in which case that
-     *    index (the first one found) is returned
-     *
-     * @param mixed $address Address(es) to search for in this
-     *                       message's TO and CC (or FROM)
-     *                       headers - please see above how the
-     *                       format of this argument affects the
-     *                       return value of this function
-     * @param boolean $use_from When TRUE, this function will ONLY
-     *                          search the FROM headers and NOT the
-     *                          TO and CC headers, when FALSE, ONLY
-     *                          the TO and CC headers are searched
-     *                          (OPTIONAL; default is FALSE)
-     * @param boolean $recurs FOR INTERNAL USE ONLY
-     *
-     * @return mixed Boolean when $address is a scalar,
-     *               indicating whether or not the address
-     *               was found in the TO or CC headers.
-     *               An integer when $address is an array,
-     *               containing the index of the value in
-     *               that array that was found in the TO
-     *               or CC headers, or boolean FALSE if
-     *               there were no matches at all
-     *
-     * @since 1.3.2
-     */
-    function findAddress($address, $use_from=FALSE, $recurs=FALSE) {
+    function findAddress($address, $recurs = false) {
         $result = false;
         if (is_array($address)) {
             $i=0;
             foreach($address as $argument) {
-                $match = $this->findAddress($argument, $use_from, true);
-                if ($match[1]) { // this indicates when the personal information matched
+                $match = $this->findAddress($argument, true);
+                $last = end($match);
+                if ($match[1]) {
                     return $i;
                 } else {
-                    if (count($match[0]) && $result === FALSE) {
+                    if (count($match[0]) && !$result) {
                         $result = $i;
                     }
                 }
                 ++$i;
             }
         } else {
+            if (!is_array($this->cc)) $this->cc = array();
             $srch_addr = $this->parseAddress($address);
             $results = array();
-            if ($use_from) {
-                if (!is_array($this->from)) $this->from = array();
-                foreach ($this->from as $from) {
-                    if (strtolower($from->host) == strtolower($srch_addr->host)) {
-                        if (strtolower($from->mailbox) == strtolower($srch_addr->mailbox)) {
-                            $results[] = $srch_addr;
-                            if (strtolower($from->personal) == strtolower($srch_addr->personal)) {
-                                if ($recurs) {
-                                    return array($results, true);
-                                } else {
-                                    return true;
-                                }
+            foreach ($this->to as $to) {
+                if ($to->host == $srch_addr->host) {
+                    if ($to->mailbox == $srch_addr->mailbox) {
+                        $results[] = $srch_addr;
+                        if ($to->personal == $srch_addr->personal) {
+                            if ($recurs) {
+                                return array($results, true);
+                            } else {
+                                return true;
                             }
                         }
                     }
                 }
-            } else {
-                if (!is_array($this->cc)) $this->cc = array();
-                if (!is_array($this->to)) $this->to = array();
-                foreach ($this->to as $to) {
-                    if (strtolower($to->host) == strtolower($srch_addr->host)) {
-                        if (strtolower($to->mailbox) == strtolower($srch_addr->mailbox)) {
-                            $results[] = $srch_addr;
-                            if (strtolower($to->personal) == strtolower($srch_addr->personal)) {
-                                if ($recurs) {
-                                    return array($results, true);
-                                } else {
-                                    return true;
-                                }
-                            }
-                        }
-                    }
-                }
-                foreach ($this->cc as $cc) {
-                    if (strtolower($cc->host) == strtolower($srch_addr->host)) {
-                        if (strtolower($cc->mailbox) == strtolower($srch_addr->mailbox)) {
-                            $results[] = $srch_addr;
-                            if (strtolower($cc->personal) == strtolower($srch_addr->personal)) {
-                                if ($recurs) {
-                                    return array($results, true);
-                                } else {
-                                    return true;
-                                }
+            }
+             foreach ($this->cc as $cc) {
+                if ($cc->host == $srch_addr->host) {
+                    if ($cc->mailbox == $srch_addr->mailbox) {
+                        $results[] = $srch_addr;
+                        if ($cc->personal == $srch_addr->personal) {
+                            if ($recurs) {
+                                return array($results, true);
+                            } else {
+                                return true;
                             }
                         }
                     }
@@ -1063,7 +736,7 @@ class Rfc822Header {
             }
             if ($recurs) {
                 return array($results, false);
-            } elseif (count($results)) {
+            } elseif (count($result)) {
                 return true;
             } else {
                 return false;
@@ -1073,12 +746,6 @@ class Rfc822Header {
         return $result;
     }
 
-    /**
-     * @param string $type0 media type
-     * @param string $type1 media subtype
-     * @return array media properties
-     * @todo check use of media type arguments
-     */
     function getContentType($type0, $type1) {
         $type0 = $this->content_type->type0;
         $type1 = $this->content_type->type1;
@@ -1086,3 +753,4 @@ class Rfc822Header {
     }
 }
 
+?>
