@@ -1,27 +1,34 @@
 <?php
 
 /**
- * functions/addressbook.php - Functions and classes for the addressbook system
+ * addressbook.php
  *
- * Functions require SM_PATH and support of forms.php functions
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: addressbook.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * Functions and classes for the addressbook system.
+ *
+ * $Id: addressbook.php,v 1.52 2003/12/26 09:13:37 tokul Exp $
  * @package squirrelmail
- * @subpackage addressbook
  */
 
 /**
- * If SM_PATH isn't defined, define it.  Required to include files.
- * @ignore
- */
-if (!defined('SM_PATH'))  {
-    define('SM_PATH','../');
-}
+   This is the path to the global site-wide addressbook.
+   It looks and feels just like a user's .abook file
+   If this is in the data directory, use "$data_dir/global.abook"
+   If not, specify the path as though it was accessed from the
+   src/ directory ("../global.abook" -> in main directory)
 
-/* make sure that display_messages.php is loaded */
-include_once(SM_PATH . 'functions/display_messages.php');
+   If you don't want a global site-wide addressbook, comment these
+   two lines out.  (They are disabled by default.)
+
+   The global addressbook is unmodifiable by anyone.  You must actually
+   use a shell script or whatnot to modify the contents.
+
+  global $data_dir, $address_book_global_filename;
+  $address_book_global_filename = "$data_dir/global.abook";
+
+*/
 
 global $addrbook_dsn, $addrbook_global_dsn;
 
@@ -30,21 +37,13 @@ global $addrbook_dsn, $addrbook_global_dsn;
    Returns the created object
 */
 function addressbook_init($showerr = true, $onlylocal = false) {
-    global $data_dir, $username, $color, $ldap_server, $address_book_global_filename;
+    global $data_dir, $username, $ldap_server, $address_book_global_filename;
     global $addrbook_dsn, $addrbook_table;
-    // Shared file based address book globals
-    global $abook_global_file, $abook_global_file_writeable, $abook_global_file_listing;
-    // Shared DB based address book globals
     global $addrbook_global_dsn, $addrbook_global_table, $addrbook_global_writeable, $addrbook_global_listing;
-    // Record size restriction in file based address books
-    global $abook_file_line_length;
 
     /* Create a new addressbook object */
     $abook = new AddressBook;
 
-    /* Create empty error message */
-    $abook_init_error='';
-
     /*
         Always add a local backend. We use *either* file-based *or* a
         database addressbook. If $addrbook_dsn is set, the database
@@ -59,80 +58,49 @@ function addressbook_init($showerr = true, $onlylocal = false) {
                             'owner' => $username,
                             'table' => $addrbook_table));
         if (!$r && $showerr) {
-            $abook_init_error.=_("Error initializing address book database.") .' '. $abook->error;
+            echo _("Error initializing addressbook database.");
+            exit;
         }
     } else {
         /* File */
         $filename = getHashedFile($username, $data_dir, "$username.abook");
         $r = $abook->add_backend('local_file', Array('filename' => $filename,
-                                                     'umask' => 0077,
-                                                     'line_length' => $abook_file_line_length,
-                                                     'create'   => true));
+                              'create'   => true));
         if(!$r && $showerr) {
-            $abook_init_error.=sprintf( _("Error opening file %s"), $filename );
+            printf( _("Error opening file %s"), $filename );
+            exit;
         }
+
     }
 
     /* This would be for the global addressbook */
-    if (isset($abook_global_file) && isset($abook_global_file_writeable)
-        && trim($abook_global_file)!=''){
-        // Detect place of address book
-        if (! preg_match("/[\/\\\]/",$abook_global_file)) {
-            /* no path chars, address book stored in data directory
-             * make sure that there is a slash between data directory
-             * and address book file name
-             */
-            $abook_global_filename=$data_dir
-                . ((substr($data_dir, -1) != '/') ? '/' : '')
-                . $abook_global_file;
-        } elseif (preg_match("/^\/|\w:/",$abook_global_file)) {
-            // full path is set in options (starts with slash or x:)
-            $abook_global_filename=$abook_global_file;
-        } else {
-            $abook_global_filename=SM_PATH . $abook_global_file;
-        }
-        $r = $abook->add_backend('local_file',array('filename'=>$abook_global_filename,
-                                                    'name' => _("Global address book"),
-                                                    'detect_writeable' => false,
-                                                    'line_length' => $abook_file_line_length,
-                                                    'writeable'=> $abook_global_file_writeable,
-                                                    'listing' => $abook_global_file_listing));
+    if (isset($address_book_global_filename)) {
+        $r = $abook->add_backend('global_file');
         if (!$r && $showerr) {
-            if ($abook_init_error!='') $abook_init_error.="\n";
-            $abook_init_error.=_("Error initializing global address book.") . "\n" . $abook->error;
+            echo _("Error initializing global addressbook.");
+            exit;
         }
     }
 
     /* Load global addressbook from SQL if configured */
     if (isset($addrbook_global_dsn) && !empty($addrbook_global_dsn)) {
-        /* Database configured */
-        if (!isset($addrbook_global_table) || empty($addrbook_global_table)) {
-            $addrbook_global_table = 'global_abook';
-        }
-        $r = $abook->add_backend('database',
-                                 Array('dsn' => $addrbook_global_dsn,
-                                       'owner' => 'global',
-                                       'name' => _("Global address book"),
-                                       'writeable' => $addrbook_global_writeable,
-                                       'listing' => $addrbook_global_listing,
-                                       'table' => $addrbook_global_table));
-        if (!$r && $showerr) {
-            if ($abook_init_error!='') $abook_init_error.="\n";
-            $abook_init_error.=_("Error initializing global address book.") . "\n" . $abook->error;
-    }
+      /* Database configured */
+      if (!isset($addrbook_global_table) || empty($addrbook_global_table)) {
+	$addrbook_global_table = 'global_abook';
+      }
+      $r = $abook->add_backend('database',
+			       Array('dsn' => $addrbook_global_dsn,
+				     'owner' => 'global',
+				     'name' => _("Global address book"),
+				     'writeable' => $addrbook_global_writeable,
+				     'listing' => $addrbook_global_listing,
+				     'table' => $addrbook_global_table));
     }
 
-    /*
-     * hook allows to include different address book backends.
-     * plugins should extract $abook and $r from arguments
-     * and use same add_backend commands as above functions.
-     * @since 1.5.1 and 1.4.5
-     */
-    $hookReturn = do_hook('abook_init', $abook, $r);
-    $abook = $hookReturn[1];
-    $r = $hookReturn[2];
+    if ($onlylocal) {
+        return $abook;
+    }
 
-    if (! $onlylocal) {
     /* Load configured LDAP servers (if PHP has LDAP support) */
     if (isset($ldap_server) && is_array($ldap_server) && function_exists('ldap_connect')) {
         reset($ldap_server);
@@ -140,22 +108,13 @@ function addressbook_init($showerr = true, $onlylocal = false) {
             if (is_array($param)) {
                 $r = $abook->add_backend('ldap_server', $param);
                 if (!$r && $showerr) {
-                        if ($abook_init_error!='') $abook_init_error.="\n";
-                        $abook_init_error.=sprintf(_("Error initializing LDAP server %s:") .
-                            "\n", $param['host']);
-                        $abook_init_error.= $abook->error;
-                    }
+                    printf( '&nbsp;' . _("Error initializing LDAP server %s:") .
+                            "<BR>\n", $param['host']);
+                    echo '&nbsp;' . $abook->error;
+                    exit;
                 }
             }
         }
-    } // end of remote abook backends init
-
-    /**
-     * display address book init errors.
-     */
-    if ($abook_init_error!='' && $showerr) {
-        $abook_init_error = sm_encode_html_special_chars($abook_init_error);
-        error_box($abook_init_error,$color);
     }
 
     /* Return the initialized object */
@@ -166,7 +125,7 @@ function addressbook_init($showerr = true, $onlylocal = false) {
 /*
  *   Had to move this function outside of the Addressbook Class
  *   PHP 4.0.4 Seemed to be having problems with inline functions.
- */
+ */    
 function addressbook_cmp($a,$b) {
 
     if($a['backend'] > $b['backend']) {
@@ -174,109 +133,11 @@ function addressbook_cmp($a,$b) {
     } else if($a['backend'] < $b['backend']) {
         return -1;
     }
-
+    
     return (strtolower($a['name']) > strtolower($b['name'])) ? 1 : -1;
 
 }
 
-/**
- * Sort array by the key "name"
- */
-function alistcmp($a,$b) {
-    $abook_sort_order=get_abook_sort();
-
-    switch ($abook_sort_order) {
-    case 0:
-    case 1:
-      $abook_sort='nickname';
-      break;
-    case 4:
-    case 5:
-      $abook_sort='email';
-      break;
-    case 6:
-    case 7:
-      $abook_sort='label';
-      break;
-    case 2:
-    case 3:
-    case 8:
-    default:
-      $abook_sort='name';
-    }
-
-    if ($a['backend'] > $b['backend']) {
-        return 1;
-    } else {
-        if ($a['backend'] < $b['backend']) {
-            return -1;
-        }
-    }
-
-    if( (($abook_sort_order+2) % 2) == 1) {
-      return (strtolower($a[$abook_sort]) < strtolower($b[$abook_sort])) ? 1 : -1;
-    } else {
-      return (strtolower($a[$abook_sort]) > strtolower($b[$abook_sort])) ? 1 : -1;
-    }
-}
-
-/**
- * Address book sorting options
- *
- * returns address book sorting order
- * @return integer book sorting options order
- */
-function get_abook_sort() {
-    global $data_dir, $username;
-
-    /* get sorting order */
-    if(sqgetGlobalVar('abook_sort_order', $temp, SQ_GET)) {
-      $abook_sort_order = (int) $temp;
-
-      if ($abook_sort_order < 0 or $abook_sort_order > 8)
-        $abook_sort_order=8;
-
-      setPref($data_dir, $username, 'abook_sort_order', $abook_sort_order);
-    } else {
-      /* get previous sorting options. default to unsorted */
-      $abook_sort_order = getPref($data_dir, $username, 'abook_sort_order', 8);
-    }
-
-    return $abook_sort_order;
-}
-
-/**
- * This function shows the address book sort button.
- *
- * @param integer $abook_sort_order current sort value
- * @param string $alt_tag alt tag value (string visible to text only browsers)
- * @param integer $Down sort value when list is sorted ascending
- * @param integer $Up sort value when list is sorted descending
- * @return string html code with sorting images and urls
- * @since 1.5.1 and 1.4.6
- */
-function show_abook_sort_button($abook_sort_order, $alt_tag, $Down, $Up ) {
-    global $form_url;
-
-     /* Figure out which image we want to use. */
-    if ($abook_sort_order != $Up && $abook_sort_order != $Down) {
-        $img = 'sort_none.png';
-        $which = $Up;
-    } elseif ($abook_sort_order == $Up) {
-        $img = 'up_pointer.png';
-        $which = $Down;
-    } else {
-        $img = 'down_pointer.png';
-        $which = 8;
-    }
-
-      /* Now that we have everything figured out, show the actual button. */
-    return ' <a href="' . $form_url .'?abook_sort_order=' . $which
-         . '"><img src="../images/' . $img
-         . '" border="0" width="12" height="10" alt="' . $alt_tag . '" title="'
-         . _("Click here to change the sorting of the address list") .'" /></a>';
-}
-
 
 /**
  * This is the main address book class that connect all the
@@ -291,20 +152,10 @@ class AddressBook {
     var $error       = '';
     var $localbackend = 0;
     var $localbackendname = '';
-    var $add_extra_field = false;
-
-    /**
-     * Constructor (PHP5 style, required in some future version of PHP)
-     */
-    function __construct() {
-        $this->localbackendname = _("Personal address book");
-    }
-
-    /**
-     * Constructor (PHP4 style, kept for compatibility reasons)
-     */
+    
+      // Constructor function.
     function AddressBook() {
-        self::__construct();
+        $localbackendname = _("Personal address book");
     }
 
     /*
@@ -342,7 +193,7 @@ class AddressBook {
 
         $newback->bnum = $this->numbackends;
         $this->backends[$this->numbackends] = $newback;
-
+        
         /* Store ID of first local backend added */
         if ($this->localbackend == 0 && $newback->btype == 'local') {
             $this->localbackend = $this->numbackends;
@@ -354,34 +205,23 @@ class AddressBook {
 
 
     /*
-     * This function takes a $row array as returned by the addressbook
+     * This function takes a $row array as returned by the addressbook 
      * search and returns an e-mail address with the full name or
      * nickname optionally prepended.
      */
 
-    static function full_address($row) {
-        global $data_dir, $username;
-        $addrsrch_fullname = getPref($data_dir, $username, 'addrsrch_fullname', 'fullname');
-
-        // allow multiple addresses in one row (poor person's grouping - bah)
-        // (separate with commas)
-        //
-        $return = '';
-        $addresses = explode(',', $row['email']);
-        foreach ($addresses as $address) {
-
-            if (!empty($return)) $return .= ', ';
-
-            if ($addrsrch_fullname == 'fullname')
-                $return .= '"' . $row['name'] . '" <' . trim($address) . '>';
-            else if ($addrsrch_fullname == 'nickname')
-                $return .= '"' . $row['nickname'] . '" <' . trim($address) . '>';
-            else // "noprefix"
-                $return .= trim($address);
+    function full_address($row) {
+        global $addrsrch_fullname, $data_dir, $username;
 
+        if (($prefix = getPref($data_dir, $username, 'addrsrch_fullname') or
+            isset($addrsrch_fullname) and $prefix = $addrsrch_fullname)
+            and $prefix !== 'noprefix') {
+            $name = ($prefix === 'nickname') ? $row['nickname']
+                : $row['name'];
+            return $name . ' <' . trim($row['email']) . '>';
+        } else {
+            return trim($row['email']);
         }
-
-        return $return;
     }
 
     /*
@@ -403,7 +243,7 @@ class AddressBook {
                 if (is_array($res)) {
                     $ret = array_merge($ret, $res);
                 } else {
-                    $this->error .= "\n" . $backend->error;
+                    $this->error .= "<br>\n" . $backend->error;
                     $failed++;
                 }
             }
@@ -419,7 +259,7 @@ class AddressBook {
 
             $ret = $this->backends[$bnum]->search($expression);
             if (!is_array($ret)) {
-                $this->error .= "\n" . $this->backends[$bnum]->error;
+                $this->error .= "<br>\n" . $this->backends[$bnum]->error;
                 $ret = FALSE;
             }
         }
@@ -430,52 +270,47 @@ class AddressBook {
 
     /* Return a sorted search */
     function s_search($expression, $bnum = -1) {
-
+    
         $ret = $this->search($expression, $bnum);
         if ( is_array( $ret ) ) {
             usort($ret, 'addressbook_cmp');
-        }
+        }    
         return $ret;
     }
 
 
     /*
-     *  Lookup an address by the indicated field. Only
-     *  possible in local backends.
+     *  Lookup an address by alias. Only possible in
+     *  local backends.
      */
-    function lookup($value, $bnum = -1, $field = SM_ABOOK_FIELD_NICKNAME) {
-
+    function lookup($alias, $bnum = -1) {
+    
         $ret = array();
-
+    
         if ($bnum > -1) {
-            $res = $this->backends[$bnum]->lookup($value, $field);
+            $res = $this->backends[$bnum]->lookup($alias);
             if (is_array($res)) {
                return $res;
             } else {
-               $this->error = $this->backends[$bnum]->error;
+               $this->error = $backend->error;
                return false;
             }
         }
-
+    
         $sel = $this->get_backend_list('local');
         for ($i = 0 ; $i < sizeof($sel) ; $i++) {
             $backend = &$sel[$i];
             $backend->error = '';
-            $res = $backend->lookup($value, $field);
-
-            // return an address if one is found
-            // (empty array means lookup concluded
-            // but no result found - in this case,
-            // proceed to next backend)
-            //
+            $res = $backend->lookup($alias);
             if (is_array($res)) {
-                if (!empty($res)) return $res;
+               if(!empty($res))
+              return $res;
             } else {
-                $this->error = $backend->error;
-                return false;
+               $this->error = $backend->error;
+               return false;
             }
         }
-
+        
         return $ret;
     }
 
@@ -483,13 +318,13 @@ class AddressBook {
     /* Return all addresses */
     function list_addr($bnum = -1) {
         $ret = array();
-
+        
         if ($bnum == -1) {
-            $sel = $this->get_backend_list('');
+            $sel = $this->get_backend_list('local');
         } else {
             $sel = array(0 => &$this->backends[$bnum]);
         }
-
+        
         for ($i = 0 ; $i < sizeof($sel) ; $i++) {
             $backend = &$sel[$i];
             $backend->error = '';
@@ -501,7 +336,7 @@ class AddressBook {
                return false;
             }
         }
-
+        
         return $ret;
     }
 
@@ -511,7 +346,7 @@ class AddressBook {
      * to, or false if it failed.
      */
     function add($userdata, $bnum) {
-
+    
         /* Validate data */
         if (!is_array($userdata)) {
             $this->error = _("Invalid input data");
@@ -528,13 +363,18 @@ class AddressBook {
         if (empty($userdata['nickname'])) {
             $userdata['nickname'] = $userdata['email'];
         }
-
-        /* Check that specified backend accept new entries */
-        if (!$this->backends[$bnum]->writeable) {
-            $this->error = _("Address book is read-only");
+        
+        if (eregi('[ \\:\\|\\#\\"\\!]', $userdata['nickname'])) {
+            $this->error = _("Nickname contains illegal characters");
             return false;
         }
-
+        
+        /* Check that specified backend accept new entries */
+        if (!$this->backends[$bnum]->writeable) {
+            $this->error = _("Addressbook is read-only");
+            return false;
+        }
+        
         /* Add address to backend */
         $res = $this->backends[$bnum]->add($userdata);
         if ($res) {
@@ -543,7 +383,7 @@ class AddressBook {
             $this->error = $this->backends[$bnum]->error;
             return false;
         }
-
+        
         return false;  // Not reached
     } /* end of add() */
 
@@ -553,23 +393,23 @@ class AddressBook {
      * If $alias is an array, all users in the array are removed.
      */
     function remove($alias, $bnum) {
-
+    
         /* Check input */
         if (empty($alias)) {
             return true;
         }
-
+        
         /* Convert string to single element array */
         if (!is_array($alias)) {
             $alias = array(0 => $alias);
         }
-
-        /* Check that specified backend is writable */
+        
+        /* Check that specified backend is writeable */
         if (!$this->backends[$bnum]->writeable) {
-            $this->error = _("Address book is read-only");
+            $this->error = _("Addressbook is read-only");
             return false;
         }
-
+        
         /* Remove user from backend */
         $res = $this->backends[$bnum]->remove($alias);
         if ($res) {
@@ -578,7 +418,7 @@ class AddressBook {
             $this->error = $this->backends[$bnum]->error;
             return false;
         }
-
+        
         return FALSE;  /* Not reached */
     } /* end of remove() */
 
@@ -588,12 +428,12 @@ class AddressBook {
      * If $alias is an array, all users in the array are removed.
      */
     function modify($alias, $userdata, $bnum) {
-
+    
         /* Check input */
         if (empty($alias) || !is_string($alias)) {
             return true;
         }
-
+        
         /* Validate data */
         if(!is_array($userdata)) {
             $this->error = _("Invalid input data");
@@ -607,17 +447,22 @@ class AddressBook {
             $this->error = _("E-mail address is missing");
             return false;
         }
-
+        
+        if (eregi('[\\: \\|\\#"\\!]', $userdata['nickname'])) {
+            $this->error = _("Nickname contains illegal characters");
+            return false;
+        }
+        
         if (empty($userdata['nickname'])) {
             $userdata['nickname'] = $userdata['email'];
         }
-
-        /* Check that specified backend is writable */
+        
+        /* Check that specified backend is writeable */
         if (!$this->backends[$bnum]->writeable) {
-            $this->error = _("Address book is read-only");;
+            $this->error = _("Addressbook is read-only");;
             return false;
         }
-
+        
         /* Modify user in backend */
         $res = $this->backends[$bnum]->modify($alias, $userdata);
         if ($res) {
@@ -626,11 +471,11 @@ class AddressBook {
             $this->error = $this->backends[$bnum]->error;
             return false;
         }
-
+        
         return FALSE;  /* Not reached */
     } /* end of modify() */
-
-
+    
+    
 } /* End of class Addressbook */
 
 /**
@@ -643,7 +488,7 @@ class addressbook_backend {
     var $btype      = 'dummy';
     var $bname      = 'dummy';
     var $sname      = 'Dummy backend';
-
+    
     /*
      * Variables common for all backends, but that
      * should not be changed by the backends.
@@ -651,40 +496,40 @@ class addressbook_backend {
     var $bnum       = -1;
     var $error      = '';
     var $writeable  = false;
-
+    
     function set_error($string) {
         $this->error = '[' . $this->sname . '] ' . $string;
         return false;
     }
-
-
+    
+    
     /* ========================== Public ======================== */
-
+    
     function search($expression) {
         $this->set_error('search not implemented');
         return false;
     }
-
-    function lookup($value, $field=SM_ABOOK_FIELD_NICKNAME) {
+    
+    function lookup($alias) {
         $this->set_error('lookup not implemented');
         return false;
     }
-
+    
     function list_addr() {
         $this->set_error('list_addr not implemented');
         return false;
     }
-
+    
     function add($userdata) {
         $this->set_error('add not implemented');
         return false;
     }
-
+    
     function remove($alias) {
         $this->set_error('delete not implemented');
         return false;
     }
-
+    
     function modify($alias, $newuserdata) {
         $this->set_error('modify not implemented');
         return false;
@@ -692,6 +537,19 @@ class addressbook_backend {
 
 }
 
+/* Sort array by the key "name" */
+function alistcmp($a,$b) {
+    if ($a['backend'] > $b['backend']) {
+        return 1;
+    } else {
+        if ($a['backend'] < $b['backend']) {
+            return -1;
+        }
+    }
+    return (strtolower($a['name']) > strtolower($b['name'])) ? 1 : -1;
+}
+
+
 /*
   PHP 5 requires that the class be made first, which seems rather
   logical, and should have been the way it was generated the first time.
@@ -700,17 +558,16 @@ class addressbook_backend {
 require_once(SM_PATH . 'functions/abook_local_file.php');
 require_once(SM_PATH . 'functions/abook_ldap_server.php');
 
+/* Use this if you wanna have a global address book */
+if (isset($address_book_global_filename)) {
+    include_once(SM_PATH . 'functions/abook_global_file.php');
+}
+
 /* Only load database backend if database is configured */
-if((isset($addrbook_dsn) && !empty($addrbook_dsn)) ||
- (isset($addrbook_global_dsn) && !empty($addrbook_global_dsn))) {
+if((isset($addrbook_dsn) && !empty($addrbook_dsn)) || 
+ (isset($addrbook_global_dsn) && !empty($addrbook_global_dsn)) ) {
   include_once(SM_PATH . 'functions/abook_database.php');
 }
 
-/*
- * hook allows adding different address book classes.
- * class must follow address book class coding standards.
- *
- * see addressbook_backend class and functions/abook_*.php files.
- * @since 1.5.1 and 1.4.5
- */
-do_hook('abook_add_class');
+
+?>
