@@ -3,16 +3,17 @@
 /**
  * attachment_common.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * This file provides the handling of often-used attachment types.
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: attachment_common.php 14817 2019-04-27 05:03:19Z pdontthink $
+ * $Id: attachment_common.php,v 1.26 2003/10/28 21:27:46 tassium Exp $
  * @package squirrelmail
  */
 
 /**
- * FIXME Needs phpDocumentator style documentation
+ * Needs documentation
  */
 require_once(SM_PATH . 'functions/global.php');
 
@@ -30,14 +31,11 @@ $FileExtensionToMimeType = array('bmp'  => 'image/x-bitmap',
                                  'png'  => 'image/png',
                                  'rtf'  => 'text/richtext',
                                  'txt'  => 'text/plain',
-                                 'patch'=> 'text/plain',
                                  'vcf'  => 'text/x-vcard');
 
 /* Register browser-supported image types */
 sqgetGlobalVar('attachment_common_types', $attachment_common_types);
 if (isset($attachment_common_types)) {
-    // var is used to detect activation of jpeg image types
-    unset($jpeg_done);
     /* Don't run this before being logged in. That may happen
        when plugins include mime.php */
     foreach ($attachment_common_types as $val => $v) {
@@ -53,25 +51,12 @@ if (isset($attachment_common_types)) {
             register_attachment_common('image/png',       'link_image');
         elseif ($val == 'image/x-xbitmap')
             register_attachment_common('image/x-xbitmap', 'link_image');
-        elseif ($val == '*/*' || $val == 'image/*') {
-            /**
-             * browser (Firefox) declared that anything is acceptable. 
-             * Lets register some common image types.
-             */
-            if (! isset($jpeg_done)) {
-                $jpeg_done = 1;
-                register_attachment_common('image/jpeg',  'link_image');
-                register_attachment_common('image/pjpeg', 'link_image');
-            }
-            register_attachment_common('image/gif',       'link_image');
-            register_attachment_common('image/png',       'link_image');
-            register_attachment_common('image/x-xbitmap', 'link_image');
-        }
     }
     unset($jpeg_done);
 }
 
 /* Register text-type attachments */
+//register_attachment_common('message/rfc822', 'link_text');
 register_attachment_common('message/rfc822', 'link_message');
 register_attachment_common('text/plain',     'link_text');
 register_attachment_common('text/richtext',  'link_text');
@@ -102,152 +87,130 @@ function register_attachment_common($type, $func) {
 }
 
 
-function attachment_common_link_text(&$Args) {
-
-    global $squirrelmail_attachments_finished_handling;
-    // TODO: The two lines below used to only depend on $Args[7] (the so-called "display filename") but that prevents attachments with the same name from having "View" links, which makes no sense.... however, was there originally some use case where this made sense??  For now, I've added the entity ID to make it unique
-    if (!empty($squirrelmail_attachments_finished_handling[$Args[7] . $Args[5]])) return;
-    $squirrelmail_attachments_finished_handling[$Args[7] . $Args[5]] = TRUE;
-
-    /* If there is a text attachment, we would like to create a "View" button
+function attachment_common_link_text(&$Args)
+{
+    /* If there is a text attachment, we would like to create a 'view' button
        that links to the text attachment viewer.
-
+      
        $Args[1] = the array of actions
-
-       Use the name of this file for adding an action
-       $Args[1]['attachment_common'] = Array for href and text
-
+      
+       Use our plugin name for adding an action
+       $Args[1]['attachment_common'] = array for href and text
+      
        $Args[1]['attachment_common']['text'] = What is displayed
-       $Args[1]['attachment_common']['href'] = Where it links to */
+       $Args[1]['attachment_common']['href'] = Where it links to
+      
+       This sets the 'href' of this plugin for a new link. */
     sqgetGlobalVar('QUERY_STRING', $QUERY_STRING, SQ_SERVER);
 
     $Args[1]['attachment_common']['href'] = SM_PATH . 'src/view_text.php?'. $QUERY_STRING;
     $Args[1]['attachment_common']['href'] =
-          set_url_var($Args[1]['attachment_common']['href'],
-          'ent_id',$Args[5]);
-
-    /* The link that we created needs a name. */
-    $Args[1]['attachment_common']['text'] = _("View");
+          set_url_var($Args[1]['attachment_common']['href'], 
+	  'ent_id',$Args[5]);
+  
+    /* The link that we created needs a name.  "view" will be displayed for
+       all text attachments handled by this plugin. */
+    $Args[1]['attachment_common']['text'] = _("view");
 
     /* Each attachment has a filename on the left, which is a link.
        Where that link points to can be changed.  Just in case the link above
        for viewing text attachments is not the same as the default link for
        this file, we'll change it.
-
+      
        This is a lot better in the image links, since the defaultLink will just
        download the image, but the one that we set it to will format the page
        to have an image tag in the center (looking a lot like this text viewer) */
     $Args[6] = $Args[1]['attachment_common']['href'];
 }
 
-function attachment_common_link_message(&$Args) {
-
-    global $squirrelmail_attachments_finished_handling;
-    // TODO: The two lines below used to only depend on $Args[7] (the so-called "display filename") but that prevents attachments with the same name from having "View" links, which makes no sense.... however, was there originally some use case where this made sense??  For now, I've added the entity ID to make it unique
-    if (!empty($squirrelmail_attachments_finished_handling[$Args[7] . $Args[5]])) return;
-    $squirrelmail_attachments_finished_handling[$Args[7] . $Args[5]] = TRUE;
-
+function attachment_common_link_message(&$Args)
+{
     $Args[1]['attachment_common']['href'] = SM_PATH . 'src/read_body.php?startMessage=' .
         $Args[2] . '&amp;passed_id=' . $Args[3] . '&amp;mailbox=' . $Args[4] .
         '&amp;passed_ent_id=' . $Args[5] . '&amp;override_type0=message&amp;override_type1=rfc822';
+    /* The link that we created needs a name.  "view" will be displayed for
+       all text attachments handled by this plugin. */
+    $Args[1]['attachment_common']['text'] = _("view");
 
-    $Args[1]['attachment_common']['text'] = _("View");
-
-    $Args[6] = $Args[1]['attachment_common']['href'];
+    $Args[6] = $Args[1]['attachment_common']['href'];    
 }
 
 
-function attachment_common_link_html(&$Args) {
-
-    global $squirrelmail_attachments_finished_handling;
-    // TODO: The two lines below used to only depend on $Args[7] (the so-called "display filename") but that prevents attachments with the same name from having "View" links, which makes no sense.... however, was there originally some use case where this made sense??  For now, I've added the entity ID to make it unique
-    if (!empty($squirrelmail_attachments_finished_handling[$Args[7] . $Args[5]])) return;
-    $squirrelmail_attachments_finished_handling[$Args[7] . $Args[5]] = TRUE;
-
+function attachment_common_link_html(&$Args) 
+{
     sqgetGlobalVar('QUERY_STRING', $QUERY_STRING, SQ_SERVER);
 
     $Args[1]['attachment_common']['href'] = SM_PATH . 'src/view_text.php?'. $QUERY_STRING.
        /* why use the overridetype? can this be removed */
        '&amp;override_type0=text&amp;override_type1=html';
     $Args[1]['attachment_common']['href'] =
-          set_url_var($Args[1]['attachment_common']['href'],
-          'ent_id',$Args[5]);
+          set_url_var($Args[1]['attachment_common']['href'], 
+	  'ent_id',$Args[5]);
 
-    $Args[1]['attachment_common']['text'] = _("View");
+    $Args[1]['attachment_common']['text'] = _("view");
 
     $Args[6] = $Args[1]['attachment_common']['href'];
 }
 
-function attachment_common_link_image(&$Args) {
-
-    global $squirrelmail_attachments_finished_handling;
-    // TODO: The two lines below used to only depend on $Args[7] (the so-called "display filename") but that prevents attachments with the same name from having "View" links, which makes no sense.... however, was there originally some use case where this made sense??  For now, I've added the entity ID to make it unique
-    if (!empty($squirrelmail_attachments_finished_handling[$Args[7] . $Args[5]])) return;
-    $squirrelmail_attachments_finished_handling[$Args[7] . $Args[5]] = TRUE;
-
+function attachment_common_link_image(&$Args)
+{
     global $attachment_common_show_images, $attachment_common_show_images_list;
 
     sqgetGlobalVar('QUERY_STRING', $QUERY_STRING, SQ_SERVER);
-
+   
     $info['passed_id'] = $Args[3];
     $info['mailbox'] = $Args[4];
     $info['ent_id'] = $Args[5];
-
+    
     $attachment_common_show_images_list[] = $info;
-
+    
     $Args[1]['attachment_common']['href'] = SM_PATH . 'src/image.php?'. $QUERY_STRING;
     $Args[1]['attachment_common']['href'] =
-          set_url_var($Args[1]['attachment_common']['href'],
-          'ent_id',$Args[5]);
-
-    $Args[1]['attachment_common']['text'] = _("View");
-
+          set_url_var($Args[1]['attachment_common']['href'], 
+	  'ent_id',$Args[5]);
+  
+    $Args[1]['attachment_common']['text'] = _("view");
+    
     $Args[6] = $Args[1]['attachment_common']['href'];
+
 }
 
 
-function attachment_common_link_vcard(&$Args) {
-
-    global $squirrelmail_attachments_finished_handling;
-    // TODO: The two lines below used to only depend on $Args[7] (the so-called "display filename") but that prevents attachments with the same name from having "View" links, which makes no sense.... however, was there originally some use case where this made sense??  For now, I've added the entity ID to make it unique
-    if (!empty($squirrelmail_attachments_finished_handling[$Args[7] . $Args[5]])) return;
-    $squirrelmail_attachments_finished_handling[$Args[7] . $Args[5]] = TRUE;
-
+function attachment_common_link_vcard(&$Args)
+{
     sqgetGlobalVar('QUERY_STRING', $QUERY_STRING, SQ_SERVER);
-
+ 
     $Args[1]['attachment_common']['href'] = SM_PATH . 'src/vcard.php?'. $QUERY_STRING;
     $Args[1]['attachment_common']['href'] =
-          set_url_var($Args[1]['attachment_common']['href'],
-          'ent_id',$Args[5]);
-
-    $Args[1]['attachment_common']['text'] = _("View Business Card");
-
+          set_url_var($Args[1]['attachment_common']['href'], 
+	  'ent_id',$Args[5]);
+  
+    $Args[1]['attachment_common']['text'] = _("Business Card");
+  
     $Args[6] = $Args[1]['attachment_common']['href'];
 }
 
 
-function attachment_common_octet_stream(&$Args) {
+function attachment_common_octet_stream(&$Args)
+{
     global $FileExtensionToMimeType;
-
+   
     do_hook('attachment_common-load_mime_types');
-
-    preg_match('/\.([^.]+)$/', $Args[7], $Regs);
-
-    $Ext = '';
-    if (is_array($Regs) && isset($Regs[1])) {
-        $Ext = $Regs[1];
-        $Ext = strtolower($Regs[1]);
-    }
-
+   
+    ereg('\\.([^\\.]+)$', $Args[7], $Regs);
+  
+    $Ext = strtolower($Regs[1]);
+   
     if ($Ext == '' || ! isset($FileExtensionToMimeType[$Ext]))
-        return;
-
-    $Ret = do_hook('attachment ' . $FileExtensionToMimeType[$Ext],
-        $Args[1], $Args[2], $Args[3], $Args[4], $Args[5], $Args[6],
+        return;       
+   
+    $Ret = do_hook('attachment ' . $FileExtensionToMimeType[$Ext], 
+        $Args[1], $Args[2], $Args[3], $Args[4], $Args[5], $Args[6], 
         $Args[7], $Args[8], $Args[9]);
-
+       
     foreach ($Ret as $a => $b) {
         $Args[$a] = $b;
     }
 }
 
+?>
