@@ -3,15 +3,15 @@
 /**
  * constants.php
  *
- * Loads constants used by the rest of the SquirrelMail source.
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
+ * Loads constants used by the rest of the Squirrelmail source.
  * This file is include by src/login.php, src/redirect.php and
  * src/load_prefs.php.
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: constants.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: constants.php,v 1.19 2003/10/28 21:27:46 tassium Exp $
  * @package squirrelmail
- * @since 1.2.0
  */
 
 /** Need to enable plugin functions for a hook */
@@ -53,17 +53,6 @@ define('SMPREF_JS_OFF', 0);
 define('SMPREF_JS_ON', 1);
 define('SMPREF_JS_AUTODETECT', 2);
 
-/* Define constants for address book functionalities. */
-define('SM_ABOOK_FIELD_NICKNAME', 0);
-define('SM_ABOOK_FIELD_FIRSTNAME', 1);
-define('SM_ABOOK_FIELD_LASTNAME', 2);
-define('SM_ABOOK_FIELD_EMAIL', 3);
-define('SM_ABOOK_FIELD_LABEL', 4);
-
-/* Define constants for script libraries. */
-define('SM_SCRIPT_LIB_REMOTE_REQUEST', 'remote_request.js');
-define('SM_SCRIPT_LIB_RELOAD_PAGE', 'reload_page.js');
-define('SM_SCRIPT_LIB_COMMON', 'common.js');
-
 do_hook('loading_constants');
 
+?>
