@@ -3,16 +3,16 @@
 /**
  * date.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Takes a date and parses it into a usable format.  The form that a
  * date SHOULD arrive in is:
  *       <Tue,> 29 Jun 1999 09:52:11 -0500 (EDT)
  * (as specified in RFC 822) -- 'Tue' is optional
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: date.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: date.php,v 1.53 2003/10/29 09:35:51 kink Exp $
  * @package squirrelmail
- * @subpackage date
  */
 
 /** Load up some useful constants */
@@ -37,26 +37,26 @@ function getGMTSeconds($stamp, $tzc) {
         case 'PST':
             $tzc = '-0800';
             break;
-        case 'Mountain':
-        case 'MST':
-        case 'PDT':
-            $tzc = '-0700';
+        case 'Mountain':   
+        case 'MST':   
+        case 'PDT':   
+            $tzc = '-0700';     
             break;
         case 'Central':
         case 'CST':
-        case 'MDT':
-            $tzc = '-0600';
+        case 'MDT':   
+            $tzc = '-0600';     
             break;
         case 'Eastern':
         case 'EST':
-        case 'CDT':
-            $tzc = '-0500';
+        case 'CDT':   
+            $tzc = '-0500';     
             break;
         case 'EDT':
             $tzc = '-0400';
             break;
-        case 'GMT':
-            $tzc = '+0000';
+        case 'GMT':   
+            $tzc = '+0000';     
             break;
         case 'BST':
         case 'MET':
@@ -64,19 +64,17 @@ function getGMTSeconds($stamp, $tzc) {
             $tzc = '+0100';
             break;
         case 'EET':
-        case 'IST':
-        case 'MET DST':
-        case 'METDST':
-	case 'CEST':
-	case 'MEST':
-            $tzc = '+0200';
+        case 'IST':   
+        case 'MET DST':   
+        case 'METDST':   
+            $tzc = '+0200';     
             break;
-        case 'HKT':
-            $tzc = '+0800';
+        case 'HKT':   
+            $tzc = '+0800';     
             break;
-        case 'JST':
+        case 'JST':   
         case 'KST':
-            $tzc = '+0900';
+            $tzc = '+0900';     
             break;
     }
     $neg = false;
@@ -88,14 +86,14 @@ function getGMTSeconds($stamp, $tzc) {
     $hh = substr($tzc,1,2);
     $mm = substr($tzc,3,2);
     $iTzc = ($hh * 60 + $mm) * 60;
-    if ($neg) $iTzc = -1 * (int) $iTzc;
+    if ($neg) $iTzc = -1 * (int) $iTzc; 
     /* stamp in gmt */
     $stamp -= $iTzc;
     /** now find what the server is at **/
     $current = date('Z', time());
     /* stamp in local timezone */
     $stamp += $current;
-
+    
     return $stamp;
 }
 
@@ -178,7 +176,7 @@ function getDayAbrv( $day_number ) {
 /**
  * Returns the (localized) string for a given month number.
  *
- * @param string month_number the month number (01..12)
+ * @param string month_number the month number (01..12) 
  * @return string the month name in human readable form
  */
 function getMonthName( $month_number ) {
@@ -229,7 +227,7 @@ function getMonthName( $month_number ) {
  * Returns the (localized) string for a given month number,
  * short representation.
  *
- * @param string month_number the month number (01..12)
+ * @param string month_number the month number (01..12) 
  * @return string the shortened month in human readable form
  */
 function getMonthAbrv( $month_number ) {
@@ -288,7 +286,7 @@ function date_intl( $date_format, $stamp ) {
     // to reduce the date calls we retrieve m and w in the same call
     $ret = date('w#m#'. $ret, $stamp );
     // extract day and month in order to replace later by intl day and month
-    $aParts = explode('#',$ret);
+    $aParts = explode('#',$ret);        
     $ret = str_replace(array('$1','$4','$2','$3',), array(getDayAbrv($aParts[0]),
                                                           getMonthAbrv($aParts[1]),
                    				          getMonthName($aParts[1]),
@@ -303,23 +301,22 @@ function date_intl( $date_format, $stamp ) {
  * and taking localization into accout.
  *
  * @param int stamp the timestamp
- * @param string fallback string to use when stamp not valid
  * @return string the long date string
  */
-function getLongDateString( $stamp, $fallback = '' ) {
+function getLongDateString( $stamp ) {
 
     global $hour_format;
-
+    
     if ($stamp == -1) {
-        return $fallback;
+        return '';
     }
 
     if ( $hour_format == SMPREF_TIME_12HR ) {
         $date_format = _("D, F j, Y g:i a");
     } else {
-        $date_format = _("D, F j, Y H:i");
+        $date_format = _("D, F j, Y G:i");
     }
-
+    
     return( date_intl( $date_format, $stamp ) );
 
 }
@@ -331,71 +328,47 @@ function getLongDateString( $stamp, $fallback = '' ) {
  * of the form: "14:23" or "Jun 14, 2003" depending
  * on whether the stamp is "today" or not.
  *
- * @param int $stamp The timestamp
- * @param boolean $return_full_date_and_time When TRUE,
- *                                           ignore all
- *                                           user settings
- *                                           and use full
- *                                           date and time
- *                                           (OPTIONAL;
- *                                           default FALSE)
+ * @param int stamp the timestamp
  * @return string the date string
  */
-function getDateString( $stamp, $return_full_date_and_time=FALSE ) {
+function getDateString( $stamp ) {
 
     global $invert_time, $hour_format, $show_full_date;
 
     if ( $stamp == -1 ) {
        return '';
     }
-
+    
     $now = time();
-
+    
     $dateZ = date('Z', $now );
-
-    // FIXME: isn't this obsolete and introduced as a terrible workaround
-    // for bugs at other places which are fixed a long time ago?
     if ($invert_time) {
         $dateZ = - $dateZ;
     }
-
-    // calculate when it was midnight and when it will be,
-    // in order to display dates differently if they're 'today'
     $midnight = $now - ($now % 86400) - $dateZ;
-    // this is to correct if after calculations midnight is more than
-    // one whole day away.
-    if ($now - $midnight > 86400) {
-        $midnight += 86400;
-    }
     $nextmid = $midnight + 86400;
-
-    if ($return_full_date_and_time) {
-        if ( $hour_format == SMPREF_TIME_12HR ) {
-            $date_format = _("D, F j, Y g:i a");
-        } else {
-            $date_format = _("D, F j, Y H:i");
-        }
-    } else if (($show_full_date == 1) || ($nextmid < $stamp)) {
+    
+    if (($show_full_date == 1) || ($nextmid < $stamp)) {
         $date_format = _("M j, Y");
     } else if ($midnight < $stamp) {
         /* Today */
         if ( $hour_format == SMPREF_TIME_12HR ) {
             $date_format = _("g:i a");
         } else {
-            $date_format = _("H:i");
+            $date_format = _("G:i");
         }
     } else if ($midnight - 518400 < $stamp) {
         /* This week */
         if ( $hour_format == SMPREF_TIME_12HR ) {
             $date_format = _("D, g:i a");
         } else {
-            $date_format = _("D, H:i");
+            $date_format = _("D, G:i");
         }
     } else {
         /* before this week */
         $date_format = _("M j, Y");
     }
-
+    
     return( date_intl( $date_format, $stamp ) );
 }
 
@@ -418,33 +391,19 @@ function getTimeStamp($dateParts) {
     **        In that case, dateParts[0] would be the <day of month>
     **        and everything would be bumped up one.
     **/
-    if (count($dateParts) <2) {
-        return -1;
-    } else if (count($dateParts) ==3) {
-        if (substr_count($dateParts[0],'-') == 2 &&
-            substr_count($dateParts[1],':') == 2) {
-            //  dd-Month-yyyy 23:19:05 +0200
-            //  redefine the date
-            $aDate = explode('-',$dateParts[0]);
-            $newDate = array($aDate[0],$aDate[1],$aDate[2],$dateParts[1],$dateParts[2]);
-            $dateParts = $newDate;
-        }
-    }
 
-    /*
+    /* 
      * Simply check to see if the first element in the dateParts
      * array is an integer or not.
      * Since the day of week is optional, this check is needed.
      */
+     if (count($dateParts) <2) {
+        return 0;
+     }
+
+    /* remove day of week */
     if (!is_numeric(trim($dateParts[0]))) {
-        /* cope with broken mailers that send "Tue,23" without space */
-        if ( preg_match ('/^\w+,(\d{1,2})$/', $dateParts[0], $match) ) {
-            /* replace Tue,23 with 23 */
-            $dateParts[0] = $match[1];
-        } else {
-            /* just drop the day of the week */
-            array_shift($dateParts);
-        }
+        $dataParts = array_shift($dateParts);
     }
     /* calculate timestamp separated from the zone and obs-zone */
     $stamp = strtotime(implode (' ', array_splice ($dateParts,0,4)));
@@ -475,3 +434,4 @@ function getTimeStamp($dateParts) {
       return ($mtime);
    }
 */
+?>
