@@ -3,14 +3,15 @@
 /**
  * functions/decode/us_ascii.php
  *
+ * Copyright (c) 2004 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * This file contains us-ascii decoding function that is needed to read
  * us-ascii encoded mails in non-us-ascii locale.
  *
  * Function replaces all 8bit symbols with '?' marks
  *
- * @copyright 2004-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: us_ascii.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: us_ascii.php,v 1.1 2004/01/29 19:37:29 tokul Exp $
  * @package squirrelmail
  * @subpackage decode
  */
@@ -22,15 +23,20 @@
  * @return string cleaned string
  */
 function charset_decode_us_ascii ($string) {
-    // don't do decoding when there are no 8bit symbols
-    if (! sq_is8bit($string,'us-ascii'))
+    global $default_charset;
+
+    if (strtolower($default_charset) == 'us-ascii')
         return $string;
 
-    $string = preg_replace("/([\201-\237])/","'?'",$string);
+    if (! ereg("[\200-\237]", $string) and ! ereg("[\241-\377]", $string) )
+        return $string;
+
+    $string = preg_replace("/([\201-\237])/e","'?'",$string);
 
     /* I don't want to use 0xA0 (\240) in any ranges. RH73 may dislike it */
     $string = str_replace("\240", '?', $string);
 
-    $string = preg_replace("/([\241-\377])/","'?'",$string);
+    $string = preg_replace("/([\241-\377])/e","'?'",$string);
     return $string;
 }
+?>
