@@ -3,31 +3,31 @@
 /**
  * file_prefs.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * This contains functions for manipulating user preferences in files
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: file_prefs.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: file_prefs.php,v 1.29 2003/10/28 21:27:46 tassium Exp $
  * @package squirrelmail
- * @subpackage prefs
- * @since 1.2.5
  */
 
+/** include this for error messages */
+include_once(SM_PATH . 'functions/display_messages.php');
+
 /**
  * Check the preferences into the session cache.
  */
 function cachePrefValues($data_dir, $username) {
     global $prefs_are_cached, $prefs_cache;
-
-    sqgetGlobalVar('prefs_are_cached', $prefs_are_cached, SQ_SESSION );
+       
     if ( isset($prefs_are_cached) && $prefs_are_cached) {
-        sqgetGlobalVar('prefs_cache', $prefs_cache, SQ_SESSION );
         return;
     }
-
+    
     sqsession_unregister('prefs_cache');
     sqsession_unregister('prefs_are_cached');
-
+    
     /* Calculate the filename for the user's preference file */
     $filename = getHashedFile($username, $data_dir, "$username.pref");
 
@@ -82,28 +82,24 @@ function cachePrefValues($data_dir, $username) {
     sqsession_register($prefs_cache, 'prefs_cache');
     sqsession_register($prefs_are_cached, 'prefs_are_cached');
 }
-
+   
 /**
  * Return the value for the preference given by $string.
  */
 function getPref($data_dir, $username, $string, $default = '') {
     global $prefs_cache;
 
-    $result = NULL;
-    $result = do_hook_function('get_pref_override',array($username, $string, $default, $data_dir));
-// FIXME: ideally, we'd have a better way to determine if the return value from the hook above should be respected, even if it is NULL, but this is as good as it gets for now... previously the test was more weak: if (!$result)
-    if (is_null($result)) {
-        cachePrefValues($data_dir, $username);
-        if (isset($prefs_cache[$string])) {
-            $result = $prefs_cache[$string];
-        } else {
-//FIXME: is there justification for having these TWO hooks so close together?  who uses these?
-            $result = do_hook_function('get_pref', array($username, $string));
-//FIXME: testing below for !$result means that a plugin cannot fetch its own pref value of 0, '0', '', FALSE, or anything else that evaluates to boolean FALSE.
-            if (!$result) {
-                $result = $default;
-            }
-        }
+    $result = do_hook_function('get_pref_override',array($username,$string));
+    if (!$result) {
+	cachePrefValues($data_dir, $username);
+	if (isset($prefs_cache[$string])) {
+    	    $result = $prefs_cache[$string];
+	} else {
+	    $result = do_hook_function('get_pref', array($username,$string));
+	    if (!$result) {	    
+    		$result = $default;
+	    }
+	}
     }
     return ($result);
 }
@@ -113,7 +109,7 @@ function getPref($data_dir, $username, $string, $default = '') {
  */
 function savePrefValues($data_dir, $username) {
     global $prefs_cache;
-
+   
     $filename = getHashedFile($username, $data_dir, "$username.pref");
 
     /* Open the file for writing, or else display an error to the user. */
@@ -124,7 +120,7 @@ function savePrefValues($data_dir, $username) {
     }
     foreach ($prefs_cache as $Key => $Value) {
         if (isset($Value)) {
-            if ( sq_fwrite($file, $Key . '=' . $Value . "\n") === FALSE ) {
+            if ( @fwrite($file, $Key . '=' . $Value . "\n") === FALSE ) {
                logout_error( sprintf( _("Preference file, %s, could not be written. Contact your system administrator to resolve this issue.") , $filename . '.tmp') );
                exit;
             }
@@ -147,11 +143,11 @@ function removePref($data_dir, $username, $string) {
     global $prefs_cache;
 
     cachePrefValues($data_dir, $username);
-
+ 
     if (isset($prefs_cache[$string])) {
         unset($prefs_cache[$string]);
     }
-
+ 
     savePrefValues($data_dir, $username);
 }
 
@@ -200,9 +196,9 @@ function checkForPrefs($data_dir, $username, $filename = '') {
         /* Otherwise, report an error. */
         $errTitle = sprintf( _("Error opening %s"), $default_pref );
         if (!is_readable($default_pref)) {
-            $errString = $errTitle . "<br />\n" .
-                         _("Default preference file not found or not readable!") . "<br />\n" .
-                         _("Please contact your system administrator and report this error.") . "<br />\n";
+            $errString = $errTitle . "<br>\n" .
+                         _("Default preference file not found or not readable!") . "<br>\n" .
+                         _("Please contact your system administrator and report this error.") . "<br>\n";
             logout_error( $errString, $errTitle );
             exit;
         } else if (!@copy($default_pref, $filename)) {
@@ -211,10 +207,10 @@ function checkForPrefs($data_dir, $username, $filename = '') {
                 $user_data = posix_getpwuid(posix_getuid());
                 $uid = $user_data['name'];
             }
-            $errString = $errTitle . '<br />' .
-                       _("Could not create initial preference file!") . "<br />\n" .
+            $errString = $errTitle . '<br>' .
+                       _("Could not create initial preference file!") . "<br>\n" .
                        sprintf( _("%s should be writable by user %s"), $data_dir, $uid ) .
-                       "<br />\n" . _("Please contact your system administrator and report this error.") . "<br />\n";
+                       "<br>\n" . _("Please contact your system administrator and report this error.") . "<br>\n";
             logout_error( $errString, $errTitle );
             exit;
         }
@@ -225,18 +221,13 @@ function checkForPrefs($data_dir, $username, $filename = '') {
  * Write the User Signature.
  */
 function setSig($data_dir, $username, $number, $value) {
-    // Limit signature size to 64KB (database BLOB limit)
-    if (strlen($value)>65536) {
-        error_option_save(_("Signature is too big."));
-        return;
-    }
     $filename = getHashedFile($username, $data_dir, "$username.si$number");
     /* Open the file for writing, or else display an error to the user. */
     if(!$file = @fopen("$filename.tmp", 'w')) {
         logout_error( sprintf( _("Signature file, %s, could not be opened. Contact your system administrator to resolve this issue."), $filename . '.tmp') );
         exit;
     }
-    if ( sq_fwrite($file, $value) === FALSE ) {
+    if ( @fwrite($file, $value) === FALSE ) {
        logout_error( sprintf( _("Signature file, %s, could not be written. Contact your system administrator to resolve this issue.") , $filename . '.tmp'));
        exit;
     }
@@ -270,4 +261,3 @@ function getSig($data_dir, $username, $number) {
     }
     return $sig;
 }
-
