@@ -3,23 +3,20 @@
 /**
  * html.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * The idea is to inlcude here some functions to make easier
  * the right to left implementation by "functionize" some
  * html outputs.
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: html.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: html.php,v 1.15 2003/10/28 21:27:46 tassium Exp $
  * @package squirrelmail
- * @since 1.3.0
  */
 
 /**
  * Generate html tags
  *
- * NOTE!  If $val is non-empty, a closing tag will be added after $val
- *        Otherwise, NO closing tag is provided!
- *
  * @param string $tag Tag to output
  * @param string $val Value between tags
  * @param string $align Alignment (left, center, etc)
@@ -54,7 +51,7 @@ function html_tag( $tag,                // Tag to output
         }
 
         if ( $bgcolor <> '' ) {
-            $bgc = " bgcolor=\"$bgcolor\"";
+            $bgc = " bgcolor=\"$bgcolor\""; 
         }
 
         switch ( $align ) {
@@ -84,95 +81,69 @@ function html_tag( $tag,                // Tag to output
         }
 
         if ( $val <> '' ) {
-            $ret .= ">$val</$tag>\n";
+            $ret .= ">$val</$tag>";
         } else {
-            $ret .= '>' . "\n";
-        }
+            $ret .= '>';
+        } 
 
         return( $ret );
     }
 
-/**
- * This function is used to add, modify or delete GET variables in a URL. 
- * It is especially useful when $url = $PHP_SELF
- *
- * Set $val to NULL to remove $var from $url.
- * To ensure compatibility with older versions, use $val='0' to set $var to 0. 
- *
- * @param string $url url that must be modified
- * @param string $var GET variable name
- * @param string $val variable value (CANNOT be an array)
- * @param boolean $link controls sanitizing of ampersand in urls (since 1.3.2)
- * @param boolean $treat_as_array When TRUE, if $var is an array (it occurs one
- *                                or more times with square brackets after it,
- *                                e.g. "var[1]"), the whole array will be removed
- *                                (when $val is NULL) or the given value will be
- *                                added to the next array slot (@since 1.4.23/1.5.2)
- *
- * @return string $url modified url
- *
- * @since 1.3.0
- *
- */
-function set_url_var($url, $var, $val=null, $link=true, $treat_as_array=false) {
-    $url = str_replace('&amp;','&',$url);
+    /* handy function to set url vars */
+    /* especially usefull when $url = $PHP_SELF */
+    function set_url_var($url, $var, $val=0, $link=true) {
+        $k = '';
+        $ret = '';
+        $pat_a = array (
+                       '/.+(\\&'.$var.')=(.*)\\&/AU',   /* in the middle */
+                       '/.+\\?('.$var.')=(.*\\&).+/AU', /* at front, more follow */
+                       '/.+(\\?'.$var.')=(.*)$/AU',     /* at front and only var */
+                       '/.+(\\&'.$var.')=(.*)$/AU'      /* at the end */
+                     );
+	preg_replace('/&amp;/','&',$url);	     
+        switch (true) {
+            case (preg_match($pat_a[0],$url,$regs)):
+                $k = $regs[1];
+                $v = $regs[2];
+                break;
+            case (preg_match($pat_a[1],$url,$regs)):
+                $k = $regs[1];
+                $v = $regs[2];
+                break;
+            case (preg_match($pat_a[2],$url,$regs)):
+                $k = $regs[1];
+                $v = $regs[2];
+                break;
+            case (preg_match($pat_a[3],$url,$regs)):
+                $k = $regs[1];
+                $v = $regs[2];
+                break;
+            default:
+                if ($val) {
+                    if (strpos($url,'?')) {
+                        $url .= "&$var=$val";
+                    } else {
+                        $url .= "?$var=$val";
+                    }
+                }
+                break;
+        }
 
-    if (strpos($url, '?') === false) {
-        $url .= '?';
-    }   
-
-    list($uri, $params) = explode('?', $url, 2);
-        
-    $newpar = array(); 
-    $params = explode('&', $params);
-    $array_names = array();
-   
-    foreach ($params as $p) {
-        if (trim($p)) {
-            $p = explode('=', $p);
-            $newpar[$p[0]] = (isset($p[1]) ? $p[1] : '');
-            if ($treat_as_array && preg_match('/(.*)\[(\d+)]$/', $p[0], $matches)) {
-               if (!isset($array_names[$matches[1]])) $array_names[$matches[1]] = array();
-               $array_names[$matches[1]][$matches[2]] = $p[1];
+        if ($k) {
+            if ($val) {
+                $rpl = "$k=$val";
+		if ($link) {
+		    $rpl = preg_replace('/&/','&amp;',$rpl);
+		}
+            } else {
+                $rpl = '';
             }
+            $pat = "/$k=$v/";
+            $url = preg_replace($pat,$rpl,$url);
         }
+        return $url;
     }
 
-    if (is_null($val)) {
-        if ($treat_as_array && !empty($array_names[$var])) {
-            foreach ($array_names[$var] as $key => $ignore)
-                unset($newpar[$var . '[' . $key . ']']);
-        } else {
-            unset($newpar[$var]);
-        }
-    } else {
-        if ($treat_as_array && !empty($array_names[$var])) {
-            $max_key = 0;
-            foreach ($array_names[$var] as $key => $ignore)
-                if ($key >= $max_key) $max_key = $key + 1;
-            $newpar[$var . '[' . $max_key . ']'] = $val;
-        } else {
-            $newpar[$var] = $val;
-        }
-    }
-
-    if (!count($newpar)) {
-        return $uri;
-    }
-   
-    $url = $uri . '?';
-    foreach ($newpar as $name => $value) {
-        $url .= "$name=$value&";
-    }
-     
-    $url = substr($url, 0, -1);
-    if ($link) {
-        $url = str_replace('&','&amp;',$url);
-    }
-    
-    return $url;
-}
-
     /* Temporary test function to proces template vars with formatting.
      * I use it for viewing the message_header (view_header.php) with
      * a sort of template.
@@ -180,7 +151,7 @@ function set_url_var($url, $var, $val=null, $link=true, $treat_as_array=false) {
     function echo_template_var($var, $format_ar = array() ) {
         $frm_last = count($format_ar) -1;
 
-        if (isset($format_ar[0])) echo $format_ar[0];
+        if (isset($format_ar[0])) echo $format_ar[0]; 
             $i = 1;
 
         switch (true) {
@@ -208,3 +179,4 @@ function set_url_var($url, $var, $val=null, $link=true, $treat_as_array=false) {
             echo $format_ar[$frm_last];
         }
     }
+?>
