@@ -3,13 +3,14 @@
 /**
  * plugin.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * This file provides the framework for a plugin architecture.
  *
  * Documentation on how to write plugins might show up some time.
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: plugin.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: plugin.php,v 1.33 2003/10/29 09:35:51 kink Exp $
  * @package squirrelmail
  */
 
@@ -67,23 +68,22 @@ function do_hook ($name) {
  * @return mixed the return value of the hook function
  */
 function do_hook_function($name,$parm=NULL) {
-    $return_value_variable_name = 'hook_return_value_' . $name;
-    global $squirrelmail_plugin_hooks, $$return_value_variable_name;
-    $$return_value_variable_name = NULL;
+    global $squirrelmail_plugin_hooks;
+    $ret = '';
 
     if (isset($squirrelmail_plugin_hooks[$name])
           && is_array($squirrelmail_plugin_hooks[$name])) {
         foreach ($squirrelmail_plugin_hooks[$name] as $function) {
             /* Add something to set correct gettext domain for plugin. */
             if (function_exists($function)) {
-                $$return_value_variable_name = $function($parm, $$return_value_variable_name);
+                $ret = $function($parm);
             }
         }
     }
 
     /* Variable-length argument lists have a slight problem when */
     /* passing values by reference. Pity. This is a workaround.  */
-    return $$return_value_variable_name;
+    return $ret;
 }
 
 /**
@@ -95,23 +95,22 @@ function do_hook_function($name,$parm=NULL) {
  * @return string a concatenation of the results of each plugin function
  */
 function concat_hook_function($name,$parm=NULL) {
-    $return_value_variable_name = 'hook_return_value_' . $name;
-    global $squirrelmail_plugin_hooks, $$return_value_variable_name;
-    $$return_value_variable_name = '';
+    global $squirrelmail_plugin_hooks;
+    $ret = '';
 
     if (isset($squirrelmail_plugin_hooks[$name])
           && is_array($squirrelmail_plugin_hooks[$name])) {
         foreach ($squirrelmail_plugin_hooks[$name] as $function) {
             /* Concatenate results from hook. */
             if (function_exists($function)) {
-                $$return_value_variable_name .= $function($parm, $$return_value_variable_name);
+                $ret .= $function($parm);
             }
         }
     }
 
     /* Variable-length argument lists have a slight problem when */
     /* passing values by reference. Pity. This is a workaround.  */
-    return $$return_value_variable_name;
+    return $ret;
 }
 
 /**
@@ -170,9 +169,7 @@ function boolean_hook_function($name,$parm=NULL,$priority=0,$tie=false) {
  * This function checks whether the user's USER_AGENT is known to
  * be broken. If so, returns true and the plugin is invisible to the
  * offending browser.
- * *** THIS IS A TEST FOR JAVASCRIPT SUPPORT ***
- * FIXME: This function needs to have its name changed!
- * FIXME: The test in this function is outdated - plenty more browsers support JavaScript, newer browser versions (Mozilla at least) exist, and moreover, we shouldn't be doing user-agent testing - should be trusting our $javascript_on global -- REMOVE THIS FUNCTION IF NOT BEING USED ANYWHERE ELSE
+ * This function needs to have its name changed!
  *
  * @return bool whether this browser properly supports JavaScript
  */
@@ -192,22 +189,11 @@ function soupNazi(){
 /*** MAIN PLUGIN LOADING CODE HERE ***/
 /*************************************/
 
-/* On startup, register all plugins configured for use. 
-   $plugins needs to be globalized because this file is
-   sometimes included inside function (non-global) scope,
-   such as for logout_error. */
-global $plugins;
+/* On startup, register all plugins configured for use. */
 if (isset($plugins) && is_array($plugins)) {
-    // turn on output buffering in order to prevent output of new lines
-    ob_start();
     foreach ($plugins as $name) {
         use_plugin($name);
     }
-    $output = trim(ob_get_contents());
-    ob_end_clean();
-    // if plugins output more than newlines and spacing, stop script execution.
-    if (!empty($output)) {
-        die($output);
-    }
 }
 
+?>
