@@ -3,37 +3,35 @@
 /**
  * prefs.php
  *
- * This contains functions for filebased user prefs locations
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: prefs.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * This contains functions for manipulating user preferences
+ *
+ * $Id: prefs.php,v 1.66 2004/01/02 16:58:04 avel Exp $
  * @package squirrelmail
- * @subpackage prefs
  */
 
 /** Include global.php */
 require_once(SM_PATH . 'functions/global.php');
-require_once(SM_PATH . 'functions/plugin.php');
-
-/** include this for error messages */
-include_once(SM_PATH . 'functions/display_messages.php');
 
 sqgetGlobalVar('prefs_cache', $prefs_cache, SQ_SESSION );
 sqgetGlobalVar('prefs_are_cached', $prefs_are_cached, SQ_SESSION );
 
 $rg = ini_get('register_globals');
 
+/* if php version >= 4.1 OR (4.0 AND $rg = off) */
 if ( !sqsession_is_registered('prefs_are_cached') ||
-     !isset($prefs_cache) ||
-     !is_array($prefs_cache)
+     !isset( $prefs_cache) ||
+     !is_array( $prefs_cache) ||
+     check_php_version(4,1) ||
+     empty($rg)
    ) {
     $prefs_are_cached = false;
     $prefs_cache = array();
 }
 
-$prefs_backend = do_hook_function('prefs_backend');
-if (isset($prefs_backend) && !empty($prefs_backend) && file_exists(SM_PATH . $prefs_backend)) {
+if (isset($prefs_backend) && file_exists(SM_PATH . $prefs_backend)) {
     require_once(SM_PATH . $prefs_backend);
 } elseif (isset($prefs_dsn) && !empty($prefs_dsn)) {
     require_once(SM_PATH . 'functions/db_prefs.php');
@@ -60,7 +58,7 @@ function getHashedFile($username, $dir, $datafile, $hash_search = true) {
     if (substr($dir, -1) == '/') {
         $dir = substr($dir, 0, strlen($dir) - 1);
     }
-
+    
     /* Compute the hash for this user and extract the hash directories. */
     $hash_dirs = computeHashDirs($username);
 
@@ -89,17 +87,14 @@ function getHashedFile($username, $dir, $datafile, $hash_search = true) {
             }
         }
     }
-
+     
     /* Return the full hashed datafile path. */
     return ($result);
 }
 
 /**
- * Helper function for getHashedFile(), given a username returns 
- * the hashed dir for that username.  
- *
- * NOTE that the hashed dir will be created if it doesn't 
- * already exist.
+ * Helper function for getHashedFile, given a username returns the hashed
+ * dir for that username.
  *
  * @param string username the username of the current user
  * @param string dir the squirrelmail datadir
@@ -113,7 +108,7 @@ function getHashedDir($username, $dir, $hash_dirs = '') {
     if (substr($dir, -1) == '/') {
         $dir = substr($dir, 0, strlen($dir) - 1);
     }
-
+    
     /* If necessary, populate the hash dir variable. */
     if ($hash_dirs == '') {
         $hash_dirs = computeHashDirs($username);
@@ -125,9 +120,9 @@ function getHashedDir($username, $dir, $hash_dirs = '') {
         $real_hash_dir .= '/' . $hash_dirs[$h];
         if (!@is_dir($real_hash_dir)) {
             if (!@mkdir($real_hash_dir, 0770)) {
-                echo sprintf(_("Error creating directory %s."), $real_hash_dir) . '<br />' .
-                     _("Could not create hashed directory structure!") . "<br />\n" .
-                     _("Please contact your system administrator and report this error.") . "<br />\n";
+                echo sprintf(_("Error creating directory %s."), $real_hash_dir) . '<br>' .
+                     _("Could not create hashed directory structure!") . "<br>\n" .
+                     _("Please contact your system administrator and report this error.") . "<br>\n";
                 exit;
             }
         }
@@ -140,68 +135,19 @@ function getHashedDir($username, $dir, $hash_dirs = '') {
 /**
  * Helper function for getHashDir which does the actual hash calculation.
  *
- * Uses a crc32 algorithm by default, but if you put
- * the following in config/config_local.php, you can
- * force md5 instead:
- *    $hash_dirs_use_md5 = TRUE;
- *
- * You may also specify that if usernames are in full
- * email address format, the domain part (beginning
- * with "@") be stripped before calculating the crc
- * or md5.  Do that by putting the following in
- * config/config_local.php:
- *    $hash_dirs_strip_domain = TRUE;
- *
  * @param string username the username to calculate the hash dir for
- *
  * @return array a list of hash dirs for this username
- *
- * @since 1.2.0
- *
  */
 function computeHashDirs($username) {
-
-    global $hash_dirs_use_md5, $hash_dirs_strip_domain;
-    static $hash_dirs = array();
-
-
-    // strip domain from username
-    if ($hash_dirs_strip_domain)
-        $user = substr($username, 0, strpos($username, '@'));
-    else
-        $user = $username;
-
-
-    // have we already calculated it?
-    if (!empty($hash_dirs[$user]))
-        return $hash_dirs[$user];
-
-
-    if ($hash_dirs_use_md5) {
-
-        $hash = md5($user);
-
-    } else {
-
-        /* Compute the hash for this user and extract the hash directories.  */
-        /* Note that the crc32() function result will be different on 32 and */
-        /* 64 bit systems, thus the hack below.                              */
-        $crc = crc32($user);
-        if ($crc & 0x80000000) {
-            $crc ^= 0xffffffff;
-            $crc += 1;
-        }
-        $hash = base_convert($crc, 10, 16);
-    }   
-
-
-    $my_hash_dirs = array();
+    /* Compute the hash for this user and extract the hash directories. */
+    $hash = base_convert(crc32($username), 10, 16);
+    $hash_dirs = array();
     for ($h = 0; $h < 4; ++ $h) {
-        $my_hash_dirs[] = substr($hash, $h, 1);
+        $hash_dirs[] = substr($hash, $h, 1);
     }
 
-    // Return our array of hash directories
-    $hash_dirs[$user] = $my_hash_dirs;
-    return ($my_hash_dirs);
+    /* Return our array of hash directories. */
+    return ($hash_dirs);
 }
 
+?>
