@@ -3,12 +3,13 @@
 /**
  * tree.php
  *
- * This file provides functions to walk trees of folders, for
- * instance to delete a whole tree.
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: tree.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * This code provides various string manipulation functions that are
+ * used by the rest of the Squirrelmail code.
+ *
+ * $Id: tree.php,v 1.28 2003/10/29 09:35:51 kink Exp $
  * @package squirrelmail
  */
 
@@ -134,18 +135,15 @@ function walkTreeInPreOrderDeleteFolders($index, $imap_stream, $tree) {
 function walkTreeInPostOrderCreatingFoldersUnderTrash($index, $imap_stream, $tree, $topFolderName) {
     global $trash_folder, $delimiter;
 
-    $position = strrpos($topFolderName, $delimiter);
-    if ($position !== FALSE) {
-        $position++;
-    }
+    $position = strrpos($topFolderName, $delimiter) + 1;
     $subFolderName = substr($tree[$index]['value'], $position);
 
     if ($tree[$index]['doIHaveChildren']) {
         sqimap_mailbox_create($imap_stream, $trash_folder . $delimiter . $subFolderName, "");
-        $mbx_response = sqimap_mailbox_select($imap_stream, $tree[$index]['value']);
+        $mbx_response = sqimap_mailbox_select($imap_stream, $tree[$index]['value']);	    
         $messageCount = $mbx_response['EXISTS'];
         if ($messageCount > 0) {
-            sqimap_msgs_list_copy($imap_stream, '1:*', $trash_folder . $delimiter . $subFolderName);
+            sqimap_messages_copy($imap_stream, 1, '*', $trash_folder . $delimiter . $subFolderName);
         }
         // after copy close the mailbox to get in unselected state
         sqimap_run_command($imap_stream,'CLOSE',false,$response,$message);
@@ -156,7 +154,7 @@ function walkTreeInPostOrderCreatingFoldersUnderTrash($index, $imap_stream, $tre
         $mbx_response = sqimap_mailbox_select($imap_stream, $tree[$index]['value']);
         $messageCount = $mbx_response['EXISTS'];
         if ($messageCount > 0) {
-            sqimap_msgs_list_copy($imap_stream, '1:*', $trash_folder . $delimiter . $subFolderName);
+            sqimap_messages_copy($imap_stream, 1, '*', $trash_folder . $delimiter . $subFolderName);
         }
         // after copy close the mailbox to get in unselected state
         sqimap_run_command($imap_stream,'CLOSE',false,$response,$message);
@@ -174,8 +172,9 @@ function simpleWalkTreePre($index, $tree) {
         for ($j = 0; $j < count($tree[$index]['subNodes']); $j++) {
             simpleWalkTreePre($tree[$index]['subNodes'][$j], $tree);
         }
-        echo $tree[$index]['value'] . '<br />';
+        echo $tree[$index]['value'] . '<br>';
     } else {
-        echo $tree[$index]['value'] . '<br />';
+        echo $tree[$index]['value'] . '<br>';
     }
 }
+?>
