@@ -3,20 +3,21 @@
 /**
  * load_prefs.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Loads preferences from the $username.pref file used by almost
  * every other script in the source directory and alswhere.
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: load_prefs.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: load_prefs.php,v 1.20 2003/10/28 21:30:54 tassium Exp $
  * @package squirrelmail
  */
 
 /** SquirrelMail required files. */
 require_once(SM_PATH . 'include/validate.php');
+require_once(SM_PATH . 'functions/prefs.php');
 require_once(SM_PATH . 'functions/plugin.php');
 require_once(SM_PATH . 'functions/constants.php');
-require_once(SM_PATH . 'functions/prefs.php');
 
 if( ! sqgetGlobalVar('username', $username, SQ_SESSION) ) {
     $username = '';
@@ -47,21 +48,20 @@ $chosen_theme = (!$found_theme ? '' : $chosen_theme);
 * were not found. This is the absolute last resort.
 * Moved here to provide 'sane' defaults for incomplete themes.
 */
-$color[0]  = '#DCDCDC';  /* light gray    TitleBar                */
-$color[1]  = '#800000';  /* red                                   */
-$color[2]  = '#CC0000';  /* light red     Warning/Error Messages  */
-$color[3]  = '#A0B8C8';  /* green-blue    Left Bar Background     */
-$color[4]  = '#FFFFFF';  /* white         Normal Background       */
-$color[5]  = '#FFFFCC';  /* light yellow  Table Headers           */
-$color[6]  = '#000000';  /* black         Text on left bar        */
-$color[7]  = '#0000CC';  /* blue          Links                   */
-$color[8]  = '#000000';  /* black         Normal text             */
-$color[9]  = '#ABABAB';  /* mid-gray      Darker version of #0    */
-$color[10] = '#666666';  /* dark gray     Darker version of #9    */
-$color[11] = '#770000';  /* dark red      Special Folders color   */
+$color[0]  = '#DCDCDC';  /* light gray    TitleBar               */
+$color[1]  = '#800000';  /* red                                  */
+$color[2]  = '#CC0000';  /* light red     Warning/Error Messages */
+$color[3]  = '#A0B8C8';  /* green-blue    Left Bar Background    */
+$color[4]  = '#FFFFFF';  /* white         Normal Background      */
+$color[5]  = '#FFFFCC';  /* light yellow  Table Headers          */
+$color[6]  = '#000000';  /* black         Text on left bar       */
+$color[7]  = '#0000CC';  /* blue          Links                  */
+$color[8]  = '#000000';  /* black         Normal text            */
+$color[9]  = '#ABABAB';  /* mid-gray      Darker version of #0   */
+$color[10] = '#666666';  /* dark gray     Darker version of #9   */
+$color[11] = '#770000';  /* dark red      Special Folders color  */
 $color[12] = '#EDEDED';
 $color[15] = '#002266';  /* (dark blue)      Unselectable folders */
-$color[16] = '#ff9933';  /* (orange)         Highlight color      */
 
 if (isset($chosen_theme) && $found_theme && (file_exists($chosen_theme))) {
     @include_once($chosen_theme);
@@ -73,11 +73,11 @@ if (isset($chosen_theme) && $found_theme && (file_exists($chosen_theme))) {
 }
 
 
-// "download_php" is found nowhere in the source - this must be some orphaned legacy code
-// if (!defined('download_php')) {
-    sqsession_register($theme_css, 'theme_css');
-// }
+if (!defined('download_php')) { 
+    sqsession_register($theme_css, 'theme_css'); 
+}
 
+$use_javascript_addr_book = getPref($data_dir, $username, 'use_javascript_addr_book', $default_use_javascript_addr_book);
 
 /* Load the user's special folder preferences */
 $move_to_sent =
@@ -87,11 +87,11 @@ $move_to_trash =
 $save_as_draft =
     getPref($data_dir, $username, 'save_as_draft', $default_save_as_draft);
 
-if ($default_unseen_type == '') {
-    $default_unseen_type = 1;
+if ($default_unseen_type == '') { 
+    $default_unseen_type = 1; 
 }
-if ($default_unseen_notify == '') {
-    $default_unseen_notify = 2;
+if ($default_unseen_notify == '') { 
+    $default_unseen_notify = 2; 
 }
 $unseen_type =
     getPref($data_dir, $username, 'unseen_type', $default_unseen_type);
@@ -143,7 +143,6 @@ if ($left_size == '') {
 }
 
 $editor_size = getPref($data_dir, $username, 'editor_size', 76 );
-$editor_height = getPref($data_dir, $username, 'editor_height', 20 );
 $use_signature = getPref($data_dir, $username, 'use_signature', SMPREF_OFF );
 $prefix_sig = getPref($data_dir, $username, 'prefix_sig');
 
@@ -157,20 +156,19 @@ $reply_citation_style =
 $reply_citation_start = getPref($data_dir, $username, 'reply_citation_start');
 $reply_citation_end = getPref($data_dir, $username, 'reply_citation_end');
 
-$body_quote = getPref($data_dir, $username, 'body_quote', '>');
-if ($body_quote == 'NONE') $body_quote = '';
+// who is using those darn block comments?  poo!
 
 // Load preference for cursor behavior for replies
 //
 $reply_focus = getPref($data_dir, $username, 'reply_focus', '');
 
 /* left refresh rate, strtolower makes 1.0.6 prefs compatible */
-$left_refresh = getPref($data_dir, $username, 'left_refresh', 600 );
+$left_refresh = getPref($data_dir, $username, 'left_refresh', SMPREF_NONE );
 $left_refresh = strtolower($left_refresh);
 
 $sort = getPref($data_dir, $username, 'sort', 6 );
 
-/* Load up the Signature file */
+/** Load up the Signature file **/
 $signature_abs = $signature = getSig($data_dir, $username, 'g');
 
 /* Message Highlighting Rules */
@@ -189,7 +187,6 @@ if( $ser = getPref($data_dir, $username, 'hililist') ) {
         $message_highlight_list[$i]['match_type'] = $highlight_array[3];
         removePref($data_dir, $username, "highlight$i");
     }
-// NB: The fact that this preference is always set here means that some plugins rely on testing it to know if a user has logged in before - the "old way" above is probably long since obsolete and unneeded, but the setPref() below should not be removed
     /* store in new format for the next time */
     setPref($data_dir, $username, 'hililist', serialize($message_highlight_list));
 }
@@ -211,7 +208,8 @@ if (!isset($index_order)) {
 $alt_index_colors =
     getPref($data_dir, $username, 'alt_index_colors', SMPREF_ON );
 
-// Folder List Display Format 
+/* Folder List Display Format */
+$use_javascript_folder_list = getPref($data_dir, $username, 'use_javascript_folder_list');
 $location_of_bar =
     getPref($data_dir, $username, 'location_of_bar', SMPREF_LOC_LEFT);
 $location_of_buttons =
@@ -223,9 +221,6 @@ $collapse_folders =
 $show_html_default =
    getPref($data_dir, $username, 'show_html_default', SMPREF_OFF);
 
-$addrsrch_fullname =
-   getPref($data_dir, $username, 'addrsrch_fullname', 'fullname');
-
 $enable_forward_as_attachment =
    getPref($data_dir, $username, 'enable_forward_as_attachment', SMPREF_ON);
 
@@ -237,22 +232,15 @@ $pf_cleandisplay = getPref($data_dir, $username, 'pf_cleandisplay', SMPREF_OFF);
 /* message disposition notification support setting */
 $mdn_user_support = getPref($data_dir, $username, 'mdn_user_support', SMPREF_ON);
 
-$do_not_reply_to_self =
-    getPref($data_dir, $username, 'do_not_reply_to_self', SMPREF_OFF);
-
 $include_self_reply_all =
     getPref($data_dir, $username, 'include_self_reply_all', SMPREF_ON);
 
-$return_to_message_after_reply =
-    getPref($data_dir, $username, 'return_to_message_after_reply', SMPREF_OFF);
-
-/* Page selector options */
 $page_selector = getPref($data_dir, $username, 'page_selector', SMPREF_ON);
 $page_selector_max = getPref($data_dir, $username, 'page_selector_max', 10);
 
 /* SqClock now in the core */
 $date_format = getPref($data_dir, $username, 'date_format', 3);
-$hour_format = getPref($data_dir, $username, 'hour_format', SMPREF_TIME_12HR);
+$hour_format = getPref($data_dir, $username, 'hour_format', 2);
 
 /*  compose in new window setting */
 $compose_new_win = getPref($data_dir, $username, 'compose_new_win', 0);
@@ -263,7 +251,7 @@ $compose_width = getPref($data_dir, $username, 'compose_width', 640);
 /* signature placement settings */
 $sig_first = getPref($data_dir, $username, 'sig_first', 0);
 
-/* strip signature from replies setting */
+/* Strip signature when replying */
 $strip_sigs = getPref($data_dir, $username, 'strip_sigs', 0);
 
 /* use the internal date of the message for sorting instead of the supplied header date */
@@ -273,22 +261,28 @@ $internal_date_sort = getPref($data_dir, $username, 'internal_date_sort', SMPREF
 $sort_by_ref = getPref($data_dir, $username, 'sort_by_ref', 1);
 
 /* Load the javascript settings. */
-$javascript_setting = getPref($data_dir, $username, 'javascript_setting', SMPREF_JS_AUTODETECT);
+$javascript_setting =
+    getPref($data_dir, $username, 'javascript_setting', SMPREF_JS_AUTODETECT);
 $javascript_on = getPref($data_dir, $username, 'javascript_on', SMPREF_ON);
-$use_javascript_addr_book = getPref($data_dir, $username, 'use_javascript_addr_book', $default_use_javascript_addr_book);
+
 
 $search_memory = getPref($data_dir, $username, 'search_memory', 0);
 
-$mailbox_select_style = getPref($data_dir, $username, 'mailbox_select_style', 1);
+$forward_cc = getPref($data_dir, $username, 'forward_cc', 0);
+
+$mailbox_select_style = getPref($data_dir, $username, 'mailbox_select_style', 0);
 
 /* Allow user to customize, and display the full date, instead of day, or time based
    on time distance from date of message */
 $show_full_date = getPref($data_dir, $username, 'show_full_date', 0);
 
 /* Allow user to customize length of from field */
-$truncate_sender = getPref($data_dir, $username, 'truncate_sender', 50);
+$truncate_sender = getPref($data_dir, $username, 'truncate_sender', 0);
 /* Allow user to customize length of subject field */
 $truncate_subject = getPref($data_dir, $username, 'truncate_subject', 50);
+/* Allow user to show recipient name if the message is from default identity */
+$show_recipient_instead = getPref($data_dir, $username, 'show_recipient_instead', 0);
 
 do_hook('loading_prefs');
 
+?>
