@@ -3,11 +3,12 @@
 /**
  * options_display.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Displays all optinos about display preferences
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: display.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: display.php,v 1.19 2004/01/28 04:10:26 ebullient Exp $
  * @package squirrelmail
  */
 
@@ -32,7 +33,7 @@ define('SMOPT_GRP_MESSAGE', 2);
 function load_optpage_data_display() {
     global $theme, $language, $languages, $js_autodetect_results,
     $compose_new_win, $default_use_mdn, $squirrelmail_language, $allow_thread_sort,
-    $optmode;
+    $optmode, $show_alternative_names, $available_languages;
 
     /* Build a simple array into which we will build options. */
     $optgrps = array();
@@ -61,22 +62,18 @@ function load_optpage_data_display() {
         'posvals' => $theme_values,
         'save'    => 'save_option_theme'
     );
-
+ 
     $css_values = array( 'none' => _("Default" ) );
-    $css_dir = SM_PATH . 'themes/css';
-    if (is_readable($css_dir) && is_dir($css_dir)) {
-        $handle=opendir($css_dir);
-        while ($file = readdir($handle) ) {
-            if ( substr( $file, -4 ) == '.css' ) {
-                $css_values[$file] = substr( $file, 0, strlen( $file ) - 4 );
-            }
+    $handle=opendir('../themes/css/');
+    while ($file = readdir($handle) ) {
+        if ( substr( $file, -4 ) == '.css' ) {
+            $css_values[$file] = substr( $file, 0, strlen( $file ) - 4 );
         }
-        closedir($handle);
     }
-
-    asort($css_values);
+    closedir($handle);
+    
     if ( count( $css_values ) > 1 ) {
-
+    
         $optvals[SMOPT_GRP_GENERAL][] = array(
             'name'    => 'custom_css',
             'caption' => _("Custom Stylesheet"),
@@ -84,28 +81,53 @@ function load_optpage_data_display() {
             'refresh' => SMOPT_REFRESH_ALL,
             'posvals' => $css_values
         );
-
+    
     }
 
+    // config.php can be unupdated.
+    if (! isset($available_languages) || $available_languages=="" ) {
+     $available_languages="ALL"; }
+    
     $language_values = array();
-    foreach ($languages as $lang_key => $lang_attributes) {
-        if (isset($lang_attributes['NAME'])) {
-            $language_values[$lang_key] = $lang_attributes['NAME'];
-        }
+    if ( strtoupper($available_languages)=='ALL') {
+	foreach ($languages as $lang_key => $lang_attributes) {
+    	    if (isset($lang_attributes['NAME'])) {
+        	$language_values[$lang_key] = $lang_attributes['NAME'];
+		if ( isset($show_alternative_names) &&
+		  $show_alternative_names &&
+		  isset($lang_attributes['ALTNAME']) ) {
+		    $language_values[$lang_key] .= " / " . $lang_attributes['ALTNAME'];
+		}
+    	    }
+	}
+    } else if (strtoupper($available_languages)!='NONE') {
+	// admin can set list of available languages in config
+	$available_languages_array=explode (" ",$available_languages);
+        foreach ($available_languages_array as $lang_key ) {
+    	    if (isset($languages[$lang_key]['NAME'])) {
+        	$language_values[$lang_key] = $languages[$lang_key]['NAME'];
+    		if ( isset($show_alternative_names) &&
+		 $show_alternative_names &&
+		 isset($languages[$lang_key]['ALTNAME']) ) {
+    		    $language_values[$lang_key] .= " / " . $languages[$lang_key]['ALTNAME'];
+        	}
+    	    }	    
+	}
     }
-
     asort($language_values);
     $language_values =
         array_merge(array('' => _("Default")), $language_values);
     $language = $squirrelmail_language;
-    $optvals[SMOPT_GRP_GENERAL][] = array(
-        'name'    => 'language',
-        'caption' => _("Language"),
-        'type'    => SMOPT_TYPE_STRLIST,
-        'refresh' => SMOPT_REFRESH_ALL,
-        'posvals' => $language_values,
-        'htmlencoded' => true
-    );
+    if (strtoupper($available_languages)!='NONE') {
+	// if set to 'none', interface will use only default language
+	$optvals[SMOPT_GRP_GENERAL][] = array(
+    	    'name'    => 'language',
+    	    'caption' => _("Language"),
+    	    'type'    => SMOPT_TYPE_STRLIST,
+    	    'refresh' => SMOPT_REFRESH_ALL,
+    	    'posvals' => $language_values
+	);
+    }
 
     /* Set values for the "use javascript" option. */
     $optvals[SMOPT_GRP_GENERAL][] = array(
@@ -118,9 +140,9 @@ function load_optpage_data_display() {
                            SMPREF_JS_OFF        => _("Never"))
     );
 
+
     if ($optmode != 'submit')
-       // FIXME: our form is named "f" - why? let's use something better
-       $onLoadScript = 'document.f.new_js_autodetect_results.value = \'' . SMPREF_JS_ON . '\'';
+       $onLoadScript = 'document.forms[0].new_js_autodetect_results.value = \'' . SMPREF_JS_ON . '\'';
     else
        $onLoadScript = '';
 
@@ -139,7 +161,7 @@ function load_optpage_data_display() {
 
     $optvals[SMOPT_GRP_MAILBOX][] = array(
         'name'    => 'show_num',
-        'caption' => _("Number of Messages per Page"),
+        'caption' => _("Number of Messages to Index"),
         'type'    => SMOPT_TYPE_INTEGER,
         'refresh' => SMOPT_REFRESH_NONE,
         'size'    => SMOPT_SIZE_TINY
@@ -179,8 +201,7 @@ function load_optpage_data_display() {
         'caption' => _("Length of From/To Field (0 for full)"),
         'type'    => SMOPT_TYPE_INTEGER,
         'refresh' => SMOPT_REFRESH_NONE,
-        'size'    => SMOPT_SIZE_TINY,
-        'initial_value' => 55
+        'size'    => SMOPT_SIZE_TINY
     );
 
     $optvals[SMOPT_GRP_MAILBOX][] = array(
@@ -188,10 +209,18 @@ function load_optpage_data_display() {
         'caption' => _("Length of Subject Field (0 for full)"),
         'type'    => SMOPT_TYPE_INTEGER,
         'refresh' => SMOPT_REFRESH_NONE,
-        'size'    => SMOPT_SIZE_TINY,
-        'initial_value' => 55
+        'size'    => SMOPT_SIZE_TINY
     );
 
+    $optvals[SMOPT_GRP_MAILBOX][] = array(
+        'name'    => 'show_recipient_instead',
+        'caption' => _("Show recipient name if the message is from your default identity"),
+        'type'    => SMOPT_TYPE_BOOLEAN,
+        'refresh' => SMOPT_REFRESH_NONE,
+        'size'    => SMOPT_SIZE_TINY
+    );
+
+
     /*** Load the General Options into the array ***/
     $optgrps[SMOPT_GRP_MESSAGE] = _("Message Display and Composition");
     $optvals[SMOPT_GRP_MESSAGE] = array();
@@ -206,15 +235,7 @@ function load_optpage_data_display() {
 
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'editor_size',
-        'caption' => _("Width of Editor Window"),
-        'type'    => SMOPT_TYPE_INTEGER,
-        'refresh' => SMOPT_REFRESH_NONE,
-        'size'    => SMOPT_SIZE_TINY
-    );
-
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'editor_height',
-        'caption' => _("Height of Editor Window"),
+        'caption' => _("Size of Editor Window"),
         'type'    => SMOPT_TYPE_INTEGER,
         'refresh' => SMOPT_REFRESH_NONE,
         'size'    => SMOPT_SIZE_TINY
@@ -233,23 +254,13 @@ function load_optpage_data_display() {
 
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'use_javascript_addr_book',
-        'caption' => _("Address Book Display Format"),
+        'caption' => _("Addressbook Display Format"),
         'type'    => SMOPT_TYPE_STRLIST,
         'refresh' => SMOPT_REFRESH_NONE,
         'posvals' => array('1' => _("Javascript"),
                            '0' => _("HTML"))
     );
 
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'addrsrch_fullname',
-        'caption' => _("Format of Addresses Added From Address Book"),
-        'type'    => SMOPT_TYPE_STRLIST,
-        'refresh' => SMOPT_REFRESH_NONE,
-        'posvals' => array('noprefix' => _("No prefix/Address only"),
-                           'nickname' => _("Nickname and address"),
-                           'fullname' => _("Full name and address"))
-    );
-
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'show_html_default',
         'caption' => _("Show HTML Version by Default"),
@@ -265,8 +276,8 @@ function load_optpage_data_display() {
     );
 
     $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'do_not_reply_to_self',
-        'caption' => _("Send Replies To My Own Messages To Previous Recipient"),
+        'name'    => 'forward_cc',
+        'caption' => _("Include CCs when Forwarding Messages"),
         'type'    => SMOPT_TYPE_BOOLEAN,
         'refresh' => SMOPT_REFRESH_NONE
     );
@@ -278,13 +289,6 @@ function load_optpage_data_display() {
         'refresh' => SMOPT_REFRESH_NONE
     );
 
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'return_to_message_after_reply',
-        'caption' => _("Return to Original Message After Replying"),
-        'type'    => SMOPT_TYPE_BOOLEAN,
-        'refresh' => SMOPT_REFRESH_NONE
-    );
-
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'show_xmailer_default',
         'caption' => _("Enable Mailer Display"),
@@ -340,11 +344,21 @@ function load_optpage_data_display() {
 
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'sig_first',
-        'caption' => _("Prepend Signature before Reply/Forward Text"),
+        'caption' => _("Append Signature before Reply/Forward Text"),
         'type'    => SMOPT_TYPE_BOOLEAN,
         'refresh' => SMOPT_REFRESH_NONE
     );
 
+    $optvals[SMOPT_GRP_MESSAGE][] = array(
+        'name'    => 'reply_focus',
+        'caption' => _("Cursor Position when Replying"),
+        'type'    => SMOPT_TYPE_STRLIST,
+        'refresh' => SMOPT_REFRESH_NONE,
+        'posvals' => array('' => _("To: field"),
+                           'focus' => _("Focus in body"),
+                           'select' => _("Select body"))
+    );
+
     $optvals[SMOPT_GRP_MESSAGE][] = array(
         'name'    => 'strip_sigs',
         'caption' => _("Strip signature when replying"),
@@ -353,31 +367,10 @@ function load_optpage_data_display() {
     );
 
     $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'body_quote',
-        'caption' => _("Prefix for Original Message when Replying"),
-        'type'    => SMOPT_TYPE_STRING,
-        'refresh' => SMOPT_REFRESH_NONE,
-        'size'    => SMOPT_SIZE_TINY,
-        'save'    => 'save_option_reply_prefix'
-    );
-
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'    => 'reply_focus',
-        'caption' => _("Cursor Position when Replying"),
-        'type'    => SMOPT_TYPE_STRLIST,
-        'refresh' => SMOPT_REFRESH_NONE,
-        'posvals' => array('' => _("To: field"),
-                           'focus' => _("Focus in body"),
-                           'select' => _("Select body"),
-                           'none' => _("No focus"))
-    );
-
-    $optvals[SMOPT_GRP_MESSAGE][] = array(
-        'name'          => 'internal_date_sort',
-        'caption'       => _("Sort by Received Date"),
-        'type'          => SMOPT_TYPE_BOOLEAN,
-        'refresh'       => SMOPT_REFRESH_ALL,
-        'initial_value' => SMPREF_ON
+        'name'    => 'internal_date_sort',
+        'caption' => _("Enable Sort by of Receive Date"),
+        'type'    => SMOPT_TYPE_BOOLEAN,
+        'refresh' => SMOPT_REFRESH_ALL
     );
     if ($allow_thread_sort == TRUE) {
         $optvals[SMOPT_GRP_MESSAGE][] = array(
@@ -386,6 +379,13 @@ function load_optpage_data_display() {
             'type'    => SMOPT_TYPE_BOOLEAN,
             'refresh' => SMOPT_REFRESH_ALL
         );
+    $optvals[SMOPT_GRP_MESSAGE][] = array(
+        'name'    => 'delete_prev_next_display',
+        'caption' => _("Show 'Delete & Prev/Next' Links"),
+        'type'    => SMOPT_TYPE_BOOLEAN,
+        'refresh' => SMOPT_REFRESH_ALL
+    );
+        
     }
     /* Assemble all this together and return it as our result. */
     $result = array(
@@ -428,11 +428,9 @@ function save_option_theme($option) {
  * This function saves the javascript detection option.
  */
 function save_option_javascript_autodetect($option) {
-    global $data_dir, $username;
+    global $data_dir, $username, $new_javascript_setting;
 
-    sqGetGlobalVar('new_javascript_setting', $new_javascript_setting);
-
-    // Set javascript either on or off.
+    /* Set javascript either on or off. */
     if ($new_javascript_setting == SMPREF_JS_AUTODETECT) {
         if ($option->new_value == SMPREF_JS_ON) {
             setPref($data_dir, $username, 'javascript_on', SMPREF_JS_ON);
@@ -444,17 +442,4 @@ function save_option_javascript_autodetect($option) {
     }
 }
 
-function save_option_reply_prefix($option) {
-    global $data_dir, $username, $new_javascript_setting;
-
-    // save as "NONE" if it was blanked out
-    //
-    if (empty($option->new_value)) $option->new_value = 'NONE';
-
-
-    // Save the option like normal.
-    //
-    save_option($option);
-
-}
-
+?>
