@@ -3,11 +3,12 @@
 /**
  * options_folder.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Displays all options relating to folders
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: folder.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: folder.php,v 1.11 2004/01/31 17:45:39 braverock Exp $
  * @package squirrelmail
  */
 
@@ -34,12 +35,12 @@ define('SMOPT_GRP_FOLDERSELECT', 2);
  * @return array all option information
  */
 function load_optpage_data_folder() {
-    global $username, $key, $imapServerAddress, $imapPort, $imap_stream_options;
+    global $username, $key, $imapServerAddress, $imapPort;
     global $folder_prefix, $default_folder_prefix, $show_prefix_option;
 
     /* Get some imap data we need later. */
     $imapConnection =
-        sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
+        sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
     $boxes = sqimap_mailbox_list($imapConnection);
 
     /* Build a simple array into which we will build options. */
@@ -98,6 +99,13 @@ function load_optpage_data_folder() {
         'save'    => 'save_option_sent_folder'
     );
 
+    $optvals[SMOPT_GRP_SPCFOLDER][] = array(
+        'name'    => 'save_reply_with_orig',
+        'caption' => _("Save Replies with Original Message"),
+        'type'    => SMOPT_TYPE_BOOLEAN,
+        'refresh' => SMOPT_REFRESH_FOLDERLIST
+    );
+
     /*** Load the General Options into the array ***/
     $optgrps[SMOPT_GRP_FOLDERLIST] = _("Folder List Options");
     $optvals[SMOPT_GRP_FOLDERLIST] = array();
@@ -125,7 +133,7 @@ function load_optpage_data_folder() {
 
     $minute_str = _("Minutes");
     $left_refresh_values = array(SMPREF_NONE => _("Never"));
-    foreach (array(30,60,120,180,300,600,1200) as $lr_val) {
+    foreach (array(30,60,120,180,300,600) as $lr_val) {
         if ($lr_val < 60) {
             $left_refresh_values[$lr_val] = "$lr_val " . _("Seconds");
         } else if ($lr_val == 60) {
@@ -181,9 +189,8 @@ function load_optpage_data_folder() {
         'caption' => _("Show Clock on Folders Panel"),
         'type'    => SMOPT_TYPE_STRLIST,
         'refresh' => SMOPT_REFRESH_FOLDERLIST,
-        'posvals' => array( '0' => _("International date and time"),
-                            '1' => _("American date and time"),
-                            '2' => _("European date and time"),
+        'posvals' => array( '1' => 'MM/DD/YY HH:MM',
+                            '2' => 'DD/MM/YY HH:MM',
                             '3' => _("Show weekday and time"),
                             '4' => _("Show time with seconds"),
                             '5' => _("Show time"),
@@ -227,10 +234,9 @@ function load_optpage_data_folder() {
         'caption' => _("Selection List Style"),
         'type'    => SMOPT_TYPE_STRLIST,
         'refresh' => SMOPT_REFRESH_NONE,
-        'posvals' => array( 0 => _("Long:") . ' "' . _("Folder") . $delim . _("Subfolder") . '"',
-                            1 => _("Indented:") . ' "&nbsp;&nbsp;&nbsp;&nbsp;' . _("Subfolder") . '"',
-                            2 => _("Delimited:") . ' ".&nbsp;' . _("Subfolder") . '"'),
-        'htmlencoded' => true
+        'posvals' => array( 0 => _("Long: ") . '"' . _("Folder") . $delim . _("Subfolder") . '"',
+                            1 => _("Indented: ") .  '"&nbsp;&nbsp;&nbsp;&nbsp;' . _("Subfolder") . '"',
+                            2 => _("Delimited: ") . '".&nbsp;' . _("Subfolder") . '"')
     );
 
     /* Assemble all this together and return it as our result. */
@@ -248,64 +254,44 @@ function load_optpage_data_folder() {
 
 /**
  * Saves the trash folder option.
- * @param object $option SquirrelOption object
- * @since 1.3.2
  */
 function save_option_trash_folder($option) {
     global $data_dir, $username;
 
-    if (strtolower($option->new_value)=='inbox') {
-        // make sure that it is not INBOX
-        error_option_save(_("You can't select INBOX as Trash folder."));
-    } else {
-        /* Set move to trash on or off. */
-        $trash_on = ($option->new_value == SMPREF_NONE ? SMPREF_OFF : SMPREF_ON);
-        setPref($data_dir, $username, 'move_to_trash', $trash_on);
+    /* Set move to trash on or off. */
+    $trash_on = ($option->new_value == SMPREF_NONE ? SMPREF_OFF : SMPREF_ON);
+    setPref($data_dir, $username, 'move_to_trash', $trash_on);
 
-        /* Now just save the option as normal. */
-        save_option($option);
-    }
+    /* Now just save the option as normal. */
+    save_option($option);
 }
 
 /**
  * Saves the sent folder option.
- * @param object $option SquirrelOption object
- * @since 1.3.2
  */
 function save_option_sent_folder($option) {
     global $data_dir, $username;
 
-    if (strtolower($option->new_value)=='inbox') {
-        // make sure that it is not INBOX
-        error_option_save(_("You can't select INBOX as Sent folder."));
-    } else {
-        /* Set move to sent on or off. */
-        $sent_on = ($option->new_value == SMPREF_NONE ? SMPREF_OFF : SMPREF_ON);
-        setPref($data_dir, $username, 'move_to_sent', $sent_on);
+    /* Set move to sent on or off. */
+    $sent_on = ($option->new_value == SMPREF_NONE ? SMPREF_OFF : SMPREF_ON);
+    setPref($data_dir, $username, 'move_to_sent', $sent_on);
 
-        /* Now just save the option as normal. */
-        save_option($option);
-    }
+    /* Now just save the option as normal. */
+    save_option($option);
 }
 
 /**
  * Saves the draft folder option.
- * @param object $option SquirrelOption object
- * @since 1.3.2
  */
 function save_option_draft_folder($option) {
     global $data_dir, $username;
 
-    if (strtolower($option->new_value)=='inbox') {
-        // make sure that it is not INBOX
-        error_option_save(_("You can't select INBOX as Draft folder."));
-    } else {
-        /* Set move to draft on or off. */
-        $draft_on = ($option->new_value == SMPREF_NONE ? SMPREF_OFF : SMPREF_ON);
-        setPref($data_dir, $username, 'save_as_draft', $draft_on);
+    /* Set move to draft on or off. */
+    $draft_on = ($option->new_value == SMPREF_NONE ? SMPREF_OFF : SMPREF_ON);
+    setPref($data_dir, $username, 'save_as_draft', $draft_on);
 
-        /* Now just save the option as normal. */
-        save_option($option);
-    }
+    /* Now just save the option as normal. */
+    save_option($option);
 }
 
+?>
