@@ -3,11 +3,12 @@
 /**
  * options_personal.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Displays all options relating to personal information
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: personal.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: personal.php,v 1.10 2003/10/29 19:58:06 kink Exp $
  * @package squirrelmail
  */
 
@@ -34,7 +35,7 @@ define('SMOPT_GRP_TZ', 3);
  * @return array all option information
  */
 function load_optpage_data_personal() {
-    global $data_dir, $username, $edit_identity, $edit_name, $edit_reply_to,
+    global $data_dir, $username, $edit_identity, $edit_name,
            $full_name, $reply_to, $email_address, $signature, $tzChangeAllowed,
            $color;
 
@@ -84,7 +85,7 @@ function load_optpage_data_personal() {
     if ($edit_identity) {
         $optvals[SMOPT_GRP_CONTACT][] = array(
             'name'    => 'email_address',
-            'caption' => _("E-mail Address"),
+            'caption' => _("Email Address"),
             'type'    => SMOPT_TYPE_STRING,
             'refresh' => SMOPT_REFRESH_NONE,
             'size'    => SMOPT_SIZE_HUGE
@@ -92,33 +93,20 @@ function load_optpage_data_personal() {
     } else {
         $optvals[SMOPT_GRP_CONTACT][] = array(
             'name'    => 'email_address',
-            'caption' => _("E-mail Address"),
+            'caption' => _("Email Address"),
             'type'    => SMOPT_TYPE_COMMENT,
             'refresh' => SMOPT_REFRESH_NONE,
             'comment' => $email_address
         );
     }
 
-    if ($edit_identity || $edit_reply_to) {
-        $optvals[SMOPT_GRP_CONTACT][] = array(
-            'name'    => 'reply_to',
-            'caption' => _("Reply To"),
-            'type'    => SMOPT_TYPE_STRING,
-            'refresh' => SMOPT_REFRESH_NONE,
-            'size'    => SMOPT_SIZE_HUGE
-        );
-    } else {
-//TODO: For many users, this is redundant to the email address above, especially if not editable -- so here instead of a comment, we could just hide it... in fact, that's what we'll do, but keep this code for posterity in case someone decides we shouldn't do this
-/*
-        $optvals[SMOPT_GRP_CONTACT][] = array(
-            'name'    => 'reply_to',
-            'caption' => _("Reply To"),
-            'type'    => SMOPT_TYPE_COMMENT,
-            'refresh' => SMOPT_REFRESH_NONE,
-            'comment' => $reply_to,
-        );
-*/
-    }
+    $optvals[SMOPT_GRP_CONTACT][] = array(
+        'name'    => 'reply_to',
+        'caption' => _("Reply To"),
+        'type'    => SMOPT_TYPE_STRING,
+        'refresh' => SMOPT_REFRESH_NONE,
+        'size'    => SMOPT_SIZE_HUGE
+    );
 
     $optvals[SMOPT_GRP_CONTACT][] = array(
         'name'    => 'signature',
@@ -129,11 +117,10 @@ function load_optpage_data_personal() {
         'save'    => 'save_option_signature'
     );
 
-    $identities_count = getPref($data_dir, $username, 'identities', 0);
-    if ($identities_count > 1 || $edit_identity) {
-        $identities_link_value = '<a href="options_identities.php">'
+    if ($edit_identity) {
+        $identities_link_value = '<A HREF="options_identities.php">'
                                . _("Edit Advanced Identities")
-                               . '</a> '
+                               . '</A> '
                                . _("(discards changes made on this form so far)");
         $optvals[SMOPT_GRP_CONTACT][] = array(
             'name'    => 'identities_link',
@@ -143,19 +130,17 @@ function load_optpage_data_personal() {
             'comment' =>  $identities_link_value
         );
     }
-
-    if ( $tzChangeAllowed || function_exists('date_default_timezone_set')) {
+    
+    if ( $tzChangeAllowed ) {
         $TZ_ARRAY[SMPREF_NONE] = _("Same as server");
         $tzfile = SM_PATH . 'locale/timezones.cfg';
-        if ((!is_readable($tzfile)) or (!$fd = fopen($tzfile,'r'))) {
-            $message = _("Error opening timezone config, contact administrator.");
-        }
-
-        // TODO: make error user friendly
-        if (isset($message)) {
-            plain_error_message($message, $color);
-            exit;
-        }
+		if ((!is_readable($tzfile)) or (!$fd = fopen($tzfile,'r'))) {
+        	$message = _("Error opening timezone config, contact administrator.");
+		}
+		if (isset($message)) {
+	            plain_error_message($message, $color);
+	            exit;
+    	}
         while (!feof ($fd)) {
             $zone = fgets($fd, 1024);
             if( $zone ) {
@@ -176,7 +161,7 @@ function load_optpage_data_personal() {
             'posvals' => $TZ_ARRAY
         );
     }
-
+    
     /*** Load the Reply Citation Options into the array ***/
     $optgrps[SMOPT_GRP_REPLY] = _("Reply Citation Options");
     $optvals[SMOPT_GRP_REPLY] = array();
@@ -187,8 +172,7 @@ function load_optpage_data_personal() {
         'type'    => SMOPT_TYPE_STRLIST,
         'refresh' => SMOPT_REFRESH_NONE,
         'posvals' => array(SMPREF_NONE    => _("No Citation"),
-                           'author_said'  => _("AUTHOR Wrote"),
-                           'date_time_author' => _("On DATE, AUTHOR Wrote"),
+                           'author_said'  => _("AUTHOR Said"),
                            'quote_who'    => _("Quote Who XML"),
                            'user-defined' => _("User-Defined"))
     );
@@ -247,3 +231,4 @@ function save_option_signature($option) {
     setSig($data_dir, $username, 'g', $option->new_value);
 }
 
+?>
