@@ -1,12 +1,14 @@
-<?php
+<?PHP
 
 /**
- * Administrator plugin - Option definitions
+ * defines.php
  *
- * @author Philippe Mingo
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: defines.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
+ * Philippe Mingo
+ *
+ * $Id: defines.php,v 1.35 2003/12/26 09:13:37 tokul Exp $
  * @package plugins
  * @subpackage administrator
  */
@@ -50,7 +52,7 @@ for ($lsv = 100; $lsv <= 300; $lsv += 10) {
 $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                              'type' => SMOPT_TYPE_COMMENT,
                                              'size' => 7 ),
-                 'SM_ver' => array( 'name' => _("SquirrelMail Version"),
+                 'SM_ver' => array( 'name' => _("Squirrelmail Version"),
                                     'type' => SMOPT_TYPE_EXTERNAL,
                                     'value' => "$version" ),
                  'PHP_ver' => array( 'name' => _("PHP Version"),
@@ -65,13 +67,13 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                  '$org_logo' => array( 'name' => _("Organization Logo"),
                                        'type' => SMOPT_TYPE_PATH,
                                        'size' => 40,
-                                       'default' => '../images/sm_logo.png'),
+				       'default' => '../images/sm_logo.png'),
                  '$org_logo_width' => array( 'name'    => _("Organization Logo Width"),
-                                             'type'    => SMOPT_TYPE_STRING,
+                                             'type'    => SMOPT_TYPE_INTEGER,
                                              'size'    => 5,
                                              'default' => 0),
                  '$org_logo_height' => array( 'name'    => _("Organization Logo Height"),
-                                              'type'    => SMOPT_TYPE_STRING,
+                                              'type'    => SMOPT_TYPE_INTEGER,
                                               'size'    => 5,
                                               'default' => 0),
                  '$org_title' => array( 'name' => _("Organization Title"),
@@ -80,10 +82,10 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                  '$signout_page' => array( 'name' => _("Signout Page"),
                                            'type' => SMOPT_TYPE_PATH,
                                            'size' => 40 ),
-                 '$provider_uri' => array( 'name' => _("Provider Link URI"),
-                                           'type' => SMOPT_TYPE_STRING ),
-                 '$provider_name' => array( 'name' => _("Provider Name"),
-                                            'type' => SMOPT_TYPE_STRING ),
+				 '$provider_uri' => array( 'name' => _("Provider Link URI"),
+				 						   'type' => SMOPT_TYPE_STRING ),
+				 '$provider_name' => array( 'name' => _("Provider Name"),
+				 						    'type' => SMOPT_TYPE_STRING ),
                  '$frame_top' => array( 'name' => _("Top Frame"),
                                         'type' => SMOPT_TYPE_STRING,
                                         'size' => 40,
@@ -105,69 +107,51 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                                                    'uw' => _("University of Washington's IMAP server"),
                                                                    'exchange' => _("Microsoft Exchange IMAP server"),
                                                                    'courier' => _("Courier IMAP server"),
-                                                                   'macosx' => _("Mac OS X Mailserver"),
-                                                                   'hmailserver' => _("hMailServer IMAP server"),
-                                                                   'mercury32' => _("Mercury/32 IMAP server"),
-                                                                   'bincimap' => _("Binc IMAP server"),
-                                                                   'dovecot' => _("Dovecot IMAP server"),
                                                                    'other' => _("Not one of the above servers") ) ),
                  '$optional_delimiter' => array( 'name' => _("IMAP Folder Delimiter"),
                                                  'type' => SMOPT_TYPE_STRING,
-                                                 'comment' => _("Use &quot;detect&quot; to auto-detect."),
+                                                 'comment' => _("Use \"detect\" to auto-detect."),
                                                  'size' => 10,
                                                  'default' => 'detect' ),
-                 '$use_imap_tls' => array( 'name' => _("Use TLS for IMAP Connections"),
-                                           'type' => SMOPT_TYPE_NUMLIST,
-                                           'comment' => _("Requires PHP 4.3.x for TLS, 5.1.0+ for STARTTLS."),
-                                           'posvals' => array( 0 => _("No"),
-                                                               1 => _("Use TLS"),
-                                                               2 => _("Use STARTTLS"))),
-                 '$imap_auth_mech' => array( 'name' => _("IMAP Authentication Type"),
-                                             'type' => SMOPT_TYPE_STRLIST,
-                                             'posvals' => array('login' => _("IMAP login"),
-                                                                'cram-md5' => 'CRAM-MD5',
-                                                                'digest-md5' => 'DIGEST-MD5'),
-                                             'default' => 'login' ),
+				 '$use_imap_tls' => array( 'name' => _("Use TLS for IMAP Connections"),
+				 						   'type' => SMOPT_TYPE_BOOLEAN,
+										   'comment' => _("Requires PHP 4.3.x! Experimental."),
+										   'default' => false ),
+				 '$imap_auth_mech' => array( 'name' => _("IMAP Authentication Type"),
+				 							 'type' => SMOPT_TYPE_STRLIST,
+											 'posvals' => array('login' => 'IMAP LOGIN',
+											 				    'cram-md5' => 'CRAM-MD5',
+																'digest-md5' => 'DIGEST-MD5'),
+											 'default' => 'login' ),
                  '$useSendmail' => array( 'name' => _("Use Sendmail Binary"),
                                           'type' => SMOPT_TYPE_BOOLEAN,
-                                          'comment' => _("Choose &quot;no&quot; for SMTP") ),
+										  'comment' => "Say 'no' for SMTP" ),
                  '$sendmail_path' => array( 'name' => _("Sendmail Path"),
                                             'type' => SMOPT_TYPE_STRING,
                                             'size' => 40 ),
-                 '$sendmail_args' => array( 'name' => _("Sendmail Arguments"),
-                                            'type' => SMOPT_TYPE_STRING,
-                                            'size' => 40 ),
                  '$smtpServerAddress' => array( 'name' => _("SMTP Server Address"),
                                                 'type' => SMOPT_TYPE_STRING,
                                                 'size' => 40 ),
                  '$smtpPort' => array( 'name' => _("SMTP Server Port"),
                                        'type' => SMOPT_TYPE_INTEGER ),
-                 '$use_smtp_tls' => array( 'name' => _("Use TLS for SMTP Connections"),
-                                           'type' => SMOPT_TYPE_NUMLIST,
-                                           'comment' => _("Requires PHP 4.3.x for TLS, 5.1.0+ for STARTTLS."),
-                                           'posvals' => array( 0 => _("No"),
-                                                               1 => _("Use TLS"),
-                                                               2 => _("Use STARTTLS"))),
-                 '$smtp_auth_mech' => array( 'name' => _("SMTP Authentication Type"),
-                                             'type' => SMOPT_TYPE_STRLIST,
-                                             'posvals' => array('none' => _("No SMTP auth"),
-                                                                'login' => _("Login (plain text)"),
-                                                                'cram-md5' => 'CRAM-MD5',
-                                                                'digest-md5' => 'DIGEST-MD5'),
-                                             'default' => 'none'),
-                 '$smtp_sitewide_user' => array( 'name' => _("Custom SMTP AUTH username"),
-                                                 'type' => SMOPT_TYPE_STRING,
-                                                 'size' => 40),
-                 '$smtp_sitewide_pass' => array( 'name' => _("Custom SMTP AUTH password"),
-                                                 'type' => SMOPT_TYPE_STRING,
-                                                 'size' => 40),
-                 '$pop_before_smtp' => array( 'name' => _("POP3 Before SMTP?"),
-                                              'type' => SMOPT_TYPE_BOOLEAN,
-                                              'default' => false ),
-                 '$encode_header_key' => array( 'name' => _("Header Encryption Key"),
-                                                'type' => SMOPT_TYPE_STRING ),
+				 '$use_smtp_tls' => array( 'name' => _("Use TLS for SMTP Connections"),
+				 						   'type' => SMOPT_TYPE_BOOLEAN,
+										   'comment' => _("Requires PHP 4.3.x! Experimental."),
+										   'default' => false ),
+				 '$smtp_auth_mech' => array( 'name' => _("SMTP Authentication Type"),
+				 							 'type' => SMOPT_TYPE_STRLIST,
+											 'posvals' => array('none' => 'No SMTP auth',
+											 					'login' => 'Login (Plaintext)',
+																'cram-md5' => 'CRAM-MD5',
+																'digest-md5' => 'DIGEST-MD5'),
+											 'default' => 'none'),
+				 '$pop_before_smtp' => array( 'name' => _("POP3 Before SMTP?"),
+				 							  'type' => SMOPT_TYPE_BOOLEAN,
+											  'default' => false ),
                  '$invert_time' => array( 'name' => _("Invert Time"),
                                           'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$default_use_mdn' => array( 'name' => _("Use Confirmation Flags"),
+                                              'type' => SMOPT_TYPE_BOOLEAN ),                                          
                  /* --------------------------------------------------------*/
                  'Group3' => array( 'name' => _("Folders Defaults"),
                                     'type' => SMOPT_TYPE_TITLE ),
@@ -212,11 +196,13 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                                                        SMPREF_UNSEEN_TOTAL => _("Unseen and Total") ) ),
                  '$auto_create_special' => array( 'name' => _("Auto Create Special Folders"),
                                                   'type' => SMOPT_TYPE_BOOLEAN ),
+                 '$default_use_javascript_addr_book' => array( 'name' => _("Default Javascript Adrressbook"),
+                                                  'type' => SMOPT_TYPE_BOOLEAN ),
                  '$delete_folder' => array( 'name' => _("Auto delete folders"),
                                             'type' => SMOPT_TYPE_BOOLEAN ),
-                 '$noselect_fix_enable' => array( 'name' => _("Enable /NoSelect folder fix"),
-                                                  'type' => SMOPT_TYPE_BOOLEAN,
-                                                  'default' => false),
+				 '$noselect_fix_enable' => array( 'name' => _("Enable /NoSelect folder fix"),
+				 								  'type' => SMOPT_TYPE_BOOLEAN,
+												  'default' => false),
                  /* --------------------------------------------------------*/
                  'Group4' => array( 'name' => _("General Options"),
                                     'type' => SMOPT_TYPE_TITLE ),
@@ -242,48 +228,30 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                                     'type' => SMOPT_TYPE_BOOLEAN ),
                  '$hide_sm_attributions' => array( 'name' => _("Hide SM attributions"),
                                                    'type' => SMOPT_TYPE_BOOLEAN ),
-                 '$default_use_mdn' => array( 'name' => _("Enable use of delivery receipts"),
+                 'default_use_mdn' => array( 'name' => _("Enable use of delivery receipts"),
                                              'type' => SMOPT_TYPE_BOOLEAN ),
                  '$edit_identity' => array( 'name' => _("Allow editing of identities"),
                                             'type' => SMOPT_TYPE_BOOLEAN ),
                  '$edit_name' => array( 'name' => _("Allow editing of full name"),
                                         'type' => SMOPT_TYPE_BOOLEAN ),
-                 '$edit_reply_to' => array( 'name' => _("Allow editing of reply-to address"),
-                                        'type' => SMOPT_TYPE_BOOLEAN ),
-                 '$hide_auth_header' => array( 'name' => _("Remove username from headers"),
-                                               'comment' => _("Used only when identities can't be modified"),
-                                               'type' => SMOPT_TYPE_BOOLEAN ),
-                 '$allow_server_sort' => array( 'name' => _("Use server-side sorting"),
-                                                'type' => SMOPT_TYPE_BOOLEAN,
-                                                'default' => false ),
-                 '$allow_thread_sort' => array( 'name' => _("Use server-side thread sorting"),
-                                                'type' => SMOPT_TYPE_BOOLEAN,
-                                                'default' => false ),
-                 '$allow_charset_search' => array( 'name' => _("Allow server charset search"),
-                                                   'type' => SMOPT_TYPE_BOOLEAN,
-                                                   'default' => false ),
-                 '$uid_support' => array( 'name' => _("UID support"),
-                                          'type' => SMOPT_TYPE_BOOLEAN,
-                                          'default' => false ),
-                 '$session_name' => array( 'name' => _("PHP session name"),
-                                           'type' => SMOPT_TYPE_HIDDEN ),
-                 '$config_location_base' => array( 'name' => _("Location base"),
-                                                   'type' => SMOPT_TYPE_STRING,
-                                                   'size' => 40,
-                                                   'default' => '' ),
-                 '$use_transparent_security_image' => array( 'name' => _("Use transparent security image"),
-                                          'type' => SMOPT_TYPE_BOOLEAN,
-                                          'default' => true ),
-                 '$display_imap_login_error' => array( 'name' => _("Show login error message directly from IMAP server instead of generic one"),
-                                          'type' => SMOPT_TYPE_BOOLEAN,
-                                          'default' => false ),
+				 '$allow_server_sort' => array( 'name' => _("Use server-side sorting"),
+				 							    'type' => SMOPT_TYPE_BOOLEAN,
+												'default' => false ),
+				 '$allow_thread_sort' => array( 'name' => _("Use server-side thread sorting"),
+				 								'type' => SMOPT_TYPE_BOOLEAN,
+												'default' => false ),
+				 '$allow_charset_search' => array( 'name' => _("Allow server charset search"),
+				 								   'type' => SMOPT_TYPE_BOOLEAN,
+												   'default' => false ),
+				 '$session_name' => array( 'name' => _("PHP session name"),
+				 						   'type' => SMOPT_TYPE_HIDDEN ),
                  /* --------------------------------------------------------*/
                  'Group5' => array( 'name' => _("Message of the Day"),
                                     'type' => SMOPT_TYPE_TITLE ),
                  '$motd' => array( 'name' => _("Message of the Day"),
                                    'type' => SMOPT_TYPE_TEXTAREA,
                                    'size' => 40 ),
-                 /* ---- Database settings ---- */
+                 /* --------------------------------------------------------*/
                  'Group6' => array( 'name' => _("Database"),
                                     'type' => SMOPT_TYPE_TITLE ),
                  '$addrbook_dsn' => array( 'name' => _("Address book DSN"),
@@ -319,60 +287,63 @@ $defcfg = array( '$config_version' => array( 'name' => _("Config File Version"),
                                              'type' => SMOPT_TYPE_STRING,
                                              'size' => 40,
                                              'default' => 'global_abook' ),
-                 '$addrbook_global_writeable' => array( 'name' => _("Allow writing into global address book"),
+                 '$addrbook_global_writable' => array( 'name' => _("Allow writing into global address book"),
                                             'type' => SMOPT_TYPE_BOOLEAN ),
                  '$addrbook_global_listing' => array( 'name' => _("Allow listing of global address book"),
                                             'type' => SMOPT_TYPE_BOOLEAN ),
-                 /* ---- Language settings ---- */
                  'Group9' => array( 'name' => _("Language settings"),
                                     'type' => SMOPT_TYPE_TITLE ),
-                 '$squirrelmail_default_language' => array( 'name' => _("Default Language"),
+		'$squirrelmail_default_language' => array( 'name' => _("Default Language"),
                                                             'type' => SMOPT_TYPE_STRLIST,
                                                             'size' => 7,
                                                             'posvals' => $language_values ),
-                 '$default_charset' => array( 'name' => _("Default Charset"),
+
+		 '$default_charset' => array( 'name' => _("Default Charset"),
                                               'type' => SMOPT_TYPE_STRLIST,
                                               'posvals' => array( 'iso-8859-1' => 'iso-8859-1',
                                                                   'iso-8859-2' => 'iso-8859-2',
                                                                   'iso-8859-7' => 'iso-8859-7',
-                                                                  'iso-8859-9' => 'iso-8859-9',
                                                                   'iso-8859-15' => 'iso-8859-15',
-                                                                  'utf-8' => 'utf-8',
+                                                                  'iso-8859-15' => 'iso-8859-15',
+                                                                  'ns_4551_1' => 'ns_4551_1',
                                                                   'koi8-r' => 'koi8-r',
-                                                                  'euc-kr' => 'euc-kr',
-                                                                  'big5' => 'big5',
-                                                                  'gb2312' => 'gb2312',
-                                                                  'tis-620' => 'tis-620',
+                                                                  'euc-KR' => 'euc-KR',
                                                                   'windows-1251' => 'windows-1251',
-                                                                  'windows-1255' => 'windows-1255',
-                                                                  'windows-1256' => 'windows-1256',
-                                                                  'iso-2022-jp' => 'iso-2022-jp' ) ),
-                  '$lossy_encoding'  => array( 'name' => _("Enable lossy encoding"),
-                                               'type' => SMOPT_TYPE_BOOLEAN ),
-                 /* ---- Settings of address books ---- */
-                 'Group10' => array( 'name' => _("Address Books"),
-                                     'type' => SMOPT_TYPE_TITLE ),
-                 '$default_use_javascript_addr_book' => array( 'name' => _("Default Javascript Addressbook"),
-                                                  'type' => SMOPT_TYPE_BOOLEAN ),
-                 '$abook_global_file' => array( 'name' => _("Global address book file"),
-                                                  'type' => SMOPT_TYPE_STRING ),
-                 '$abook_global_file_writeable' => array( 'name' => _("Allow writing into global address book file"),
-                                                  'type' => SMOPT_TYPE_BOOLEAN ),
+                                                                  'ISO-2022-JP' => 'ISO-2022-JP' ) ),
+		'$show_alternative_names'  => array( 'name' => _("Show alternative language names"),
+                                                    'type' => SMOPT_TYPE_BOOLEAN ),
+		'$available_languages' => array( 'name' => _("Available languages"),
+                                           'type' => SMOPT_TYPE_STRING,
+                                           'size' => 40 ),
+		'$agresive_decoding'  => array( 'name' => _("Use agresive decoding"),
+                                                    'type' => SMOPT_TYPE_BOOLEAN ),
+                 'Group10' => array( 'name' => _("Tweaks"),
+                                    'type' => SMOPT_TYPE_TITLE ),
+		 '$advanced_tree'  => array( 'name' => _("Use advanced tree folder listing"),
+                                                    'type' => SMOPT_TYPE_BOOLEAN ),
+		 '$oldway'  => array( 'name' => _("Use old folder listing functions"),
+                                                    'type' => SMOPT_TYPE_BOOLEAN ),
+		 '$use_php_recode'  => array( 'name' => _("Use php recode functions"),
+                                                    'type' => SMOPT_TYPE_BOOLEAN ),
+		 '$use_php_iconv'  => array( 'name' => _("Use php iconv functions"),
+                                                    'type' => SMOPT_TYPE_BOOLEAN ),
                  /* --------------------------------------------------------*/
                  'Group7' => array( 'name' => _("Themes"),
                                     'type' => SMOPT_TYPE_TITLE ),
                  '$theme_css' => array( 'name' => _("Style Sheet URL (css)"),
                                         'type' => SMOPT_TYPE_PATH,
                                         'size' => 40 ),
-                 '$theme_default' => array( 'name' => _("Default theme"),
-                                            'type' => SMOPT_TYPE_INTEGER,
-                                            'default' => 0,
-                                            'comment' => _("Use index number of theme") ),
+		 '$theme_default' => array( 'name' => _("Default theme"),
+ 					    'type' => SMOPT_TYPE_INTEGER,
+					    'default' => 0,
+					    'comment' => _("Use index number of theme") ),
                  /* --------------------------------------------------------*/
-                 '$config_use_color' => array( 'name' => '',
-                                               'type' => SMOPT_TYPE_HIDDEN ),
-                 '$no_list_for_subscribe' => array( 'name' => '',
-                                                    'type' => SMOPT_TYPE_HIDDEN ),
+                 '$config_use_color' => array(  'name' => '',
+                                                'type' => SMOPT_TYPE_HIDDEN ),
+				 '$no_list_for_subscribe' => array( 'name' => '',
+				'type' => SMOPT_TYPE_HIDDEN ),
                  /* --------------------------------------------------------*/
 
                );
+
+?>
