@@ -1,31 +1,23 @@
 <?php
+
 /**
- * Administrator plugin - Setup script
+ * setup.php
  *
- * Plugin allows remote administration.
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * @version $Id: setup.php 14800 2019-01-08 04:27:15Z pdontthink $
- * @author Philippe Mingo
- * @copyright (c) 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ *  Administrator plugin. Allows remote administration.  Philippe Mingo
+ *
+ * $Id: setup.php,v 1.8 2003/10/27 22:24:38 tassium Exp $
  * @package plugins
  * @subpackage administrator
  */
 
-/** add SM_PATH */
-if (!defined('SM_PATH'))  {
-    define('SM_PATH','../../');
-}
-
 /** @ignore */
 require_once(SM_PATH . 'plugins/administrator/auth.php');
 
-/**
- * Init the plugin
- * @access private
- */
 function squirrelmail_plugin_init_administrator() {
-    global $squirrelmail_plugin_hooks;
+    global $squirrelmail_plugin_hooks, $username;
 
     if ( adm_check_user() ) {        
         $squirrelmail_plugin_hooks['optpage_register_block']['administrator'] =
@@ -33,12 +25,9 @@ function squirrelmail_plugin_init_administrator() {
     }
 }
 
-/**
- * Register option block
- * @access private
- */
 function squirrelmail_administrator_optpage_register_block() {
     global $optpage_blocks;
+    global $AllowSpamFilters;
 
     $optpage_blocks[] = array(
         'name' => _("Administration"),
@@ -47,3 +36,4 @@ function squirrelmail_administrator_optpage_register_block() {
         'js'   => false
     );
 }
+?>
