@@ -1,43 +1,56 @@
 <?php
 
 /**
+ * calendar.php
+ *
+ * Copyright (c) 2002-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
+ * Originally contrubuted by Michal Szczotka <michal@tuxy.org>
+ *
  * Displays the main calendar page (month view).
  *
- * @copyright 2002-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: calendar.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: calendar.php,v 1.17 2003/12/01 21:56:49 cigamit Exp $
  * @package plugins
  * @subpackage calendar
  */
 
-/** @ignore */
+/**
+*/
 define('SM_PATH','../../');
 
-/* SquirrelMail required files. */
-include_once(SM_PATH . 'include/validate.php');
-/* load date_intl() */
-include_once(SM_PATH . 'functions/date.php');
+/* Calender plugin required files. */
+require_once(SM_PATH . 'plugins/calendar/calendar_data.php');
+require_once(SM_PATH . 'plugins/calendar/functions.php');
 
-/* Calendar plugin required files. */
-include_once(SM_PATH . 'plugins/calendar/calendar_data.php');
-include_once(SM_PATH . 'plugins/calendar/functions.php');
+/* SquirrelMail required files. */
+require_once(SM_PATH . 'include/validate.php');
+require_once(SM_PATH . 'functions/strings.php');
+require_once(SM_PATH . 'functions/date.php');
+require_once(SM_PATH . 'config/config.php');
+require_once(SM_PATH . 'functions/page_header.php');
+require_once(SM_PATH . 'include/load_prefs.php');
+require_once(SM_PATH . 'functions/html.php');
 
 /* get globals */
-if (! sqgetGlobalVar('month',$month,SQ_FORM) || ! is_numeric($month)) {
-    unset($month);
+
+if (isset($_GET['month'])) {
+    $month = $_GET['month'];
 }
-if (! sqgetGlobalVar('year',$year,SQ_FORM) || ! is_numeric($year)) {
-    unset($year);
+if (isset($_GET['year'])) {
+    $year = $_GET['year'];
+}
+if (isset($_POST['year'])) {
+    $year = $_POST['year'];
+}
+if (isset($_POST['month'])) {
+    $month = $_POST['month'];
 }
 /* got 'em */
 
-/**
- * display upper part of month calendar view
- * @return void
- * @access private
- */
+//display upper part of month calendar view
 function startcalendar() {
-    global $year, $month, $color;
+    global $year, $month, $day, $color;
 
     $prev_date = mktime(0, 0, 0, $month - 1, 1, $year);
     $act_date  = mktime(0, 0, 0, $month, 1, $year);
@@ -69,25 +82,21 @@ function startcalendar() {
                             )
                        ) . "\n".
                        html_tag( 'tr',
-                           html_tag( 'th', _("Sunday"), '', $color[5], 'width="14%"' ) ."\n" .
-                           html_tag( 'th', _("Monday"), '', $color[5], 'width="14%"' ) ."\n" .
-                           html_tag( 'th', _("Tuesday"), '', $color[5], 'width="14%"' ) ."\n" .
-                           html_tag( 'th', _("Wednesday"), '', $color[5], 'width="14%"' ) ."\n" .
-                           html_tag( 'th', _("Thursday"), '', $color[5], 'width="14%"' ) ."\n" .
-                           html_tag( 'th', _("Friday"), '', $color[5], 'width="14%"' ) ."\n" .
-                           html_tag( 'th', _("Saturday"), '', $color[5], 'width="14%"' ) ."\n"
+                           html_tag( 'th', _("Sunday"), '', $color[5], 'width="14%" width="90"' ) ."\n" .
+                           html_tag( 'th', _("Monday"), '', $color[5], 'width="14%" width="90"' ) ."\n" .
+                           html_tag( 'th', _("Tuesday"), '', $color[5], 'width="14%" width="90"' ) ."\n" .
+                           html_tag( 'th', _("Wednesday"), '', $color[5], 'width="14%" width="90"' ) ."\n" .
+                           html_tag( 'th', _("Thursday"), '', $color[5], 'width="14%" width="90"' ) ."\n" .
+                           html_tag( 'th', _("Friday"), '', $color[5], 'width="14%" width="90"' ) ."\n" .
+                           html_tag( 'th', _("Saturday"), '', $color[5], 'width="14%" width="90"' ) ."\n"
                        )
                ) ,
            '', $color[0] ) ."\n";
 }
 
-/**
- * main logic for month view of calendar
- * @return void
- * @access private
- */
+//main logic for month view of calendar
 function drawmonthview() {
-    global $year, $month, $color, $calendardata, $todayis;
+    global $year, $month, $day, $color, $calendardata, $todayis;
 
     $aday = 1 - date('w', mktime(0, 0, 0, $month, 1, $year));
     $days_in_month = date('t', mktime(0, 0, 0, $month, 1, $year));
@@ -100,10 +109,10 @@ function drawmonthview() {
             if ( $aday <= $days_in_month && $aday > 0){
                 echo html_tag( 'td', '', 'left', $color[4], 'height="50" valign="top"' ) ."\n".
                      html_tag( 'div', '', 'right' );
-                echo(($cdate==$todayis) ? '<font size="-1" color="'.$color[1].'">[ ' . _("TODAY") . " ] " : '<font size="-1">');
-                echo "<a href=\"day.php?year=$year&amp;month=$month&amp;day=";
+                echo(($cdate==$todayis) ? "<font size=-1 color=$color[1]>[ " . _("TODAY") . " ] " : "<font size=-1>");
+                echo "<a href=day.php?year=$year&amp;month=$month&amp;day=";
                 echo(($aday<10) ? "0" : "");
-                echo "$aday\">$aday</a></font></div>";
+                echo "$aday>$aday</a></font></div>";
             } else {
                 echo html_tag( 'td', '', 'left', $color[0]) ."\n".
                      "&nbsp;";
@@ -112,13 +121,8 @@ function drawmonthview() {
                 $i=0;
                 while ($calfoo = each($calendardata[$cdate])) {
                     $calbar = $calendardata[$cdate][$calfoo['key']];
-                    // FIXME: how to display multiline task
-                    $title = '['. $calfoo['key']. '] ' .
-                        str_replace(array("\r","\n"),array(' ',' '),sm_encode_html_special_chars($calbar['message']));
-                    // FIXME: link to nowhere
-                    echo "<a href=\"#\" style=\"text-decoration:none; color: "
-                        .($calbar['priority']==1 ? $color[1] : $color[6])
-                        ."\" title=\"$title\">".sm_encode_html_special_chars($calbar['title'])."</a><br />\n";
+                    $title = '['. $calfoo['key']. '] ' .$calbar['message'];
+                    echo ($calbar['priority']==1) ? "<a href=\"#\" style=\"text-decoration:none; color: $color[1]\" title=\"$title\">$calbar[title]</a><br>\n" : "<a href=\"#\" style=\"text-decoration:none; color: $color[6]\" title=\"$title\">$calbar[title]</a><br>\n";
                     $i=$i+1;
                     if($i==2){
                         break;
@@ -132,27 +136,23 @@ function drawmonthview() {
     }
 }
 
-/**
- * end of monthly view and form to jump to any month and year
- * @return void
- * @access private
- */
+//end of monthly view and form to jump to any month and year
 function endcalendar() {
     global $year, $month, $day, $color;
 
     echo html_tag( 'tr' ) ."\n" .
            html_tag( 'td', '', 'left', '', 'colspan="7"' ) ."\n" .
-         "          <form name=\"caljump\" action=\"calendar.php\" method=\"post\">\n".
-         "          <select name=\"year\">\n";
+         "          <FORM NAME=caljump ACTION=\"calendar.php\" METHOD=POST>\n".
+         "          <SELECT NAME=\"year\">\n";
     select_option_year($year);
-    echo "          </select>\n".
-         "          <select name=\"month\">\n";
+    echo "          </SELECT>\n".
+         "          <SELECT NAME=\"month\">\n";
     select_option_month($month);
-    echo "          </select>\n".
-         '          <input type="submit" value="' . _("Go") . "\" />\n".
-         "          </form>\n".
-         "          </td></tr>\n".
-         "</table></td></tr></table>\n";
+    echo "          </SELECT>\n".
+         '         <INPUT TYPE=SUBMIT VALUE="' . _("Go") . "\">\n".
+         "          </FORM>\n".
+         "          </TD></TR>\n".
+         "</TABLE></TD></TR></TABLE>\n";
 }
 
 
@@ -177,4 +177,4 @@ drawmonthview();
 endcalendar();
 
 ?>
-</body></html>
\ No newline at end of file
+</body></html>
