@@ -1,109 +1,137 @@
 <?php
 
 /**
+ * event_create.php
+ *
+ * Copyright (c) 2002-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
+ * Originally contrubuted by Michal Szczotka <michal@tuxy.org>
+ *
  * functions to create a event for calendar.
  *
- * @copyright 2002-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: event_create.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: event_create.php,v 1.19 2003/12/01 21:56:49 cigamit Exp $
  * @package plugins
  * @subpackage calendar
  */
 
-/** @ignore */
+/**
+ * @ignore
+ */
 define('SM_PATH','../../');
 
-/* SquirrelMail required files. */
-include_once(SM_PATH . 'include/validate.php');
-/* date_intl() */
-include_once(SM_PATH . 'functions/date.php');
+/* Calender plugin required files. */
+require_once(SM_PATH . 'plugins/calendar/calendar_data.php');
+require_once(SM_PATH . 'plugins/calendar/functions.php');
 
-/* Calendar plugin required files. */
-include_once(SM_PATH . 'plugins/calendar/calendar_data.php');
-include_once(SM_PATH . 'plugins/calendar/functions.php');
+/* SquirrelMail required files. */
+require_once(SM_PATH . 'include/validate.php');
+require_once(SM_PATH . 'functions/strings.php');
+require_once(SM_PATH . 'functions/date.php');
+require_once(SM_PATH . 'config/config.php');
+require_once(SM_PATH . 'functions/page_header.php');
+require_once(SM_PATH . 'include/load_prefs.php');
+require_once(SM_PATH . 'functions/html.php');
 
 /* get globals */
-if (! sqGetGlobalVar('year',$year,SQ_FORM) || ! is_numeric($year)) {
-    unset($year);
-}
-if (! sqGetGlobalVar('month',$month,SQ_FORM) || ! is_numeric($month)) {
-    unset($month);
-}
-if (! sqGetGlobalVar('day',$day,SQ_FORM) || ! is_numeric($day)) {
-    unset($day);
-}
-if (! sqGetGlobalVar('hour',$hour,SQ_FORM) || ! is_numeric($hour)) {
-    unset($hour);
-}
-if (! sqGetGlobalVar('event_hour',$event_hour,SQ_POST) || ! is_numeric($event_hour)) {
-    unset($event_hour);
-}
-if (! sqGetGlobalVar('event_minute',$event_minute,SQ_POST) || ! is_numeric($event_minute)) {
-    unset($event_minute);
-}
-if (! sqGetGlobalVar('event_length',$event_length,SQ_POST) || ! is_numeric($event_length)) {
-    unset($event_length);
-}
-if (! sqGetGlobalVar('event_priority',$event_priority,SQ_POST) || ! is_numeric($event_priority)) {
-    unset($event_priority);
-}
-
-sqGetGlobalVar('event_title',$event_title,SQ_POST);
-sqGetGlobalVar('event_text',$event_text,SQ_POST);
-sqGetGlobalVar('send',$send,SQ_POST);
 
+if (isset($_POST['year'])) {
+    $year = $_POST['year'];
+}
+elseif (isset($_GET['year'])) {
+    $year = $_GET['year'];
+}
+if (isset($_POST['month'])) {
+    $month = $_POST['month'];
+}
+elseif (isset($_GET['month'])) {
+    $month = $_GET['month'];
+}
+if (isset($_POST['day'])) {
+    $day = $_POST['day'];
+}
+elseif (isset($_GET['day'])) {
+    $day = $_GET['day'];
+}
+if (isset($_POST['hour'])) {
+    $hour = $_POST['hour'];
+}
+elseif (isset($_GET['hour'])) {
+    $hour = $_GET['hour'];
+}
+if (isset($_POST['event_hour'])) {
+    $event_hour = $_POST['event_hour'];
+}
+if (isset($_POST['event_minute'])) {
+    $event_minute = $_POST['event_minute'];
+}
+if (isset($_POST['event_length'])) {
+    $event_length = $_POST['event_length'];
+}
+if (isset($_POST['event_priority'])) {
+    $event_priority = $_POST['event_priority'];
+}
+if (isset($_POST['event_title'])) {
+    $event_title = $_POST['event_title'];
+}
+if (isset($_POST['event_text'])) {
+    $event_text = $_POST['event_text'];
+}
+if (isset($_POST['send'])) {
+    $send = $_POST['send'];
+}
 /* got 'em */
 
 //main form to gather event info
 function show_event_form() {
     global $color, $editor_size, $year, $day, $month, $hour;
 
-    echo "\n<form name=\"eventscreate\" action=\"event_create.php\" method=\"post\">\n".
-         "      <input type=\"hidden\" name=\"year\" value=\"$year\" />\n".
-         "      <input type=\"hidden\" name=\"month\" value=\"$month\" />\n".
-         "      <input type=\"hidden\" name=\"day\" value=\"$day\" />\n".
+    echo "\n<FORM name=eventscreate action=\"event_create.php\" METHOD=POST >\n".
+         "      <INPUT TYPE=hidden NAME=\"year\" VALUE=\"$year\">\n".
+         "      <INPUT TYPE=hidden NAME=\"month\" VALUE=\"$month\">\n".
+         "      <INPUT TYPE=hidden NAME=\"day\" VALUE=\"$day\">\n".
          html_tag( 'tr' ) .
          html_tag( 'td', _("Start time:"), 'right', $color[4] ) . "\n" .
          html_tag( 'td', '', 'left', $color[4] ) . "\n" .
-         "      <select name=\"event_hour\">\n";
+         "      <SELECT NAME=\"event_hour\">\n";
     select_option_hour($hour);
-    echo "      </select>\n" .
+    echo "      </SELECT>\n" .
          "      &nbsp;:&nbsp;\n" .
-         "      <select name=\"event_minute\">\n";
+         "      <SELECT NAME=\"event_minute\">\n";
     select_option_minute("00");
-    echo "      </select>\n".
+    echo "      </SELECT>\n".
          "      </td></tr>\n".
          html_tag( 'tr' ) .
          html_tag( 'td', _("Length:"), 'right', $color[4] ) . "\n" .
          html_tag( 'td', '', 'left', $color[4] ) . "\n" .
-         "      <select name=\"event_length\">\n";
+         "      <SELECT NAME=\"event_length\">\n";
     select_option_length("0");
-    echo "      </select>\n".
+    echo "      </SELECT>\n".
          "      </td></tr>\n".
          html_tag( 'tr' ) .
          html_tag( 'td', _("Priority:"), 'right', $color[4] ) . "\n" .
          html_tag( 'td', '', 'left', $color[4] ) . "\n" .
-         "      <select name=\"event_priority\">\n";
+         "      <SELECT NAME=\"event_priority\">\n";
     select_option_priority("0");
-    echo "      </select>\n".
+    echo "      </SELECT>\n".
          "      </td></tr>\n".
          html_tag( 'tr' ) .
          html_tag( 'td', _("Title:"), 'right', $color[4] ) . "\n" .
          html_tag( 'td', '', 'left', $color[4] ) . "\n" .
-         "      <input type=\"text\" name=\"event_title\" value=\"\" size=\"30\" maxlength=\"50\" /><br />\n".
+         "      <INPUT TYPE=text NAME=\"event_title\" VALUE=\"\" SIZE=30 MAXLENGTH=50><BR>\n".
          "      </td></tr>\n".
          html_tag( 'tr',
              html_tag( 'td',
-                 "<textarea name=\"event_text\" rows=\"5\" cols=\"$editor_size\" wrap=\"hard\"></textarea>" ,
+                 "<TEXTAREA NAME=\"event_text\" ROWS=5 COLS=\"$editor_size\" WRAP=HARD></TEXTAREA>" ,
              'left', $color[4], 'colspan="2"' )
          ) ."\n" .
          html_tag( 'tr',
              html_tag( 'td',
-                 '<input type="submit" name="send" value="' .
-                 _("Set Event") . '" />' ,
+                 "<INPUT TYPE=SUBMIT NAME=send VALUE=\"" .
+                 _("Set Event") . "\">" ,
              'left', $color[4], 'colspan="2"' )
          ) ."\n";
-    echo "</form>\n";
+    echo "</FORM>\n";
 }
 
 
@@ -138,33 +166,37 @@ if(!isset($event_text)){
     show_event_form();
 } else {
     readcalendardata();
+    //make sure that event text is fittting in one line
+    $event_text=nl2br($event_text);
+    $event_text=ereg_replace ("\n", "", $event_text);
+    $event_text=ereg_replace ("\r", "", $event_text);
     $calendardata["$month$day$year"]["$event_hour$event_minute"] =
-    array( 'length'   => $event_length,
+    array( 'length' => $event_length,
            'priority' => $event_priority,
-           'title'    => $event_title,
-           'message'  => $event_text,
+           'title' => $event_title,
+           'message' => $event_text,
            'reminder' => '' );
     //save
     writecalendardata();
     echo html_tag( 'table',
                 html_tag( 'tr',
-                    html_tag( 'th', _("Event Has been added!") . "<br />\n", '', $color[4], 'colspan="2"' )
+                    html_tag( 'th', _("Event Has been added!") . "<br>\n", '', $color[4], 'colspan="2"' )
                 ) .
                 html_tag( 'tr',
                     html_tag( 'td', _("Date:"), 'right', $color[4] ) . "\n" .
-                    html_tag( 'td', date_intl(_("m/d/Y"),mktime(0,0,0,$month,$day,$year)), 'left', $color[4] ) . "\n"
+                    html_tag( 'td', $month .'/'.$day.'/'.$year, 'left', $color[4] ) . "\n"
                 ) .
                 html_tag( 'tr',
                     html_tag( 'td', _("Time:"), 'right', $color[4] ) . "\n" .
-                    html_tag( 'td', date_intl(_("H:i"),mktime($event_hour,$event_minute,0,$month,$day,$year)), 'left', $color[4] ) . "\n"
+                    html_tag( 'td', $event_hour.':'.$event_minute, 'left', $color[4] ) . "\n"
                 ) .
                 html_tag( 'tr',
                     html_tag( 'td', _("Title:"), 'right', $color[4] ) . "\n" .
-                    html_tag( 'td', sm_encode_html_special_chars($event_title,ENT_NOQUOTES), 'left', $color[4] ) . "\n"
+                    html_tag( 'td', htmlspecialchars($event_title,ENT_NOQUOTES), 'left', $color[4] ) . "\n"
                 ) .
                 html_tag( 'tr',
                     html_tag( 'td', _("Message:"), 'right', $color[4] ) . "\n" .
-                    html_tag( 'td', nl2br(sm_encode_html_special_chars($event_text,ENT_NOQUOTES)), 'left', $color[4] ) . "\n"
+                    html_tag( 'td', htmlspecialchars($event_text,ENT_NOQUOTES), 'left', $color[4] ) . "\n"
                 ) .
                 html_tag( 'tr',
                     html_tag( 'td',
@@ -176,4 +208,4 @@ if(!isset($event_text)){
 
 ?>
 </table></td></tr></table>
-</body></html>
\ No newline at end of file
+</body></html>
