@@ -1,6 +1,10 @@
 <?php
+
 /**
- * Message and Spam Filter Plugin - Filtering Functions
+ * Message and Spam Filter Plugin
+ *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This plugin filters your inbox into different folders based upon given
  * criteria.  It is most useful for people who are subscibed to mailing lists
@@ -18,17 +22,14 @@
  *
  * Also view plugins/README.plugins for more information.
  *
- * @version $Id: filters.php 14800 2019-01-08 04:27:15Z pdontthink $
- * @copyright (c) 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * $Id: filters.php,v 1.52 2004/01/03 13:31:26 tokul Exp $
  * @package plugins
  * @subpackage filters
  */
 
 /**
- * FIXME: Undocumented function
- * @access private
- */
+*
+*/
 function filters_SaveCache () {
     global $data_dir, $SpamFilters_DNScache;
 
@@ -45,7 +46,7 @@ function filters_SaveCache () {
        $fp = fopen($data_dir . '/dnscache', 'r');
        flock($fp,LOCK_EX);
     }
-    $fp1 = fopen($data_dir . '/dnscache', 'w+');
+    $fp1=fopen($data_dir . '/dnscache', 'w+');
 
     foreach ($SpamFilters_DNScache as $Key=> $Value) {
        $tstr = $Key . ',' . $Value['L'] . ',' . $Value['T'] . "\n";
@@ -56,10 +57,6 @@ function filters_SaveCache () {
     fclose($fp);
 }
 
-/**
- * Loads the DNS Cache from disk
- * @access private
- */
 function filters_LoadCache () {
     global $data_dir, $SpamFilters_DNScache;
 
@@ -67,82 +64,23 @@ function filters_LoadCache () {
         $SpamFilters_DNScache = array();
         if ($fp = fopen ($data_dir . '/dnscache', 'r')) {
             flock($fp,LOCK_SH);
-            while ($data = fgetcsv($fp,1024)) {
+            while ($data=fgetcsv($fp,1024)) {
                if ($data[2] > time()) {
                   $SpamFilters_DNScache[$data[0]]['L'] = $data[1];
                   $SpamFilters_DNScache[$data[0]]['T'] = $data[2];
                }
             }
+
             flock($fp,LOCK_UN);
         }
     }
 }
 
-/**
- * Uses the BulkQuery executable to query all the RBLs at once
- * @param array $filters Array of SPAM Filters
- * @param array $IPs Array of IP Addresses
- * @param array $read TODO: Document this parameter
- * @access private
- */
-function filters_bulkquery($filters_spam_scan, $filters, $read) {
+function filters_bulkquery($filters, $IPs) {
     global $SpamFilters_YourHop, $attachment_dir, $username,
            $SpamFilters_DNScache, $SpamFilters_BulkQuery,
            $SpamFilters_CacheTTL;
 
-    $IPs = array();
-    $i = 0;
-    while ($i < count($read)) {
-        // EIMS will give funky results
-        $Chunks = explode(' ', $read[$i]);
-        if ($Chunks[0] != '*') {
-            $i ++;
-            continue;
-        }
-        $MsgNum = $Chunks[1];
-
-        $i ++;
-
-        // Look through all of the Received headers for IP addresses
-        // Stop when I get ")" on a line
-        // Stop if I get "*" on a line (don't advance)
-        // and above all, stop if $i is bigger than the total # of lines
-        while (($i < count($read)) &&
-                ($read[$i][0] != ')' && $read[$i][0] != '*' &&
-                $read[$i][0] != "\n")) {
-            // Check to see if this line is the right "Received from" line
-            // to check
-            if (is_int(strpos($read[$i], $SpamFilters_YourHop))) {
-                $read[$i] = preg_replace('/[^0-9\.]/', ' ', $read[$i]);
-                $elements = explode(' ', $read[$i]);
-                foreach ($elements as $value) {
-                    if ($value != '' &&
-                        preg_match('/((\d{1,3}\.){3}\d{1,3})/',
-                            $value)) {
-                        $Chunks = explode('.', $value);
-                        $IP = $Chunks[3] . '.' . $Chunks[2] . '.' .
-                              $Chunks[1] . '.' . $Chunks[0];
-                        foreach ($filters as $key => $value) {
-                            if ($filters[$key]['enabled'] &&
-                                      $filters[$key]['dns']) {
-                                if (strlen($SpamFilters_DNScache[$IP.'.'.$filters[$key]['dns']]) == 0) {
-                                   $IPs[$IP] = true;
-                                   break;
-                                }
-                            }
-                        }
-                        // If we've checked one IP and YourHop is
-                        // just a space
-                        if ($SpamFilters_YourHop == ' ') {
-                            break;  // don't check any more
-                        }
-                    }
-                }
-            }
-            $i ++;
-        }
-    }
-
     if (count($IPs) > 0) {
         $rbls = array();
         foreach ($filters as $key => $value) {
@@ -175,94 +113,46 @@ function filters_bulkquery($filters_spam_scan, $filters, $read) {
     }
 }
 
-/**
- * Starts the filtering process
- * @access private
- */
 function start_filters() {
-    global $mailbox, $imapServerAddress, $imapPort, $imap_stream_options,
+    global $mailbox, $imapServerAddress, $imapPort, $imap,
            $imap_general, $filters, $imap_stream, $imapConnection,
            $UseSeparateImapConnection, $AllowSpamFilters;
 
-    // if there were filtering errors previously during
-    // this login session, we won't try again
-    //
-    // (errors that this plugin was able to catch or a "NO"
-    // response/failure from IMAP found in the current session,
-    // which could have resulted from an attempted filter copy
-    // (over quota), in which case execution halts before this
-    // plugin can catch the problem -- note, however, that any
-    // other IMAP "NO" failure (caused by unrelated actions) at
-    // any time during the current session will cause this plugin
-    // to effectively shut down)
-    //
-    sqgetGlobalVar('filters_error', $filters_error, SQ_SESSION, FALSE);
-    sqgetGlobalVar('IMAP_FATAL_ERROR_TYPE', $imap_fatal_error, SQ_SESSION, '');
-    if ($filters_error || $imap_fatal_error == 'NO')
-        return;
-
     sqgetGlobalVar('username', $username, SQ_SESSION);
     sqgetGlobalVar('key',      $key,      SQ_COOKIE);
 
+#    if ($mailbox == 'INBOX') {
+        // Detect if we have already connected to IMAP or not.
+        // Also check if we are forced to use a separate IMAP connection
+        if ((!isset($imap_stream) && !isset($imapConnection)) ||
+            $UseSeparateImapConnection) {
+                $stream = sqimap_login($username, $key, $imapServerAddress,
+                                    $imapPort, 10);
+                $previously_connected = false;
+        } elseif (isset($imapConnection)) {
+            $stream = $imapConnection;
+            $previously_connected = true;
+        } else {
+            $previously_connected = true;
+            $stream = $imap_stream;
+        }
 
-    $filters = load_filters();
-
-    // No point running spam filters if there aren't any to run //
-    if ($AllowSpamFilters) {
-        $spamfilters = load_spam_filters();
-
-        $AllowSpamFilters = false;
-        foreach($spamfilters as $filterkey => $value) {
-            if ($value['enabled'] == SMPREF_ON) {
-                $AllowSpamFilters = true;
-                break;
+        if (sqimap_get_num_messages($stream, 'INBOX') > 0) {
+            // Filter spam from inbox before we sort them into folders
+            if ($AllowSpamFilters) {
+                spam_filters($stream);
             }
-        }
-    }
 
-    // No user filters, and no spam filters, no need to continue //
-    if (!$AllowSpamFilters && empty($filters)) {
-        return;
-    }
-
-
-    // Detect if we have already connected to IMAP or not.
-    // Also check if we are forced to use a separate IMAP connection
-    if ((!isset($imap_stream) && !isset($imapConnection)) ||
-        $UseSeparateImapConnection ) {
-            $stream = sqimap_login($username, $key, $imapServerAddress,
-                                $imapPort, 10, $imap_stream_options);
-            $previously_connected = false;
-    } else if (isset($imapConnection)) {
-        $stream = $imapConnection;
-        $previously_connected = true;
-    } else {
-        $previously_connected = true;
-        $stream = $imap_stream;
-    }
-    $aStatus = sqimap_status_messages ($stream, 'INBOX', array('MESSAGES'));
-
-    if ($aStatus['MESSAGES']) {
-        sqimap_mailbox_select($stream, 'INBOX');
-        // Filter spam from inbox before we sort them into folders
-        if ($AllowSpamFilters) {
-            spam_filters($stream);
+            // Sort into folders
+            user_filters($stream);
         }
 
-        // Sort into folders
-        user_filters($stream);
-    }
-
-    if (!$previously_connected) {
-        sqimap_logout($stream);
-    }
+        if (!$previously_connected) {
+            sqimap_logout($stream);
+        }
+#    }
 }
 
-/**
- * Does the loop through each filter
- * @param stream imap_stream the stream to read from
- * @access private
- */
 function user_filters($imap_stream) {
     global $data_dir, $username;
     $filters = load_filters();
@@ -270,66 +160,44 @@ function user_filters($imap_stream) {
     $filters_user_scan = getPref($data_dir, $username, 'filters_user_scan');
 
     sqimap_mailbox_select($imap_stream, 'INBOX');
-    $id = array();
+    $expunge = false;
     // For every rule
     for ($i=0, $num = count($filters); $i < $num; $i++) {
-    	// Don't attempt to run filters if folder does not exist //
-    	if (!sqimap_mailbox_exists($imap_stream, $filters[$i]['folder'])) {
-    		continue;
-    	}
-    	
-    	
         // If it is the "combo" rule
         if ($filters[$i]['where'] == 'To or Cc') {
             /*
             *  If it's "TO OR CC", we have to do two searches, one for TO
             *  and the other for CC.
             */
-            $id = filter_search_and_delete($imap_stream, 'TO',
-                  $filters[$i]['what'], $filters[$i]['folder'], $filters_user_scan, $id);
-            $id = filter_search_and_delete($imap_stream, 'CC',
-                  $filters[$i]['what'], $filters[$i]['folder'], $filters_user_scan, $id);
+            $expunge = filter_search_and_delete($imap_stream, 'TO',
+                  $filters[$i]['what'], $filters[$i]['folder'], $filters_user_scan, $expunge);
+            $expunge = filter_search_and_delete($imap_stream, 'CC',
+                  $filters[$i]['what'], $filters[$i]['folder'], $filters_user_scan, $expunge);
         } else {
             /*
             *  If it's a normal TO, CC, SUBJECT, or FROM, then handle it
             *  normally.
             */
-            $id = filter_search_and_delete($imap_stream, $filters[$i]['where'],
-                 $filters[$i]['what'], $filters[$i]['folder'], $filters_user_scan, $id);
+            $expunge = filter_search_and_delete($imap_stream, $filters[$i]['where'],
+                 $filters[$i]['what'], $filters[$i]['folder'], $filters_user_scan, $expunge);
         }
     }
     // Clean out the mailbox whether or not auto_expunge is on
     // That way it looks like it was redirected properly
-    if (count($id)) {
+    if ($expunge) {
         sqimap_mailbox_expunge($imap_stream, 'INBOX');
     }
 }
 
-/**
- * Creates and runs the IMAP command to filter messages
- * @param string $imap TODO: Document this parameter
- * @param string $where Which part of the message to search (TO, CC, SUBJECT, etc...)
- * @param string $what String to search for
- * @param string $where_to Folder it will move to
- * @param string $user_scan Whether to search all or just unseen
- * @param string $del_id TODO: Document this parameter
- * @access private
- */
-function filter_search_and_delete($imap, $where, $what, $where_to, $user_scan,
-                                  $del_id) {
-    global $languages, $squirrelmail_language, $allow_charset_search,
+function filter_search_and_delete($imap_stream, $where, $what, $where_to, $user_scan, 
+                                  $should_expunge) {
+    global $languages, $squirrelmail_language, $allow_charset_search, 
            $uid_support, $imap_server_type;
-
-    if (strtolower($where_to) == 'inbox') {
-        return array();
-    }
-
     if ($user_scan == 'new') {
         $category = 'UNSEEN';
     } else {
         $category = 'ALL';
     }
-    $category .= ' UNDELETED';
 
     if ($allow_charset_search &&
         isset($languages[$squirrelmail_language]['CHARSET']) &&
@@ -346,20 +214,15 @@ function filter_search_and_delete($imap, $where, $what, $where_to, $user_scan,
         $what  = addslashes(trim($what[1]));
     }
 
-    // see comments in squirrelmail sqimap_search function
-    if ($imap_server_type == 'macosx' || $imap_server_type == 'hmailserver') {
-        $search_str .= ' ' . $where . ' ' . $what;
-        $read = sqimap_run_command_list($imap, $search_str, true, $response, $message, $uid_support);        
+    if ($imap_server_type == 'macosx') {    
+	$search_str .= ' ' . $where . ' ' . $what;
     } else {
-    	$lit = array();
-    	$lit['commands'][] = $search_str . ' ' . $where;
-    	$lit['literal_args'][] = $what;
-    	
-		$read = sqimap_run_literal_command($imap, $lit, true, $response, $message, $uid_support );
+	$search_str .= ' ' . $where . ' {' . strlen($what) . "}\r\n"
+                    . $what . "\r\n";
     }
 
     /* read data back from IMAP */
-    
+    $read = sqimap_run_command($imap_stream, $search_str, true, $response, $message, $uid_support);
 
     // This may have problems with EIMS due to it being goofy
 
@@ -367,42 +230,33 @@ function filter_search_and_delete($imap, $where, $what, $where_to, $user_scan,
                 substr($read[$r], 0, 8) != '* SEARCH'; $r++) {}
     if ($response == 'OK') {
         $ids = explode(' ', $read[$r]);
-        if (sqimap_mailbox_exists($imap, $where_to)) {
-            /*
-             * why we do n calls instead of just one. It is safer to copy
-             * messages one by one, but code does not call expunge after
-             * message is copied and quota limits are not resolved.
-             */
+        
+        if (sqimap_mailbox_exists($imap_stream, $where_to)) {
+            $del_id = array();
             for ($j=2, $num = count($ids); $j < $num; $j++) {
                 $id = trim($ids[$j]);
-                if (sqimap_msgs_list_move($imap, $id, $where_to)) {
+                if (is_numeric($id)) {
                     $del_id[] = $id;
-                } else {
-                    // if errors occurred, don't try to filter again during this session
-                    sqsession_register(TRUE, 'filters_error');
-                    global $color;
-                    error_box(_("A problem occurred filtering messages. Check filter settings and account quota if applicable. Filtering is disabled for the remainder of this login session."), $color);
-                    // we stil return info about what was successfully
-                    // filtered before this error occurred
-                    return $del_id;
                 }
             }
+            if (count($del_id)) {
+                $should_expunge = true;
+                sqimap_msgs_list_move ($imap_stream, $del_id, $where_to);
+                // sqimap_mailbox_expunge($imap_stream, 'INBOX');
+            }
         }
     }
-    return $del_id;
+    return $should_expunge;
 }
 
-/**
- * Loops through all the Received Headers to find IP Addresses
- * @param stream imap_stream the stream to read from
- * @access private
- */
+// These are the spam filters
 function spam_filters($imap_stream) {
     global $data_dir, $username, $uid_support;
     global $SpamFilters_YourHop;
     global $SpamFilters_DNScache;
     global $SpamFilters_SharedCache;
     global $SpamFilters_BulkQuery;
+    global $SpamFilters_CacheTTL;
 
     $filters_spam_scan = getPref($data_dir, $username, 'filters_spam_scan');
     $filters_spam_folder = getPref($data_dir, $username, 'filters_spam_folder');
@@ -428,70 +282,72 @@ function spam_filters($imap_stream) {
 
     sqimap_mailbox_select($imap_stream, 'INBOX');
 
-    $search_array = array();
-    if ($filters_spam_scan == 'new') {
+    // Ask for a big list of all "Received" headers in the inbox with
+    // flags for each message.  Kinda big.
+    
+    // MGK, removed FLAGS from query. It wasn't used.
+    if ($filters_spam_scan != 'new') {
+        $query = 'FETCH 1:* (BODY.PEEK[HEADER.FIELDS (Received)])';
+    } else {
         $read = sqimap_run_command($imap_stream, 'SEARCH UNSEEN', true, $response, $message, $uid_support);
-        if (isset($read[0])) {
-            for ($i = 0, $iCnt = count($read); $i < $iCnt; ++$i) {
-                if (preg_match("/^\* SEARCH (.+)$/", $read[$i], $regs)) {
-                    $search_array = explode(' ', trim($regs[1]));
-                    break;
+        if ($response != 'OK' || trim($read[0]) == '* SEARCH') {
+    	    $query = 'FETCH 1:* (BODY.PEEK[HEADER.FIELDS (RECEIVED)])';
+        } else {
+            if (isset($read[0])) {
+                if (preg_match("/^\* SEARCH (.+)$/", $read[0], $regs)) {
+                    $search_array = preg_split("/ /", trim($regs[1]));
                 }
             }
-        }
+            $msgs_str = sqimap_message_list_squisher($search_array);
+            $query =  'FETCH ' . $msgs_str . ' (BODY.PEEK[HEADER.FIELDS (RECEIVED)])';
+	    }
     }
-
-    if ($filters_spam_scan == 'new' && count($search_array)) {
-        $msg_str = sqimap_message_list_squisher($search_array);
-        $imap_query = 'FETCH ' . $msg_str . ' (FLAGS BODY.PEEK[HEADER.FIELDS (RECEIVED)])';
-    } else if ($filters_spam_scan != 'new') {
-        $imap_query = 'FETCH 1:* (FLAGS BODY.PEEK[HEADER.FIELDS (RECEIVED)])';
-    } else {
+    $headers = filter_get_headers ($imap_stream, $query);    
+    if (!$headers) {
         return;
     }
-
-    $read = sqimap_run_command_list($imap_stream, $imap_query, true, $response, $message, $uid_support);
-
-    if (isset($response) && $response != 'OK') {
-        return;
-    }
-
-    $messages = parseFetch($read);
-
+    
     $bulkquery = (strlen($SpamFilters_BulkQuery) > 0 ? true : false);
+    $IPs = array();
     $aSpamIds = array();
-    foreach($messages as $id=>$message) {
-        if (isset($message['UID'])) {
-            $MsgNum = $message['UID'];
+    foreach ($headers as $id => $aValue) {
+        if (isset($aValue['UID'])) { 
+            $MsgNum = $aValue['UID'];
         } else {
             $MsgNum = $id;
         }
-
-        if (isset($message['received'])) {
-            foreach($message['received'] as $received) {
+        // Look through all of the Received headers for IP addresses
+        if (isset($aValue['HEADER']['Received'])) {
+            foreach ($aValue['HEADER']['Received'] as $received) {
+                // Check to see if this line is the right "Received from" line
+                // to check
+                
+                // $aValue['HEADER']['Received'] is an array with all the received lines.
+                // We should check them from bottom to top and only check the first 2.
+                // Currently we check only the header where $SpamFilters_YourHop in occures
+                
                 if (is_int(strpos($received, $SpamFilters_YourHop))) {
-                    if (preg_match('/([0-9]{1,3})\.([0-9]{1,3})\.([0-9]{1,3})\.([0-9]{1,3})/', $received, $matches)) {
-                        $IsSpam = false;
-                        if (filters_spam_check_site($matches[1], $matches[2], $matches[3], $matches[4], $filters)) {
+                    if (preg_match('/([0-9]{1,3})\.([0-9]{1,3})\.([0-9]{1,3})\.([0-9]{1,3})/',$received,$aMatch)) {
+                        $isspam = false;
+                        if (filters_spam_check_site($aMatch[1],$aMatch[2],$aMatch[3],$aMatch[4],$filters)) {
                             $aSpamIds[] = $MsgNum;
-                            $IsSpam = true;
+                            $isspam = true;
                         }
-
                         if ($bulkquery) {
-                            array_shift($matches);
-                            $IP = explode('.', $matches);
+                            array_shift($aMatch);
+                            $IP = explode('.',$aMatch);
                             foreach ($filters as $key => $value) {
                                 if ($filters[$key]['enabled'] && $filters[$key]['dns']) {
-                                    if (strlen($SpamFilters_DNScache[$IP . '.' . $filters[$key]['dns']]) == 0) {
-                                        $IPs[$IP] = true;
-                                        break;
+                                    if (strlen($SpamFilters_DNScache[$IP.'.'.$filters[$key]['dns']]) == 0) {
+                                       $IPs[$IP] = true;
+                                       break;
                                     }
                                 }
                             }
                         }
                         // If we've checked one IP and YourHop is
                         // just a space
-                        if ($SpamFilters_YourHop == ' ' || $IsSpam) {
+                        if ($SpamFilters_YourHop == ' ' || $isspam) {
                             break;  // don't check any more
                         }
                     }
@@ -501,14 +357,8 @@ function spam_filters($imap_stream) {
     }
     // Lookie!  It's spam!  Yum!
     if (count($aSpamIds) && sqimap_mailbox_exists($imap_stream, $filters_spam_folder)) {
-        if (!sqimap_msgs_list_move($imap_stream, $aSpamIds, $filters_spam_folder)) {
-            // if errors occurred, don't try to filter again during this session
-            sqsession_register(TRUE, 'filters_error');
-            global $color;
-            error_box(_("A problem occurred filtering messages. Check filter folders and account quota if applicable. Filtering is disabled for the remainder of this login session."), $color);
-            return;
-        }
-        sqimap_mailbox_expunge($imap_stream, 'INBOX', true, $aSpamIds);
+        sqimap_msgs_list_move ($imap_stream, $aSpamIds, $filters_spam_folder);
+        sqimap_mailbox_expunge($imap_stream, 'INBOX');
     }
 
     if ($bulkquery && count($IPs)) {
@@ -522,30 +372,15 @@ function spam_filters($imap_stream) {
     }
 }
 
-/**
- * Does the loop through each enabled filter for the specified IP address.
- * IP format:  $a.$b.$c.$d
- * @param int $a First subset of IP
- * @param int $b Second subset of IP
- * @param int $c Third subset of IP
- * @param int $d Forth subset of IP
- * @param array $filters The Spam Filters
- * @return boolean Whether the IP is Spam
- * @access private
- */
+// Does the loop through each enabled filter for the specified IP address.
+// IP format:  $a.$b.$c.$d
 function filters_spam_check_site($a, $b, $c, $d, &$filters) {
     global $SpamFilters_DNScache, $SpamFilters_CacheTTL;
     foreach ($filters as $key => $value) {
         if ($filters[$key]['enabled']) {
             if ($filters[$key]['dns']) {
-
-                /**
-                 * RFC allows . on end of hostname to force domain lookup to
-                 * not use search domain from resolv.conf, i.e. to ensure
-                 * search domain isn't used if no hostname is found
-                 */
                 $filter_revip = $d . '.' . $c . '.' . $b . '.' . $a . '.' .
-                                $filters[$key]['dns'] . '.';
+                                $filters[$key]['dns'];
 
                 if(!isset($SpamFilters_DNScache[$filter_revip]['L']))
                         $SpamFilters_DNScache[$filter_revip]['L'] = '';
@@ -559,12 +394,8 @@ function filters_spam_check_site($a, $b, $c, $d, &$filters) {
                     $SpamFilters_DNScache[$filter_revip]['T'] =
                                        time() + $SpamFilters_CacheTTL;
                 }
-
-                /**
-                 * gethostbyname returns ip if resolved, or returns original
-                 * host supplied to function if there is no resolution
-                 */
-                if ($SpamFilters_DNScache[$filter_revip]['L'] != $filter_revip) {
+                if ($SpamFilters_DNScache[$filter_revip]['L'] ==
+                    $filters[$key]['result']) {
                     return 1;
                 }
             }
@@ -573,29 +404,19 @@ function filters_spam_check_site($a, $b, $c, $d, &$filters) {
     return 0;
 }
 
-/**
- * Loads the filters from the user preferences
- * @return array All the user filters
- * @access private
- */
 function load_filters() {
     global $data_dir, $username;
 
     $filters = array();
-    for ($i = 0; $fltr = getPref($data_dir, $username, 'filter' . $i); $i++) {
+    for ($i=0; $fltr = getPref($data_dir, $username, 'filter' . $i); $i++) {
         $ary = explode(',', $fltr);
         $filters[$i]['where'] = $ary[0];
-        $filters[$i]['what'] = str_replace('###COMMA###', ',', $ary[1]);
+        $filters[$i]['what'] = $ary[1];
         $filters[$i]['folder'] = $ary[2];
     }
     return $filters;
 }
 
-/**
- * Loads the Spam Filters and checks the preferences for the enabled status
- * @return array All the spam filters
- * @access private
- */
 function load_spam_filters() {
     global $data_dir, $username, $SpamFilters_ShowCommercial;
 
@@ -614,7 +435,7 @@ function load_spam_filters() {
         $filters['MAPS RSS']['dns'] = 'relays.mail-abuse.org';
         $filters['MAPS RSS']['result'] = '127.0.0.2';
         $filters['MAPS RSS']['comment'] =
-            _("COMMERCIAL - Servers that are configured (or misconfigured) to allow spam to be relayed through their system will be banned with this. Another good one to use.");
+            _("COMMERCIAL - Servers that are configured (or misconfigured) to allow spam to be relayed through their system will be banned with this.  Another good one to use.");
 
         $filters['MAPS DUL']['prefname'] = 'filters_spam_maps_dul';
         $filters['MAPS DUL']['name'] = 'MAPS Dial-Up List';
@@ -622,7 +443,7 @@ function load_spam_filters() {
         $filters['MAPS DUL']['dns'] = 'dialups.mail-abuse.org';
         $filters['MAPS DUL']['result'] = '127.0.0.3';
         $filters['MAPS DUL']['comment'] =
-            _("COMMERCIAL - Dial-up users are often filtered out since they should use their ISP's mail servers to send mail. Spammers typically get a dial-up account and send spam directly from there.");
+            _("COMMERCIAL - Dial-up users are often filtered out since they should use their ISP's mail servers to send mail.  Spammers typically get a dial-up account and send spam directly from there.");
 
         $filters['MAPS RBLplus-RBL']['prefname'] = 'filters_spam_maps_rblplus_rbl';
         $filters['MAPS RBLplus-RBL']['name'] = 'MAPS RBL+ RBL List';
@@ -649,6 +470,14 @@ function load_spam_filters() {
             _("COMMERCIAL - RBL+ Dial-up entries.");
     }
 
+    $filters['ORDB']['prefname'] = 'filters_spam_ordb';
+    $filters['ORDB']['name'] = 'Open Relay Database List';
+    $filters['ORDB']['link'] = 'http://www.ordb.org/';
+    $filters['ORDB']['dns'] = 'relays.ordb.org';
+    $filters['ORDB']['result'] = '127.0.0.2';
+    $filters['ORDB']['comment'] =
+        _("FREE - ORDB was born when ORBS went off the air. It seems to have fewer false positives than ORBS did though.");
+
     $filters['FiveTen Direct']['prefname'] = 'filters_spam_fiveten_src';
     $filters['FiveTen Direct']['name'] = 'Five-Ten-sg.com Direct SPAM Sources';
     $filters['FiveTen Direct']['link'] = 'http://www.five-ten-sg.com/blackhole.php';
@@ -727,7 +556,7 @@ function load_spam_filters() {
     $filters['SPAMcop']['dns'] = 'bl.spamcop.net';
     $filters['SPAMcop']['result'] = '127.0.0.2';
     $filters['SPAMcop']['comment'] =
-        _("FREE, for now - SpamCop - An interesting solution that lists servers that have a very high spam to legit email ratio (85 percent or more).");
+        _("FREE, for now - SPAMCOP - An interesting solution that lists servers that have a very high spam to legit email ratio (85 percent or more).");
 
     $filters['dev.null.dk']['prefname'] = 'filters_spam_devnull';
     $filters['dev.null.dk']['name'] = 'dev.null.dk Lists';
@@ -833,22 +662,43 @@ function load_spam_filters() {
     $filters['NJABL DUL']['comment'] =
         _("FREE, for now - Not Just Another Blacklist - Dial-up IPs.");
 
+    $filters['Conf DSBL.ORG Relay']['prefname'] = 'filters_spam_dsbl_conf_ss';
+    $filters['Conf DSBL.ORG Relay']['name'] = 'DSBL.org Confirmed Relay List';
+    $filters['Conf DSBL.ORG Relay']['link'] = 'http://www.dsbl.org/';
+    $filters['Conf DSBL.ORG Relay']['dns'] = 'list.dsbl.org';
+    $filters['Conf DSBL.ORG Relay']['result'] = '127.0.0.2';
+    $filters['Conf DSBL.ORG Relay']['comment'] =
+        _("FREE - Distributed Sender Boycott List - Confirmed Relays");
+
+    $filters['Conf DSBL.ORG Multi-Stage']['prefname'] = 'filters_spam_dsbl_conf_ms';
+    $filters['Conf DSBL.ORG Multi-Stage']['name'] = 'DSBL.org Confirmed Multi-Stage Relay List';
+    $filters['Conf DSBL.ORG Multi-Stage']['link'] = 'http://www.dsbl.org/';
+    $filters['Conf DSBL.ORG Multi-Stage']['dns'] = 'multihop.dsbl.org';
+    $filters['Conf DSBL.ORG Multi-Stage']['result'] = '127.0.0.2';
+    $filters['Conf DSBL.ORG Multi-Stage']['comment'] =
+        _("FREE - Distributed Sender Boycott List - Confirmed Multi-stage Relays");
+
+    $filters['UN-Conf DSBL.ORG']['prefname'] = 'filters_spam_dsbl_unc';
+    $filters['UN-Conf DSBL.ORG']['name'] = 'DSBL.org UN-Confirmed Relay List';
+    $filters['UN-Conf DSBL.ORG']['link'] = 'http://www.dsbl.org/';
+    $filters['UN-Conf DSBL.ORG']['dns'] = 'unconfirmed.dsbl.org';
+    $filters['UN-Conf DSBL.ORG']['result'] = '127.0.0.2';
+    $filters['UN-Conf DSBL.ORG']['comment'] =
+        _("FREE - Distributed Sender Boycott List - UN-Confirmed Relays");
+
     foreach ($filters as $Key => $Value) {
-        $filters[$Key]['enabled'] = (bool)getPref($data_dir, $username, $filters[$Key]['prefname']);
+        $filters[$Key]['enabled'] = getPref($data_dir, $username,
+            $filters[$Key]['prefname']);
     }
 
     return $filters;
 }
 
-/**
- * Removes a User filter
- * @param int $id ID of the filter to remove
- * @access private
- */
 function remove_filter ($id) {
     global $data_dir, $username;
 
-    while ($nextFilter = getPref($data_dir, $username, 'filter' . ($id + 1))) {
+    while ($nextFilter = getPref($data_dir, $username, 'filter' .
+        ($id + 1))) {
         setPref($data_dir, $username, 'filter' . $id, $nextFilter);
         $id ++;
     }
@@ -856,12 +706,6 @@ function remove_filter ($id) {
     removePref($data_dir, $username, 'filter' . $id);
 }
 
-/**
- * Swaps two filters
- * @param int $id1 ID of first filter to swap
- * @param int $id2 ID of second filter to swap
- * @access private
- */
 function filter_swap($id1, $id2) {
     global $data_dir, $username;
 
@@ -874,21 +718,18 @@ function filter_swap($id1, $id2) {
     }
 }
 
-/**
- * This updates the filter rules when renaming or deleting folders
- * @param array $args
- * @access private
- */
+/* This update the filter rules when
+   renaming or deleting folders */
 function update_for_folder ($args) {
     $old_folder = $args[0];
-    $new_folder = $args[2];
-    $action = $args[1];
+        $new_folder = $args[2];
+        $action = $args[1];
     global $plugins, $data_dir, $username;
     $filters = array();
     $filters = load_filters();
     $filter_count = count($filters);
     $p = 0;
-    for ($i = 0; $i < $filter_count; $i++) {
+    for ($i=0;$i<$filter_count;$i++) {
         if (!empty($filters)) {
             if ($old_folder == $filters[$i]['folder']) {
                 if ($action == 'rename') {
@@ -905,16 +746,125 @@ function update_for_folder ($args) {
         }
     }
 }
-
-/**
- * Display formated error message
- * @param string $string text message
- * @return string html formated text message
- * @access private
+/*
+ * Function extracted from sqimap_get_small_header_list.
+ * The unused FETCH arguments and HEADERS are disabled.
  */
-function do_error($string) {
-    global $color;
-    echo "<p align=\"center\"><font color=\"$color[2]\">";
-    echo $string;
-    echo "</font></p>\n";
+function filter_get_headers ($imap_stream, $query) {
+    global $uid_support;
+    /* Get the small headers for each message in $msg_list */
+
+    $read_list = sqimap_run_command_list ($imap_stream, $query, false, $response, $message, $uid_support);
+
+    if (isset($response) && $response != 'OK') {
+        return false;
+    }
+
+
+    foreach ($read_list as $r) {
+        $read = implode('',$r);
+        /* 
+            * #id<space>FETCH<space>(
+        */
+        /* extract the message id */
+        $i_space = strpos($read,' ',2);
+        $id = substr($read,2,$i_space-2);
+        $fetch = substr($read,$i_space+1,5);
+        if (!is_numeric($id) && $fetch !== 'FETCH') {
+            set_up_language($squirrelmail_language);
+            echo '<br><b><font color=$color[2]>' .
+                 _("ERROR : Could not complete request.") .
+                 '</b><br>' .
+                 _("Unknown response from IMAP server: ") . ' 1.' .
+                 htmlspecialchars($read) . "</font><br>\n";
+                 break;
+        }
+        $i = strpos($read,'(',$i_space+5);
+        $read = substr($read,$i+1);
+        $i_len = strlen($read);
+        $i = 0;
+        while ($i < $i_len && $i !== false) {
+            /* get argument */
+            $read = trim(substr($read,$i));
+            $i_len = strlen($read);
+            $i = strpos($read,' ');
+            $arg = substr($read,0,$i);
+            ++$i;
+            switch ($arg)
+            {
+            case 'UID':
+                $i_pos = strpos($read,' ',$i);
+                if (!$i_pos) {
+                    $i_pos = strpos($read,')',$i);
+                }
+                if ($i_pos) {
+                    $unique_id = substr($read,$i,$i_pos-$i);
+                    $i = $i_pos+1;
+                } else {
+                    break 3;
+                }
+                $msgs[$id]['UID'] = $unique_id;
+                break;
+            // case 'FLAGS':
+            //    $flags = parseArray($read,$i);
+            //    if (!$flags) break 3;
+            //    $msgs[$id]['FLAGS'] = $flags;
+            //    break;
+            // case 'RFC822.SIZE':
+            //    $i_pos = strpos($read,' ',$i);
+            //    if (!$i_pos) {
+            //        $i_pos = strpos($read,')',$i);
+            //    }
+            //    if ($i_pos) {
+            //        $size = substr($read,$i,$i_pos-$i);
+            //        $i = $i_pos+1;
+            //    } else {
+            //        break 3;
+            //    }
+            //    $msgs[$id]['SIZE'] = $size;
+            //    
+            //    break;
+            // case 'INTERNALDATE':
+            //    $msgs[$id]['INTERNALDATE'] = parseString($read,$i);
+            //    break;
+            case 'BODY.PEEK[HEADER.FIELDS':
+            case 'BODY[HEADER.FIELDS':
+                $i = strpos($read,'{',$i);
+                $header = parseString($read,$i);
+                if ($header === false) break 3;
+                /* First we unfold the header */
+                $hdr = trim(str_replace(array("\r\n\t", "\r\n "),array('', ''), $header));
+                /* Now we can make a new header array with */
+                /* each element representing a headerline  */
+                $hdr = explode("\r\n" , $hdr);
+                foreach ($hdr as $line) {
+                    $pos = strpos($line, ':');
+                    if ($pos > 0) {
+                        $field = strtolower(substr($line, 0, $pos));
+                        if (!strstr($field,' ')) { /* valid field */
+                            $value = trim(substr($line, $pos+1));
+                            switch($field) {
+                            case 'received':    $msgs[$id]['HEADER']['Received'][] =       $value; break;
+                            // case 'to':          $msgs[$id]['HEADER']['To']=             $value; break;
+                            // case 'cc':          $msgs[$id]['HEADER']['Cc'] =            $value; break;
+                            // case 'from':        $msgs[$id]['HEADER']['From'] =          $value; break;
+                            // case 'date':        $msgs[$id]['HEADER']['Date'] =          $value; break;
+                            // case 'x-priority':  $msgs[$id]['HEADER']['Prio'] =          $value; break;
+                            // case 'subject':     $msgs[$id]['HEADER']['Subject'] =       $value; break;
+                            // case 'content-type':$msgs[$id]['HEADER']['Content-Type'] =  $value; break;
+                            default: break;
+                            }
+                        }
+                    }
+                }
+                break;
+            default:
+                ++$i;
+                break;
+            }
+        }
+    }
+    return $msgs;
 }
+
+?>
\ No newline at end of file
