@@ -1,6 +1,10 @@
 <?php
+
 /**
- * Message and Spam Filter Plugin - Filtering Options
+ * Message and Spam Filter Plugin
+ *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This plugin filters your inbox into different folders based upon given
  * criteria. It is most useful for people who are subscibed to mailing lists
@@ -18,17 +22,12 @@
  *
  * Also view plugins/README.plugins for more information.
  *
- * @version $Id: options.php 14800 2019-01-08 04:27:15Z pdontthink $
- * @copyright (c) 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * $Id: options.php,v 1.30 2003/12/01 21:56:49 cigamit Exp $
  * @package plugins
  * @subpackage filters
  */
 
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../../');
 
 /* SquirrelMail required files. */
@@ -37,7 +36,6 @@ require_once(SM_PATH . 'functions/page_header.php');
 require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'functions/imap_mailbox.php');
 require_once(SM_PATH . 'include/load_prefs.php');
-require_once(SM_PATH . 'functions/forms.php');
 require_once(SM_PATH . 'plugins/filters/filters.php');
 
 global $AllowSpamFilters;
@@ -52,66 +50,44 @@ sqgetGlobalVar('delimiter', $delimiter, SQ_SESSION);
 
 sqgetGlobalVar('theid', $theid);
 sqgetGlobalVar('action', $action, SQ_GET);
-global $imap_stream_options; // in case not defined in config
 
-if (sqgetGlobalVar('filter_submit',$filter_submit,SQ_POST)) {
+// FIXME: use sqgetGlobalVar below.
 
-    if(! isset($theid) ) $theid = 0;
+   if (isset($_POST['filter_submit'])) {
+      if(isset($_GET['theid'])) {
+          $theid = $_GET['theid'];
+      } elseif (isset($_POST['theid'])) {
+          $theid = $_POST['theid'];
+      } else {
+          $theid = 0;
+      }
+      $filter_what   = $_POST['filter_what'];
+      $filter_where  = $_POST['filter_where'];
+      $filter_folder = $_POST['filter_folder'];
 
-    $complete_post=true;
+      $filter_what = str_replace(',', ' ', $filter_what);
+      $filter_what = str_replace("\\\\", "\\", $filter_what);
+      $filter_what = str_replace("\\\"", '"', $filter_what);
+      $filter_what = str_replace('"', '&quot;', $filter_what);
 
-    // FIXME: write human readable error messages
-    sqgetGlobalVar('filter_what', $filter_what, SQ_POST);
-    if (!sqgetGlobalVar('filter_what', $filter_what, SQ_POST)) {
-        do_error("Post error");
-        $complete_post=false;
-    }
-
-    sqgetGlobalVar('filter_where', $filter_where, SQ_POST);
-    if (!sqgetGlobalVar('filter_where', $filter_where, SQ_POST)) {
-        do_error("Post error");
-        $complete_post=false;
-    }
-
-    sqgetGlobalVar('filter_folder', $filter_folder, SQ_POST);
-    if (!sqgetGlobalVar('filter_folder', $filter_folder, SQ_POST)) {
-        do_error("Post error");
-        $complete_post=false;
-    }
-
-    if ($complete_post) {
-        $filter_what = str_replace(',', '###COMMA###', $filter_what);
-        $filter_what = str_replace("\\\\", "\\", $filter_what);
-        $filter_what = str_replace("\\\"", '"', $filter_what);
-        $filter_what = str_replace('"', '&quot;', $filter_what);
-
-        if (empty($filter_what)) {
-            do_error(_("WARNING! You must enter something to search for."));
-            $action = 'edit';
-        }
-
-        if (($filter_where == 'Header') && (strchr($filter_what,':') == '')) {
-            do_error(_("WARNING! Header filters should be of the format &quot;Header: value&quot;"));
-            $action = 'edit';
-        }
-        if ($action != 'edit') {
-            setPref($data_dir, $username, 'filter'.$theid, $filter_where.','.$filter_what.','.$filter_folder);
-        }
-        $filters[$theid]['where'] = $filter_where;
-        $filters[$theid]['what'] = $filter_what;
-        $filters[$theid]['folder'] = $filter_folder;
-    }
-} elseif (isset($action) && $action == 'delete') {
+      if (($filter_where == 'Header') && (strchr($filter_what,':') == '')) {
+         print ('WARNING! Header filters should be of the format "Header: value"<BR>');
+	 $action = 'edit';
+      }
+      setPref($data_dir, $username, 'filter'.$theid, $filter_where.','.$filter_what.','.$filter_folder);
+      $filters[$theid]['where'] = $filter_where;
+      $filters[$theid]['what'] = $filter_what;
+      $filters[$theid]['folder'] = $filter_folder;
+   } elseif (isset($action) && $action == 'delete') {
       remove_filter($theid);
-} elseif (isset($action) && $action == 'move_up') {
+   } elseif (isset($action) && $action == 'move_up') {
       filter_swap($theid, $theid - 1);
-} elseif (isset($action) && $action == 'move_down') {
+   } elseif (isset($action) && $action == 'move_down') {
       filter_swap($theid, $theid + 1);
-} elseif (sqgetGlobalVar('user_submit',$user_submit,SQ_POST)) {
-    sqgetGlobalVar('filters_user_scan_set',$filters_user_scan_set,SQ_POST);
-    setPref($data_dir, $username, 'filters_user_scan', $filters_user_scan_set);
-    echo '<br /><center><b>'._("Saved Scan type")."</b></center>\n";
-}
+   } elseif (isset($_POST['user_submit'])) {
+       setPref($data_dir, $username, 'filters_user_scan', $_POST['filters_user_scan_set']);
+       echo '<br><center><b>'._("Saved Scan type")."</b></center>\n";
+   }
 
    $filters = load_filters();
    $filters_user_scan = getPref($data_dir, $username, 'filters_user_scan');
@@ -119,13 +95,12 @@ if (sqgetGlobalVar('filter_submit',$filter_submit,SQ_POST)) {
    echo html_tag( 'table',
             html_tag( 'tr',
                 html_tag( 'td',
-                    '<center><b>' . _("Options") . ' - ' . _("Message Filtering") . '</b></center>' ,
-                    'left', $color[0]
-                )
-            ),
-            'center', '', 'width="95%" border="0" cellpadding="2" cellspacing="0"'
-        ) .
-        '<br /><form method="post" action="options.php">'.
+                    '<center><b>' . _("Options") . ' -  ' . _("Message Filtering") . '</b></center>' ,
+                'left', $color[0] )
+            ) ,
+         'center', '', 'width="95%" border="0" cellpadding="2" cellspacing="0"' ) .
+
+        '<br><form method=post action="options.php">'.
         '<center>'.
         html_tag( 'table', '', '', '', 'border="0" cellpadding="2" cellspacing="0"' ) .
             html_tag( 'tr' ) .
@@ -144,57 +119,50 @@ if (sqgetGlobalVar('filter_submit',$filter_submit,SQ_POST)) {
     echo '>' . _("Only unread messages") . '</option>' .
             '</select>'.
         '</td>'.
-        html_tag( 'td', '<input type="submit" name="user_submit" value="' . _("Save") . '" />', 'left' ) .
+        html_tag( 'td', '<input type=submit name="user_submit" value="' . _("Save") . '">', 'left' ) .
         '</table>'.
         '</center>'.
         '</form>'.
 
         html_tag( 'div', '[<a href="options.php?action=add">' . _("New") .
             '</a>] - [<a href="'.SM_PATH.'src/options.php">' . _("Done") . '</a>]' ,
-        'center' ) . '<br />';
+        'center' ) . '<br>';
 
     if (isset($action) && ($action == 'add' || $action == 'edit')) {
 
-        $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
+        $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
         $boxes = sqimap_mailbox_list($imapConnection);
-
-        for ($a = 0, $cnt = count($boxes); $a < $cnt; $a++) {
-            if (strtolower($boxes[$a]['formatted']) == 'inbox') {
-                unset($boxes[$a]);
-            }
-        }
-
         sqimap_logout($imapConnection);
         if ( !isset($theid) ) {
             $theid = count($filters);
         }
         echo html_tag( 'div', '', 'center' ) .
-             '<form action="options.php" method="post">'.
+             '<form action="options.php" method=post>'.
              html_tag( 'table', '', '', '', 'border="0" cellpadding="2" cellspacing="0"' ) .
              html_tag( 'tr' ) .
                 html_tag( 'td', _("Match:"), 'left' ) .
                 html_tag( 'td', '', 'left' ) .
-                    '<select name="filter_where">';
+                    '<select name=filter_where>';
 
         $L = isset($filters[$theid]['where']);
 
         $sel = (($L && $filters[$theid]['where'] == 'From')?'selected':'');
-        echo "<option value=\"From\" $sel>" . _("From") . '</option>';
+        echo "<option value=\"From\" $sel>" . _ ("From") . '</option>';
 
         $sel = (($L && $filters[$theid]['where'] == 'To')?'selected':'');
-        echo "<option value=\"To\" $sel>" . _("To") . '</option>';
+        echo "<option value=\"To\" $sel>" . _ ("To") . '</option>';
 
         $sel = (($L && $filters[$theid]['where'] == 'Cc')?'selected':'');
-        echo "<option value=\"Cc\" $sel>" . _("Cc") . '</option>';
+        echo "<option value=\"Cc\" $sel>" . _ ("Cc") . '</option>';
 
         $sel = (($L && $filters[$theid]['where'] == 'To or Cc')?'selected':'');
-        echo "<option value=\"To or Cc\" $sel>" . _("To or Cc") . '</option>';
+        echo "<option value=\"To or Cc\" $sel>" . _ ("To or Cc") . '</option>';
 
         $sel = (($L && $filters[$theid]['where'] == 'Subject')?'selected':'');
-        echo "<option value=\"Subject\" $sel>" . _("Subject") . '</option>';
+        echo "<option value=\"Subject\" $sel>" . _ ("Subject") . '</option>';
 
         $sel = (($L && $filters[$theid]['where'] == 'Header')?'selected':'');
-        echo "<option value=\"Header\" $sel>" . _("Header") . '</option>';
+        echo "<option value=\"Header\" $sel>" . _ ("Header") . '</option>';
 
         echo         '</select>'.
                 '</td>'.
@@ -202,18 +170,18 @@ if (sqgetGlobalVar('filter_submit',$filter_submit,SQ_POST)) {
             html_tag( 'tr' ) .
                 html_tag( 'td', _("Contains:"), 'right' ) .
                 html_tag( 'td', '', 'left' ) .
-                    '<input type="text" size="32" name="filter_what" value="';
+                    '<input type=text size=32 name=filter_what value="';
         if (isset($filters[$theid]['what'])) {
-            echo sm_encode_html_special_chars($filters[$theid]['what']);
+            echo $filters[$theid]["what"];
         }
-        echo '" />'.
+        echo '">'.
                 '</td>'.
             '</tr>'.
             html_tag( 'tr' ) .
                 html_tag( 'td', _("Move to:"), 'left' ) .
                 html_tag( 'td', '', 'left' ) .
                     '<tt>'.
-                    '<select name="filter_folder">';
+                    '<select name=filter_folder>';
         $selected = 0;
         if ( isset($filters[$theid]['folder']) )
           $selected = array(strtolower($filters[$theid]['folder']));
@@ -223,14 +191,14 @@ if (sqgetGlobalVar('filter_submit',$filter_submit,SQ_POST)) {
                 '</td>'.
             '</tr>'.
             '</table>'.
-            '<input type="submit" name="filter_submit" value="' . _("Submit") . "\" />\n".
-            addHidden('theid', $theid).
+            '<input type=submit name=filter_submit value=' . _("Submit") . '>'.
+            "<input type=hidden name=theid value=$theid>".
             '</form>'.
             '</div>';
 
     }
 
-    echo html_tag( 'table', '', 'center', '', 'border="0" cellpadding="3" cellspacing="0"' );
+	echo html_tag( 'table', '', 'center', '', 'border="0" cellpadding="3" cellspacing="0"' );
 
     for ($i=0, $num = count($filters); $i < $num; $i++) {
 
@@ -239,34 +207,29 @@ if (sqgetGlobalVar('filter_submit',$filter_submit,SQ_POST)) {
         echo html_tag( 'tr', '', '', $clr ) .
                    html_tag( 'td',
                        '<small>' .
-                       "[<a href=\"options.php?theid=$i&amp;action=edit\">" . _("Edit") . '</a>]'.
+                       "[<a href=\"options.php?theid=$i&action=edit\">" . _("Edit") . '</a>]'.
                        '</small>' ,
                    'left' ) .
                    html_tag( 'td',
                        '<small>' .
-                       "[<a href=\"options.php?theid=$i&amp;action=delete\">" . _("Delete") . '</a>]'.
+                       "[<a href=\"options.php?theid=$i&action=delete\">" . _("Delete") . '</a>]'.
                        '</small>' ,
-                   'left' );
+                   'left' ) .
+                   html_tag( 'td', '', 'center' ) . '<small>[';
 
-        if ($num > 1) {
-            echo html_tag( 'td', '', 'center' ) . '<small>[';
-            if (isset($filters[$i + 1])) {
-                echo "<a href=\"options.php?theid=$i&amp;action=move_down\">" . _("Down") . '</a>';
-                if ($i > 0) {
-                    echo '&nbsp;|&nbsp;';
-                }
-            }
+        if (isset($filters[$i + 1])) {
+            echo "<a href=\"options.php?theid=$i&action=move_down\">" . _("Down") . '</a>';
             if ($i > 0) {
-                echo "<a href=\"options.php?theid=$i&amp;action=move_up\">" . _("Up") . '</a>';
+                echo '&nbsp;|&nbsp;';
             }
-            echo ']</small></td>';
         }
-        echo html_tag( 'td', '-', 'left' ) .
-             html_tag( 'td', '', 'left' );
-        printf( _("If %s contains %s then move to %s"),
-            '<b>'.$filters[$i]['where'].'</b>',
-            '<b>'.$filters[$i]['what'].'</b>',
-            '<b>'.sm_encode_html_special_chars(imap_utf7_decode_local($fdr)).'</b>');
+        if ($i > 0) {
+            echo "<a href=\"options.php?theid=$i&action=move_up\">" . _("Up") . '</a>';
+        }
+        echo ']</small></td>'.
+            html_tag( 'td', '-', 'left' ) .
+            html_tag( 'td', '', 'left' );
+        printf( _("If <b>%s</b> contains <b>%s</b> then move to <b>%s</b>"), _($filters[$i]['where']), $filters[$i]['what'], $fdr );
         echo '</td></tr>';
 
     }
@@ -277,4 +240,4 @@ if (sqgetGlobalVar('filter_submit',$filter_submit,SQ_POST)) {
             ) ,
         'center', '', 'width="80%" border="0" cellpadding="2" cellspacing="0"' );
     echo '</body></html>';
-?>
+?>
\ No newline at end of file
