@@ -1,6 +1,9 @@
 <?php
 /**
- * Message and Spam Filter Plugin - Spam Options
+ * Message and Spam Filter Plugin
+ *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This plugin filters your inbox into different folders based upon given
  * criteria.  It is most useful for people who are subscibed to mailing lists
@@ -18,17 +21,12 @@
  *
  * Also view plugins/README.plugins for more information.
  *
- * @version $Id: spamoptions.php 14800 2019-01-08 04:27:15Z pdontthink $
- * @copyright (c) 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
+ * $Id: spamoptions.php,v 1.19 2003/12/01 21:56:49 cigamit Exp $
  * @package plugins
  * @subpackage filters
  */
 
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../../');
 
 /* SquirrelMail required files. */
@@ -47,34 +45,19 @@ sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
 sqgetGlobalVar('delimiter', $delimiter, SQ_SESSION);
 
 sqgetGlobalVar('action', $action, SQ_GET);
-global $imap_stream_options; // in case not defined in config
 /* end globals */
 
 displayPageHeader($color, 'None');
 
-if (sqgetGlobalVar('spam_submit',$spam_submit,SQ_POST)) {
+if (isset($_POST['spam_submit'])) {
     $spam_filters = load_spam_filters();
-
-    // setting spam folder    
-    sqgetGlobalVar('filters_spam_folder_set',$filters_spam_folder_set,SQ_POST);
-    if (isset($filters_spam_folder_set)) {
-        setPref($data_dir, $username, 'filters_spam_folder', $filters_spam_folder_set);
-    } else {
-	echo _("You must select a spam folder.");
-    }
-
-    // setting scan type
-    sqgetGlobalVar('filters_spam_scan_set',$filters_spam_scan_set,SQ_POST);
-    if (isset($filters_spam_scan_set)) {
-	setPref($data_dir, $username, 'filters_spam_scan', $filters_spam_scan_set);
-    } else {
-	echo _("You must select a scan type.");
-    }
-
+    setPref($data_dir, $username, 'filters_spam_folder', $_POST['filters_spam_folder_set']);
+    setPref($data_dir, $username, 'filters_spam_scan', $_POST['filters_spam_scan_set']);
     foreach ($spam_filters as $Key => $Value) {
         $input = $spam_filters[$Key]['prefname'] . '_set';
-        if ( sqgetGlobalVar($input,$input_key,SQ_POST) ) {
-            setPref( $data_dir, $username, $spam_filters[$Key]['prefname'],$input_key);
+        if ( isset( $_POST[$input] ) ) {
+            setPref( $data_dir, $username, $spam_filters[$Key]['prefname'],
+                     $_POST[$input]);
         } else {
             removePref($data_dir, $username, $spam_filters[$Key]['prefname']);
         }
@@ -92,17 +75,17 @@ echo html_tag( 'table',
         'center', $color[0], 'width="95%" border="0" cellpadding="2" cellspacing="0"' );
 
 if ($SpamFilters_YourHop == ' ') {
-    echo '<br />' .
+    echo '<br>' .
         html_tag( 'div', '<b>' .
-            sprintf(_("WARNING! Tell the administrator to set the %s variable."), '&quot;SpamFilters_YourHop&quot;') .
+            _("WARNING! Tell your admin to set the SpamFilters_YourHop variable") .
             '</b>' ,
         'center' ) .
-        '<br />';
+        '<br>';
 }
 
 
 if (isset($action) && $action == 'spam') {
-    $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
+    $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
     $boxes = sqimap_mailbox_list($imapConnection);
     sqimap_logout($imapConnection);
     $numboxes = count($boxes);
@@ -115,7 +98,7 @@ if (isset($action) && $action == 'spam') {
         }
     }
 
-    echo '<form method="post" action="spamoptions.php">'.
+    echo '<form method=post action="spamoptions.php">'.
         '<center>'.
         html_tag( 'table', '', '', '', 'width="85%" border="0" cellpadding="2" cellspacing="0"' ) .
             html_tag( 'tr' ) .
@@ -142,21 +125,21 @@ if (isset($action) && $action == 'spam') {
             '<select name="filters_spam_scan_set">'.
             '<option value=""';
     if ($filters_spam_scan == '') {
-        echo ' selected="selected"';
+        echo ' SELECTED';
     }
     echo '>' . _("All messages") . '</option>'.
             '<option value="new"';
     if ($filters_spam_scan == 'new') {
-        echo ' selected="selected"';
+        echo ' SELECTED';
     }
-    echo '>' . _("Unread messages only") . '</option>' .
+    echo '>' . _("Only unread messages") . '</option>' .
             '</select>'.
         '</td>'.
     '</tr>'.
     html_tag( 'tr',
           html_tag( 'td', '&nbsp;' ) .
           html_tag( 'td',
-              _("The more messages scanned, the longer it takes. It's recommended to scan unread messages only. If a change to the filters is made, it's recommended to set it to scan all messages, then go view the INBOX, then come back and set it to scan unread messages only. That way, the new spam filters will be applied and even the spam you didn't catch with the old filters will be scanned.") ,
+              _("The more messages you scan, the longer it takes.  I would suggest that you scan only new messages.  If you make a change to your filters, I would set it to scan all messages, then go view my INBOX, then come back and set it to scan only new messages.  That way, your new spam filters will be applied and you'll scan even the spam you read with the new filters.") ,
           'left' )
       );
 
@@ -166,13 +149,13 @@ if (isset($action) && $action == 'spam') {
         echo html_tag( 'tr' ) .
                    html_tag( 'th', $Key, 'right', '', 'nowrap' ) ."\n" .
                    html_tag( 'td' ) .
-            '<input type="checkbox" name="' .
+            '<input type=checkbox name="' .
             $spam_filters[$Key]['prefname'] .
             '_set"';
         if ($spam_filters[$Key]['enabled']) {
-            echo ' checked="checked"';
+            echo ' CHECKED';
         }
-        echo ' /> - ';
+        echo '> - ';
         if ($spam_filters[$Key]['link']) {
             echo '<a href="' .
                  $spam_filters[$Key]['link'] .
@@ -190,21 +173,24 @@ if (isset($action) && $action == 'spam') {
 
     }
     echo html_tag( 'tr',
-        html_tag( 'td', '<input type="submit" name="spam_submit" value="' . _("Save") . '" />', 'center', '', 'colspan="2"' )
+        html_tag( 'td', '<input type=submit name="spam_submit" value="' . _("Save") . '">', 'center', '', 'colspan="2"' )
     ) . "\n" .
         '</table>'.
         '</center>'.
         '</form>';
-} else {
-    // action is not set or action is not spam
+    echo '</body></html>';
+}
+
+if (! isset($_GET['action']) || $_GET['action'] != 'spam') {
+
     echo html_tag( 'p', '', 'center' ) .
          '[<a href="spamoptions.php?action=spam">' . _("Edit") . '</a>]' .
-         ' - [<a href="../../src/options.php">' . _("Done") . '</a>]</center><br /><br />';
-    printf( _("Spam is sent to %s."), ($filters_spam_folder?'<b>'.sm_encode_html_special_chars(imap_utf7_decode_local($filters_spam_folder)).'</b>':'[<i>'._("not set yet").'</i>]' ) );
-    echo '<br />';
-    printf( _("Spam scan is limited to %s."), '<b>' . ( ($filters_spam_scan == 'new')?_("Unread messages only"):_("All messages") ) . '</b>' );
+         ' - [<a href="../../src/options.php">' . _("Done") . '</a>]</center><br><br>';
+    printf( _("Spam is sent to <b>%s</b>"), ($filters_spam_folder?$filters_spam_folder:_("[<i>not set yet</i>]") ) );
+    echo '<br>';
+    printf( _("Spam scan is limited to <b>%s</b>"), (($filters_spam_scan == 'new')?_("New Messages Only"):_("All Messages") ) );
     echo '</p>'.
-        '<table border="0" cellpadding="3" cellspacing="0" align="center" bgcolor="' . $color[0] . "\">\n";
+        "<table border=0 cellpadding=3 cellspacing=0 align=center bgcolor=\"$color[0]\">";
 
     $spam_filters = load_spam_filters();
 
@@ -235,6 +221,7 @@ if (isset($action) && $action == 'spam') {
         echo "</td></tr>\n";
     }
     echo '</table>';
+    echo '</body></html>';
 }
-?>
-</body></html>
+
+?>
\ No newline at end of file
