@@ -1,15 +1,17 @@
 <?php
 
-/* setup file for the IMAP server info plugin
- * Copyright (c) 1999-2019 The SquirrelMail Project Team
+/** setup file for the IMAP server info plugin
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *   
  * by: Jason Munro jason@stdbev.com
  * 
- * $Id: setup.php 14800 2019-01-08 04:27:15Z pdontthink $
- * 
+ * $Id: setup.php,v 1.5 2003/10/27 22:24:39 tassium Exp $
+ * @package plugins
+ * @subpackage info
  */
 
+/** @ignore */
 require_once (SM_PATH . 'plugins/info/functions.php');
 
 function squirrelmail_plugin_init_info() {
@@ -23,8 +25,9 @@ function info_opt() {
     $optpage_blocks[] = array(
         'name' => _("IMAP server information"),
         'url'  => '../plugins/info/options.php',
-        'desc' => _("Run some test IMAP commands, displaying both the command and the result. These tests use the SquirrelMail IMAP commands and your current SquirrelMail configuration. Custom command strings can be used."),
+        'desc' => _("Run some test IMAP commands, displaying both the command and the result. These tests use the Squirrelmail IMAP commands and your current Squirrelmail configuration. Custom command strings can be used."),
         'js'   => false
     );
 }
 
+?>
