@@ -3,7 +3,7 @@
 /**
  * setup.php
  *
- * Copyright (c) 1999-2019 The SquirrelMail Project Team
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * Implementation of RFC 2369 for SquirrelMail.
@@ -11,11 +11,14 @@
  * this plugin displays a menu which gives the user a choice of mailinglist
  * commands such as (un)subscribe, help and list archives.
  *
- * $Id: setup.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: setup.php,v 1.28 2003/11/01 17:36:16 alex-brainstorm Exp $
  * @package plugins
  * @subpackage listcommands
  */
 
+/**
+ * Initialize the listcommands plugin
+ */
 function squirrelmail_plugin_init_listcommands () {
     global $squirrelmail_plugin_hooks;
 
@@ -23,8 +26,7 @@ function squirrelmail_plugin_init_listcommands () {
 }
 
 function plugin_listcommands_menu() {
-    global $passed_id, $passed_ent_id, $color, $mailbox,
-           $message, $compose_new_win, $startMessage;
+    global $passed_id, $passed_ent_id, $color, $mailbox, $message;
 
     /**
      * Array of commands we can deal with from the header. The Reply option
@@ -41,64 +43,38 @@ function plugin_listcommands_menu() {
 
     foreach ($message->rfc822_header->mlist as $cmd => $actions) {
 
-        /* I don't know this action... skip it */
-        if ( !array_key_exists($cmd, $fieldsdescr) ) {
+	/* I don't know this action... skip it */
+	if ( ( function_exists('array_key_exists') &&       /* PHP >= 4.1 */
+               !array_key_exists($cmd, $fieldsdescr) ) ||
+             ( function_exists('key_exists') && 
+               !key_exists($cmd, $fieldsdescr) )            /* PHP == 4.0.6 */
+        ) {
             continue;
         }
 
         /* proto = {mailto,href} */
-        $aActionKeys = array_keys($actions);
-        // note that we only use the first cmd/action, ignore the rest
-        $proto = array_shift($aActionKeys);
-        $act   = array_shift($actions);
+	$proto = array_shift(array_keys($actions));
+	$act   = array_shift($actions);
 
         if ($proto == 'mailto') {
 
-            $identity = '';
-
             if (($cmd == 'post') || ($cmd == 'owner')) {
-                $url = 'src/compose.php?' .
-                (isset($startMessage)?'startMessage='.$startMessage.'&amp;':'');
+                $url = 'src/compose.php?';
             } else {
                 $url = "plugins/listcommands/mailout.php?action=$cmd&amp;";
-
-                // try to find which identity the mail should come from
-                include_once(SM_PATH . 'functions/identity.php');
-                $idents = get_identities();
-                // ripped from src/compose.php
-                $identities = array();
-                if (count($idents) > 1) {
-                    foreach($idents as $nr=>$data) {
-                        $enc_from_name = '"'.$data['full_name'].'" <'. $data['email_address'].'>';
-                        $identities[] = $enc_from_name;
-                    }
-
-                    $identity_match = $message->rfc822_header->findAddress($identities);
-                    if ($identity_match !== FALSE) {
-                        $identity = $identity_match;
-                    }
-                }
             }
-
-            // if things like subject are given, peel them off and give
-            // them to src/compose.php as is (not encoded)
-            if (strpos($act, '?') > 0) {
-               list($act, $parameters) = explode('?', $act, 2);
-               $parameters = '&amp;identity=' . $identity . '&amp;' . $parameters;
-            } else {
-               $parameters = '&amp;identity=' . $identity;
-            }
-
-            $url .= 'send_to=' . urlencode($act) . $parameters;
+            $url .= 'send_to=' . strtr($act,'?','&');
 
             $output[] = makeComposeLink($url, $fieldsdescr[$cmd]);
 
             if ($cmd == 'post') {
-                $url .= '&amp;passed_id='.$passed_id.
-                    '&amp;mailbox='.urlencode($mailbox).
-                    (isset($passed_ent_id)?'&amp;passed_ent_id='.$passed_ent_id:'');
+                if (!isset($mailbox))
+                    $mailbox = 'INBOX';
+	        $url .= '&amp;passed_id='.$passed_id.
+		        '&amp;mailbox='.urlencode($mailbox).
+		        (isset($passed_ent_id)?'&amp;passed_ent_id='.$passed_ent_id:'');
                 $url .= '&amp;smaction=reply';
-                
+
                 $output[] = makeComposeLink($url, $fieldsdescr['reply']);
             }
         } else if ($proto == 'href') {
@@ -117,3 +93,4 @@ function plugin_listcommands_menu() {
     }
 }
 
+?>
