@@ -1,23 +1,27 @@
-<?php
+<?php 
+
+   /**
+    * mail_fetch/setup.php
+    *
+    * Copyright (c) 1999-2003 The SquirrelMail Project Team
+    *
+    * Copyright (c) 1999 CDI (cdi@thewebmasters.net) All Rights Reserved
+    * Modified by Philippe Mingo 2001 mingo@rotedic.com
+    * An RFC 1939 compliant wrapper class for the POP3 protocol.
+    *
+    * Licensed under the GNU GPL. For full terms see the file COPYING.
+    *
+    * pop3 class
+    *
+    * $Id: class.POP3.php,v 1.15 2003/12/05 03:48:02 cigamit Exp $
+    * @package plugins
+    * @subpackage mail_fetch
+    */
 
 /**
- * mail_fetch/setup.php
- *
- * Copyright (c) 1999-2012 CDI (cdi@thewebmasters.net) All Rights Reserved
- * Modified by Philippe Mingo 2001-2009 mingo@rotedic.com
- * An RFC 1939 compliant wrapper class for the POP3 protocol.
- *
- * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
- * POP3 class
- *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: class.POP3.php 14800 2019-01-08 04:27:15Z pdontthink $
- * @package plugins
- * @subpackage mail_fetch
+ * This is the pop3 class - DOCUMENT ME
+ * @package squirrelmail
  */
-
 class POP3 {
     var $ERROR      = '';       //  Error string.
 
@@ -81,7 +85,7 @@ class POP3 {
             $server = $this->MAILSERVER;
 
         if(empty($server)){
-            $this->ERROR = "POP3 connect: " . _("No server specified");
+            $this->ERROR = _("POP3 connect:") . ' ' . _("No server specified");
             unset($this->FP);
             return false;
         }
@@ -89,7 +93,7 @@ class POP3 {
         $fp = @fsockopen("$server", $port, $errno, $errstr);
 
         if(!$fp) {
-            $this->ERROR = "POP3 connect: " . _("Error ") . "[$errno] [$errstr]";
+            $this->ERROR = _("POP3 connect:") . ' ' . _("Error ") . "[$errno] [$errstr]";
             unset($this->FP);
             return false;
         }
@@ -101,7 +105,7 @@ class POP3 {
         if($this->DEBUG)
             error_log("POP3 SEND [connect: $server] GOT [$reply]",0);
         if(!$this->is_ok($reply)) {
-            $this->ERROR = "POP3 connect: " . _("Error ") . "[$reply]";
+            $this->ERROR = _("POP3 connect:") . ' ' . _("Error ") . "[$reply]";
             unset($this->FP);
             return false;
         }
@@ -114,15 +118,15 @@ class POP3 {
         // Sends the USER command, returns true or false
 
         if( empty($user) ) {
-            $this->ERROR = "POP3 user: " . _("no login ID submitted");
+            $this->ERROR = _("POP3 user:") . ' ' . _("no login ID submitted");
             return false;
         } elseif(!isset($this->FP)) {
-            $this->ERROR = "POP3 user: " . _("connection not established");
+            $this->ERROR = _("POP3 user:") . ' ' . _("connection not established");
             return false;
         } else {
             $reply = $this->send_cmd("USER $user");
             if(!$this->is_ok($reply)) {
-                $this->ERROR = "POP3 user: " . _("Error ") . "[$reply]";
+                $this->ERROR = _("POP3 user:") . ' ' . _("Error ") . "[$reply]";
                 return false;
             } else
                 return true;
@@ -134,15 +138,15 @@ class POP3 {
         // returns false (undef) on Auth failure
 
         if(empty($pass)) {
-            $this->ERROR = "POP3 pass: " . _("No password submitted");
+            $this->ERROR = _("POP3 pass:") . ' ' . _("No password submitted");
             return false;
         } elseif(!isset($this->FP)) {
-            $this->ERROR = "POP3 pass: " . _("connection not established");
+            $this->ERROR = _("POP3 pass:") . ' ' . _("connection not established");
             return false;
         } else {
             $reply = $this->send_cmd("PASS $pass");
             if(!$this->is_ok($reply)) {
-                $this->ERROR = "POP3 pass: " . _("Authentication failed") . " [$reply]";
+                $this->ERROR = _("POP3 pass:") . ' ' . _("authentication failed ") . "[$reply]";
                 $this->quit();
                 return false;
             } else {
@@ -161,21 +165,21 @@ class POP3 {
         //  (apop is optional per rfc1939)
 
         if(!isset($this->FP)) {
-            $this->ERROR = "POP3 apop: " . _("No connection to server");
+            $this->ERROR = _("POP3 apop:") . ' ' . _("No connection to server");
             return false;
         } elseif(!$this->ALLOWAPOP) {
             $retVal = $this->login($login,$pass);
             return $retVal;
         } elseif(empty($login)) {
-            $this->ERROR = "POP3 apop: " . _("No login ID submitted");
+            $this->ERROR = _("POP3 apop:") . ' ' . _("No login ID submitted");
             return false;
         } elseif(empty($pass)) {
-            $this->ERROR = "POP3 apop: " . _("No password submitted");
+            $this->ERROR = _("POP3 apop:") . ' ' . _("No password submitted");
             return false;
         } else {
             $banner = $this->BANNER;
             if( (!$banner) or (empty($banner)) ) {
-                $this->ERROR = "POP3 apop: " . _("No server banner") . ' - ' . _("abort");
+                $this->ERROR = _("POP3 apop:") . ' ' . _("No server banner") . ' - ' . _("abort");
                 $retVal = $this->login($login,$pass);
                 return $retVal;
             } else {
@@ -185,7 +189,7 @@ class POP3 {
                 $cmd = "APOP $login $APOPString";
                 $reply = $this->send_cmd($cmd);
                 if(!$this->is_ok($reply)) {
-                    $this->ERROR = "POP3 apop: " . _("apop authentication failed") . ' - ' . _("abort");
+                    $this->ERROR = _("POP3 apop:") . ' ' . _("apop authentication failed") . ' - ' . _("abort");
                     $retVal = $this->login($login,$pass);
                     return $retVal;
                 } else {
@@ -204,7 +208,7 @@ class POP3 {
         // the number of messages.)
 
         if( !isset($this->FP) ) {
-            $this->ERROR = "POP3 login: " . _("No connection to server");
+            $this->ERROR = _("POP3 login:") . ' ' . _("No connection to server");
             return false;
         } else {
             $fp = $this->FP;
@@ -229,7 +233,7 @@ class POP3 {
         //  only the header information, and none of the body.
 
         if(!isset($this->FP)) {
-            $this->ERROR = "POP3 top: " . _("No connection to server");
+            $this->ERROR = _("POP3 top:") . ' ' . _("No connection to server");
             return false;
         }
         $this->update_timer();
@@ -245,7 +249,7 @@ class POP3 {
         }
         if(!$this->is_ok($reply))
         {
-            $this->ERROR = "POP3 top: " . _("Error ") . "[$reply]";
+            $this->ERROR = _("POP3 top:") . ' ' . _("Error ") . "[$reply]";
             return false;
         }
 
@@ -253,7 +257,7 @@ class POP3 {
         $MsgArray = array();
 
         $line = fgets($fp,$buffer);
-        while ( !preg_match('/^\.\r\n/',$line))
+        while ( !ereg("^\.\r\n",$line))
         {
             $MsgArray[$count] = $line;
             $count++;
@@ -271,7 +275,7 @@ class POP3 {
 
         if(!isset($this->FP))
         {
-            $this->ERROR = "POP3 pop_list: " . _("No connection to server");
+            $this->ERROR = _("POP3 pop_list:") . ' ' . _("No connection to server");
             return false;
         }
         $fp = $this->FP;
@@ -299,10 +303,10 @@ class POP3 {
             }
             if(!$this->is_ok($reply))
             {
-                $this->ERROR = "POP3 pop_list: " . _("Error ") . "[$reply]";
+                $this->ERROR = _("POP3 pop_list:") . ' ' . _("Error ") . "[$reply]";
                 return false;
             }
-            list($junk,$num,$size) = preg_split('/\s+/',$reply);
+            list($junk,$num,$size) = explode(" ",$reply);
             return $size;
         }
         $cmd = "LIST";
@@ -310,7 +314,7 @@ class POP3 {
         if(!$this->is_ok($reply))
         {
             $reply = $this->strip_clf($reply);
-            $this->ERROR = "POP3 pop_list: " . _("Error ") .  "[$reply]";
+            $this->ERROR = _("POP3 pop_list:") . ' ' . _("Error ") .  "[$reply]";
             return false;
         }
         $MsgArray = array();
@@ -320,12 +324,12 @@ class POP3 {
             if($msgC > $Total) { break; }
             $line = fgets($fp,$this->BUFFER);
             $line = $this->strip_clf($line);
-            if(strpos($line, '.') === 0)
+            if(ereg("^\.",$line))
             {
-                $this->ERROR = "POP3 pop_list: " . _("Premature end of list");
+                $this->ERROR = _("POP3 pop_list:") . ' ' . _("Premature end of list");
                 return false;
             }
-            list($thisMsg,$msgSize) = preg_split('/\s+/',$line);
+            list($thisMsg,$msgSize) = explode(" ",$line);
             settype($thisMsg,"integer");
             if($thisMsg != $msgC)
             {
@@ -345,7 +349,7 @@ class POP3 {
 
         if(!isset($this->FP))
         {
-            $this->ERROR = "POP3 get: " . _("No connection to server");
+            $this->ERROR = _("POP3 get:") . ' ' . _("No connection to server");
             return false;
         }
 
@@ -358,7 +362,7 @@ class POP3 {
 
         if(!$this->is_ok($reply))
         {
-            $this->ERROR = "POP3 get: " . _("Error ") . "[$reply]";
+            $this->ERROR = _("POP3 get:") . ' ' . _("Error ") . "[$reply]";
             return false;
         }
 
@@ -366,9 +370,8 @@ class POP3 {
         $MsgArray = array();
 
         $line = fgets($fp,$buffer);
-        while ( !preg_match('/^\.\r\n/',$line))
+        while ( !ereg("^\.\r\n",$line))
         {
-            if ( $line{0} == '.' ) { $line = substr($line,1); }
             $MsgArray[$count] = $line;
             $count++;
             $line = fgets($fp,$buffer);
@@ -385,18 +388,18 @@ class POP3 {
         $last = -1;
         if(!isset($this->FP))
         {
-            $this->ERROR = "POP3 last: " . _("No connection to server");
+            $this->ERROR = _("POP3 last:") . ' ' . _("No connection to server");
             return $last;
         }
 
         $reply = $this->send_cmd("STAT");
         if(!$this->is_ok($reply))
         {
-            $this->ERROR = "POP3 last: " . _("Error ") . "[$reply]";
+            $this->ERROR = _("POP3 last:") . ' ' . _("Error ") . "[$reply]";
             return $last;
         }
 
-        $Vars = preg_split('/\s+/',$reply);
+        $Vars = explode(" ",$reply);
         $count = $Vars[1];
         $size = $Vars[2];
         settype($count,"integer");
@@ -415,7 +418,7 @@ class POP3 {
 
         if(!isset($this->FP))
         {
-            $this->ERROR = "POP3 reset: " . _("No connection to server");
+            $this->ERROR = _("POP3 reset:") . ' ' . _("No connection to server");
             return false;
         }
         $reply = $this->send_cmd("RSET");
@@ -425,7 +428,7 @@ class POP3 {
             //  response - if it ever does, something truely
             //  wild is going on.
 
-            $this->ERROR = "POP3 reset: " . _("Error ") . "[$reply]";
+            $this->ERROR = _("POP3 reset:") . ' ' . _("Error ") . "[$reply]";
             @error_log("POP3 reset: ERROR [$reply]",0);
         }
         $this->quit();
@@ -449,13 +452,13 @@ class POP3 {
 
         if(!isset($this->FP))
         {
-            $this->ERROR = "POP3 send_cmd: " . _("No connection to server");
+            $this->ERROR = _("POP3 send_cmd:") . ' ' . _("No connection to server");
             return false;
         }
 
         if(empty($cmd))
         {
-            $this->ERROR = "POP3 send_cmd: " . _("Empty command string");
+            $this->ERROR = _("POP3 send_cmd:") . ' ' . _("Empty command string");
             return "";
         }
 
@@ -475,7 +478,7 @@ class POP3 {
 
         if(!isset($this->FP))
         {
-            $this->ERROR = "POP3 quit: " . _("connection does not exist");
+            $this->ERROR = _("POP3 quit:") . ' ' . _("connection does not exist");
             return false;
         }
         $fp = $this->FP;
@@ -512,7 +515,7 @@ class POP3 {
         //  Array element 0 will contain the total number of msgs
 
         if(!isset($this->FP)) {
-            $this->ERROR = "POP3 uidl: " . _("No connection to server");
+            $this->ERROR = _("POP3 uidl:") . ' ' . _("No connection to server");
             return false;
         }
 
@@ -524,10 +527,10 @@ class POP3 {
             $reply = $this->send_cmd($cmd);
             if(!$this->is_ok($reply))
             {
-                $this->ERROR = "POP3 uidl: " . _("Error ") . "[$reply]";
+                $this->ERROR = _("POP3 uidl:") . ' ' . _("Error ") . "[$reply]";
                 return false;
             }
-            list ($ok,$num,$myUidl) = preg_split('/\s+/',$reply);
+            list ($ok,$num,$myUidl) = explode(" ",$reply);
             return $myUidl;
         } else {
             $this->update_timer();
@@ -547,15 +550,18 @@ class POP3 {
             if($this->DEBUG) { @error_log("POP3 SEND [$cmd] GOT [$reply]",0); }
             if(!$this->is_ok($reply))
             {
-                $this->ERROR = "POP3 uidl: " . _("Error ") . "[$reply]";
+                $this->ERROR = _("POP3 uidl:") . ' ' . _("Error ") . "[$reply]";
                 return false;
             }
 
             $line = "";
             $count = 1;
             $line = fgets($fp,$buffer);
-            while ( !preg_match('/^\.\r\n/',$line)) {
-                list ($msg,$msgUidl) = preg_split('/\s+/',$line);
+            while ( !ereg("^\.\r\n",$line)) {
+                if(ereg("^\.\r\n",$line)) {
+                    break;
+                }
+                list ($msg,$msgUidl) = explode(" ",$line);
                 $msgUidl = $this->strip_clf($msgUidl);
                 if($count == $msg) {
                     $UIDLArray[$msg] = $msgUidl;
@@ -577,18 +583,18 @@ class POP3 {
 
         if(!isset($this->FP))
         {
-            $this->ERROR = "POP3 delete: " . _("No connection to server");
+            $this->ERROR = _("POP3 delete:") . ' ' . _("No connection to server");
             return false;
         }
         if(empty($msgNum))
         {
-            $this->ERROR = "POP3 delete: " . _("No msg number submitted");
+            $this->ERROR = _("POP3 delete:") . ' ' . _("No msg number submitted");
             return false;
         }
         $reply = $this->send_cmd("DELE $msgNum");
         if(!$this->is_ok($reply))
         {
-            $this->ERROR = "POP3 delete: " . _("Command failed ") . "[$reply]";
+            $this->ERROR = _("POP3 delete:") . ' ' . _("Command failed ") . "[$reply]";
             return false;
         }
         return true;
@@ -604,7 +610,7 @@ class POP3 {
         if( empty($cmd) )
             return false;
         else
-            return( stripos($cmd, '+OK') !== false );
+            return( ereg ("^\+OK", $cmd ) );
     }
 
     function strip_clf ($text = "") {
@@ -613,7 +619,8 @@ class POP3 {
         if(empty($text))
             return $text;
         else {
-            $stripped = str_replace(array("\r","\n"),'',$text);
+            $stripped = str_replace("\r",'',$text);
+            $stripped = str_replace("\n",'',$stripped);
             return $stripped;
         }
     }
@@ -646,11 +653,4 @@ class POP3 {
 
 }   // End class
 
-// For php4 compatibility
-if (!function_exists("stripos")) {
-    function stripos($haystack, $needle){
-        return strpos($haystack, stristr( $haystack, $needle ));
-    }
-}
-
-
+?>
