@@ -3,32 +3,28 @@
 /**
  * mail_fetch/options.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Setup of the mailfetch plugin.
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: options.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: options.php,v 1.28 2003/12/01 21:56:50 cigamit Exp $
  * @package plugins
  * @subpackage mail_fetch
  */
 
+/** @ignore */
 define('SM_PATH','../../');
 
 require_once(SM_PATH . 'include/validate.php');
 require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'include/load_prefs.php');
 
-// don't load this page if this plugin is not enabled
-//
-global $plugins;
-if (!in_array('mail_fetch', $plugins)) exit;
-
 /* globals */
 sqgetGlobalVar('username',   $username,   SQ_SESSION);
 sqgetGlobalVar('key',        $key,        SQ_COOKIE);
 sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
 sqgetGlobalVar('delimiter',  $delimiter,  SQ_SESSION);
-global $imap_stream_options; // in case not defined in config
     
 if(!sqgetGlobalVar('mf_cypher', $mf_cypher, SQ_POST)) {
     $mf_cypher = '';
@@ -56,8 +52,6 @@ sqgetGlobalVar('mf_login',         $mf_login,         SQ_POST);
 sqgetGlobalVar('mf_fref',          $mf_fref,          SQ_POST);
 sqgetGlobalVar('mf_lmos',          $mf_lmos,          SQ_POST);
 sqgetGlobalVar('submit_mailfetch', $submit_mailfetch, SQ_POST);
-$mf_port = trim($mf_port);
-$mf_server = trim($mf_server);
 
 
 /* end globals */
@@ -66,79 +60,31 @@ $mf_server = trim($mf_server);
 
     switch( $mf_action ) {
     case 'add':
-
-        $mf_action = 'config';
-
-        // restrict port number if necessary
-        //
-        $message = validate_mail_fetch_port_number($mf_port);
-        if (!empty($message)) break;
-
-        // restrict server address if necessary
-        //
-        $message = validate_mail_fetch_server_address($mf_server);
-        if (!empty($message)) break;
-
         if ($mf_sn<1) $mf_sn=0;
         if (!isset($mf_server)) return;
         setPref($data_dir,$username,"mailfetch_server_$mf_sn", (isset($mf_server)?$mf_server:""));
         setPref($data_dir,$username,"mailfetch_port_$mf_sn", (isset($mf_port)?$mf_port:110));
         setPref($data_dir,$username,"mailfetch_alias_$mf_sn", (isset($mf_alias)?$mf_alias:""));
         setPref($data_dir,$username,"mailfetch_user_$mf_sn",(isset($mf_user)?$mf_user:""));
-        $pass = "";
-        if ( isset($mf_pass) ) {
-            if ( isset($mf_cypher) && $mf_cypher == 'on' ) {
-                setPref($data_dir,$username,"mailfetch_cypher", ($mf_cypher == 'on' ? 'on' : ''));
-                $pass = encrypt($mf_pass);
-            } else {
-                $pass = $mf_pass;
-            }
-        }
-        setPref($data_dir,$username,"mailfetch_pass_$mf_sn",$pass);
+        setPref($data_dir,$username,"mailfetch_pass_$mf_sn",(isset($mf_pass)?encrypt( $mf_pass )    :""));
+        if( isset($mf_cypher) && $mf_cypher <> 'on' ) SetPref($data_dir,$username,'mailfetch_cypher',    'on');
         setPref($data_dir,$username,"mailfetch_lmos_$mf_sn",(isset($mf_lmos)?$mf_lmos:""));
         setPref($data_dir,$username,"mailfetch_login_$mf_sn",(isset($mf_login)?$mf_login:""));
         setPref($data_dir,$username,"mailfetch_fref_$mf_sn",(isset($mf_fref)?$mf_fref:""));
         setPref($data_dir,$username,"mailfetch_subfolder_$mf_sn",(isset($mf_subfolder)?$mf_subfolder:""));
         $mf_sn++;
         setPref($data_dir,$username,'mailfetch_server_number', $mf_sn);
+        $mf_action = 'config';
         break;
-
-    // modify a server
-    //
     case 'confirm_modify':
-
-        // restrict port number if necessary
-        //
-        $message = validate_mail_fetch_port_number($mf_port);
-        if (!empty($message)) {
-            $mf_action = 'Modify';
-            break;
-        }
-
-        // restrict server address if necessary
-        //
-        $message = validate_mail_fetch_server_address($mf_server);
-        if (!empty($message)) {
-            $mf_action = 'Modify';
-            break;
-        }
-
+        //modify    a server
         if (!isset($mf_server)) return;
         setPref($data_dir,$username,"mailfetch_server_$mf_sn", (isset($mf_server)?$mf_server:""));
         setPref($data_dir,$username,"mailfetch_port_$mf_sn", (isset($mf_port)?$mf_port:110));
         setPref($data_dir,$username,"mailfetch_alias_$mf_sn", (isset($mf_alias)?$mf_alias:""));
         setPref($data_dir,$username,"mailfetch_user_$mf_sn",(isset($mf_user)?$mf_user:""));
-        $pass = "";
-        if ( isset($mf_pass) ) {
-           if ( isset($mf_cypher) && $mf_cypher == 'on' ) {
-               setPref($data_dir,$username,"mailfetch_cypher", 'on');
-               $pass = encrypt($mf_pass);
-           } else {
-               setPref($data_dir,$username,"mailfetch_cypher", '');
-               $pass = $mf_pass;
-           }
-        }
-        setPref($data_dir,$username,"mailfetch_pass_$mf_sn",$pass);
+        setPref($data_dir,$username,"mailfetch_pass_$mf_sn",(isset($mf_pass)?encrypt( $mf_pass )    :""));
+        if( $mf_cypher <> 'on' ) setPref($data_dir,$username,"mailfetch_cypher", 'on');
         setPref($data_dir,$username,"mailfetch_lmos_$mf_sn",(isset($mf_lmos)?$mf_lmos:""));
         setPref($data_dir,$username,"mailfetch_login_$mf_sn",(isset($mf_login)?$mf_login:""));
         setPref($data_dir,$username,"mailfetch_fref_$mf_sn",(isset($mf_fref)?$mf_fref:""));
@@ -216,12 +162,12 @@ $mf_server = trim($mf_server);
             html_tag( 'table',
                 html_tag( 'tr',
                     html_tag( 'td',
-                        _("You should be aware that the encryption used to store your password is not perfectly secure. However, if you are using pop, there is inherently no encryption anyway. Additionally, the encryption that we do to save it on the server can be undone by a hacker reading the source to this file." ) ,
+                        _("You should be aware that the encryption used to store your password is not perfectly secure.  However, if you are using pop, there is inherently no encryption anyway. Additionally, the encryption that we do to save it on the server can be undone by a hacker reading the source to this file." ) ,
                     'left' )
                 ) .
                 html_tag( 'tr',
                     html_tag( 'td',
-                        _("If you leave password empty, it will be asked when you fetch mail.") ,
+                        _("If you leave password empty, it will be required when you fetch mail.") ,
                     'left' )
                 ) .
                 html_tag( 'tr',
@@ -233,14 +179,6 @@ $mf_server = trim($mf_server);
                 ) ,
             'center', '', 'width="95%"' );
 
-    // display error or other messages if necessary
-    //
-    if (!empty($message)) {
-        echo html_tag( 'table', '', 'center', '', 'width="70%" cellpadding="5" cellspacing="1"' ) .
-             html_tag( 'tr',
-             html_tag( 'td', '<b>' . $message . '</b>', 'center', $color[2] ));
-    }
-
     switch( $mf_action ) {
     case 'config':
         echo html_tag( 'table', '', 'center', '', 'width="70%" cellpadding="5" cellspacing="1"' ) .
@@ -276,7 +214,7 @@ $mf_server = trim($mf_server);
                 html_tag( 'tr' ) .
                     html_tag( 'th', _("Store in Folder:"), 'right' ) .
                     html_tag( 'td', '', 'left' );
-        $imapConnection = sqimap_login ($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
+        $imapConnection = sqimap_login ($username, $key, $imapServerAddress, $imapPort, 0);
         $boxes = sqimap_mailbox_list($imapConnection);
         echo '<select name="mf_subfolder">';
 
@@ -287,15 +225,15 @@ $mf_server = trim($mf_server);
         echo '</select></td></tr>' .
                 html_tag( 'tr',
                     html_tag( 'th', '&nbsp;', 'right' ) .
-                    html_tag( 'td', '<input type="checkbox" name="mf_lmos" checked>' . _("Leave mail on server"), 'left' )
+                    html_tag( 'td', '<input type="checkbox" name="mf_lmos" checked>' . _("Leave Mail on Server"), 'left' )
                 ) .
                 html_tag( 'tr',
                     html_tag( 'th', '&nbsp;', 'right' ) .
-                    html_tag( 'td', '<input type="checkbox" name="mf_login">' . _("Check mail at login"), 'left' )
+                    html_tag( 'td', '<input type="checkbox" name="mf_login">' . _("Check mail during login"), 'left' )
                 ) .
                 html_tag( 'tr',
                     html_tag( 'th', '&nbsp;', 'right' ) .
-                    html_tag( 'td', '<input type="checkbox" name="mf_fref">' . _("Check mail at folder refresh"), 'left' )
+                    html_tag( 'td', '<input type="checkbox" name="mf_fref">' . _("Check mail during folder refresh"), 'left' )
                 ) .
                 html_tag( 'tr',
                     html_tag( 'td',
@@ -317,14 +255,14 @@ $mf_server = trim($mf_server);
             echo '<b>' . _("Server Name:") . '</b> <select name="mf_sn">';
             for ($i=0;$i<$mailfetch_server_number;$i++) {
                 echo "<option value=\"$i\">" .
-                    sm_encode_html_special_chars( (($mailfetch_alias_[$i]=='')?$mailfetch_server_[$i]:$mailfetch_alias_[$i])) . "</option>";
+                    htmlspecialchars( (($mailfetch_alias_[$i]=='')?$mailfetch_server_[$i]:$mailfetch_alias_[$i])) . "</option>";
             }
             echo '</select>'.
                  '&nbsp;&nbsp;<INPUT TYPE=submit name=mf_action_mod value="' . _("Modify") . '">'.
                  '&nbsp;&nbsp;<INPUT TYPE=submit name=mf_action_del value="' . _("Delete") . '">'.
                  '</form>';
         } else {
-            echo _("No servers known.");
+            echo _("No-one server in use. Try to add.");
         }
         echo '</td></tr></table>';
         break;
@@ -343,7 +281,7 @@ $mf_server = trim($mf_server);
                     html_tag( 'td',
                         "<INPUT TYPE=\"hidden\" NAME=\"mf_sn\" VALUE=\"$mf_sn\">" .
                         '<INPUT TYPE="hidden" NAME="mf_action" VALUE="confirm_delete">' .
-                        '<br>' . _("Selected Server:") . " <b>" . sm_encode_html_special_chars($mailfetch_server_[$mf_sn]) . "</b><br>" .
+                        '<br>' . _("Selected Server:") . " <b>" . htmlentities($mailfetch_server_[$mf_sn]) . "</b><br>" .
                         _("Confirm delete of selected server?") . '<br><br>' .
                         '<input type=submit name=submit_mailfetch value="' . _("Confirm Delete") . '">' .
                         '<br></form>' ,
@@ -370,29 +308,29 @@ $mf_server = trim($mf_server);
             html_tag( 'table' ) .
                 html_tag( 'tr',
                     html_tag( 'th', _("Server:"), 'right' ) .
-                    html_tag( 'td', '<input type="text" name="mf_server" value="' . sm_encode_html_special_chars($mailfetch_server_[$mf_sn]) . '" size="40">', 'left' )
+                    html_tag( 'td', '<input type="text" name="mf_server" value="' . htmlentities($mailfetch_server_[$mf_sn]) . '" size="40">', 'left' )
                 ) .
                 html_tag( 'tr',
                     html_tag( 'th', _("Port:"), 'right' ) .
-                    html_tag( 'td', '<input type="text" name="mf_port" value="' . sm_encode_html_special_chars($mailfetch_port_[$mf_sn]) . '" size="40">', 'left' )
+                    html_tag( 'td', '<input type="text" name="mf_port" value="' . $mailfetch_port_[$mf_sn] . '" size="40">', 'left' )
                 ) .
                 html_tag( 'tr',
                     html_tag( 'th', _("Alias:"), 'right' ) .
-                    html_tag( 'td', '<input type="text" name="mf_alias" value="' . sm_encode_html_special_chars($mailfetch_alias_[$mf_sn]) . '" size="40">', 'left' )
+                    html_tag( 'td', '<input type="text" name="mf_alias" value="' . htmlentities($mailfetch_alias_[$mf_sn]) . '" size="40">', 'left' )
                 ) .
                 html_tag( 'tr',
                     html_tag( 'th', _("Username:"), 'right' ) .
-                    html_tag( 'td', '<input type="text" name="mf_user" value="' . sm_encode_html_special_chars($mailfetch_user_[$mf_sn]) . '" size="20">', 'left' )
+                    html_tag( 'td', '<input type="text" name="mf_user" value="' . $mailfetch_user_[$mf_sn] . '" size="20">', 'left' )
                 ) .
                 html_tag( 'tr',
                     html_tag( 'th', _("Password:"), 'right' ) .
-                    html_tag( 'td', '<input type="password" name="mf_pass" value="' . sm_encode_html_special_chars($mailfetch_pass_[$mf_sn]) . '" size="20">', 'left' )
+                    html_tag( 'td', '<input type="password" name="mf_pass" value="' . $mailfetch_pass_[$mf_sn] . '" size="20">', 'left' )
                 ) .
                 html_tag( 'tr' ) .
                     html_tag( 'th', _("Store in Folder:"), 'right' ) .
                     html_tag( 'td', '', 'left' );
 
-        $imapConnection = sqimap_login ($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
+        $imapConnection = sqimap_login ($username, $key, $imapServerAddress, $imapPort, 0);
         $boxes = sqimap_mailbox_list($imapConnection);
         echo '<select name="mf_subfolder">';
         $selected = 0;
@@ -413,14 +351,14 @@ $mf_server = trim($mf_server);
                     html_tag( 'th', '&nbsp;', 'right' ) .
                     html_tag( 'td',
                         '<input type=checkbox name=mf_login ' . ( ($mailfetch_login_[$mf_sn] == 'on')?'checked':'') .
-                        '>' . _("Check mail at login"),
+                        '>' . _("Check mail during login"),
                     'left' )
                 ) .
                 html_tag( 'tr',
                     html_tag( 'th', '&nbsp;', 'right' ) .
                     html_tag( 'td',
                         '<input type=checkbox name=mf_fref ' . ( ($mailfetch_fref_[$mf_sn] == 'on')?'checked':'') .
-                        '>' . _("Check mail at folder refresh") ,
+                        '>' . _("Check mail during folder refresh") ,
                     'left' )
                 ) .
                 html_tag( 'tr',
@@ -442,7 +380,7 @@ $mf_server = trim($mf_server);
         html_tag( 'table',
             html_tag( 'tr',
                 html_tag( 'td', '<b>' . _("Undefined Function") . '</b>', 'center', $color[9] ) .
-                html_tag( 'td', '<b>' .  _("The function you requested is unknown.") . '</b>', 'center', $color[0] )
+                html_tag( 'td', '<b>' . _("Hey! Wath do You are looking for?") . '</b>', 'center', $color[0] )
             ) ,
         'center', '', 'width="70%"' );
     }
