@@ -1,16 +1,13 @@
 <?php
-/**
- * Message Details plugin - bottom frame with message structure and rfc822 body
+
+/** Message Source  
  *
  * Plugin to view the RFC822 raw message output and the bodystructure of a message
  *
+ * Copyright (c) 2002 Marc Groot Koerkamp, The Netherlands
  * Licensed under the GNU GPL. For full terms see the file COPYING.
- *
- * @author Marc Groot Koerkamp
- * @copyright 2002 Marc Groot Koerkamp, The Netherlands
- * @copyright 2004-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: message_details_bottom.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * 
+ * $Id: message_details_bottom.php,v 1.12 2003/10/27 22:24:40 tassium Exp $
  * @package plugins
  * @subpackage message_details
  */
@@ -22,26 +19,18 @@ define('SM_PATH','../../');
 require_once(SM_PATH . 'include/validate.php');
 require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'functions/mime.php');
+require_once(SM_PATH . 'config/config.php');
+require_once(SM_PATH . 'functions/prefs.php');
 
 global $color, $uid_support;
 
 sqgetGlobalVar('passed_id', $passed_id, SQ_GET);
-if (!sqGetGlobalVar('passed_ent_id', $passed_ent_id, SQ_FORM))
-    $passed_ent_id = 0;
 sqgetGlobalVar('mailbox', $mailbox, SQ_GET);
 
 sqgetGlobalVar('username', $username, SQ_SESSION);
 sqgetGlobalVar('key', $key, SQ_COOKIE);
 sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
-global $imap_stream_options; // in case not defined in config
 
-/**
- * Calculates id of MIME entity
- * @param string $entString
- * @param integer $direction
- * @return string
- * @access private
- */
 function CalcEntity($entString, $direction) {
     $result = $entString;
     if ($direction == -1) {
@@ -72,12 +61,19 @@ function CalcEntity($entString, $direction) {
     return ($result);
 }
 
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
+function returnTime($start) {
+ $stop = gettimeofday();
+ $timepassed =  1000000 * ($stop['sec'] - $start['sec']) + $stop['usec'] - $start['usec'];
+ return $timepassed;
+}
+
+function GetMimeProperties($header) {
+}
+
+$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 $read = sqimap_mailbox_select($imapConnection, $mailbox);
-if (!empty($passed_ent_id))
-    $body = sqimap_run_command($imapConnection, "FETCH $passed_id BODY[$passed_ent_id]",true, $response, $readmessage, $uid_support);
-else
-    $body = sqimap_run_command($imapConnection, "FETCH $passed_id RFC822",true, $response, $readmessage, $uid_support);
+$start = gettimeofday();
+$body = sqimap_run_command($imapConnection, "FETCH $passed_id RFC822",true, $response, $readmessage, $uid_support);
 $message_body = '';
 $header = false;
 $mimepart = false;
@@ -86,7 +82,7 @@ $messageheader = true;
 $messageheaderstart=false;
 $boundaries = array();
 $entities = array();
-sqsession_unregister("entities");
+session_unregister("entities");
 $pre = '<b>';
 $end = '</b>';
 $entStr = '';
@@ -108,7 +104,7 @@ for ($i=1; $i < $count; $i++) {
 	} else if ($messageheader) {
 	    if ($header) {
 		$header=false;
-		$end = "\n \n".'</div>'."\n \n".'<div class="ent_body" id="'.$entStr.'B">'."\n \n"; 
+		$end = "\n \n".'</div>'."\n \n".'<div class="ent_body" ID="'.$entStr.'B">'."\n \n"; 
 	    }
 	    $mimepart = -$header;
 	    $bnd_end = false;
@@ -120,7 +116,7 @@ for ($i=1; $i < $count; $i++) {
 	} else {
 	    if ($header) {
 	        $pre = '';
-		$end = "\n \n".'</div>'."\n \n".'<div class="ent_body" id="'.$entStr.'B">'."\n \n"; 
+		$end = "\n \n".'</div>'."\n \n".'<div class="ent_body" ID="'.$entStr.'B">'."\n \n"; 
 	    }
 	    $header = false;
 	    $mimepart=true;
@@ -132,7 +128,7 @@ for ($i=1; $i < $count; $i++) {
 	    $messageheaderstart=true;
 	    if ($pre != '<b>') {
 		$pre = '<i><font color ='."$color[1]>";
-		$end = '</font></i>';
+		$end = '</i></font>';
 	    }
 	}     
 	if (!$messageheader && !$header ) {
@@ -144,26 +140,26 @@ for ($i=1; $i < $count; $i++) {
 	$end = '';
     }
     if (  ( $header || $messageheader) && (preg_match("/^.*boundary=\"?(.+(?=\")|.+).*/i",$line,$reg)) )  {
-        $bnd = $reg[1];
-        $bndreg = $bnd;    
-        $bndreg = str_replace("\\","\\\\",$bndreg);	
-        $bndreg = str_replace("?","\\?",$bndreg);
-        $bndreg = str_replace("+","\\+",$bndreg);		
-        $bndreg = str_replace(".","\\.",$bndreg);			
-        $bndreg = str_replace("/","\\/",$bndreg);
-        $bndreg = str_replace("-","\\-",$bndreg);
-        $bndreg = str_replace("(","\\(",$bndreg);
-        $bndreg = str_replace(")","\\)",$bndreg);
+	$bnd = $reg[1];
+	$bndreg = $bnd;    
+	$bndreg = str_replace("\\","\\\\",$bndreg);	
+	$bndreg = str_replace("?","\\?",$bndreg);
+	$bndreg = str_replace("+","\\+",$bndreg);		
+	$bndreg = str_replace(".","\\.",$bndreg);			
+	$bndreg = str_replace("/","\\/",$bndreg);
+	$bndreg = str_replace("-","\\-",$bndreg);
+	$bndreg = str_replace("(","\\(",$bndreg);
+	$bndreg = str_replace(")","\\)",$bndreg);
 
-        $boundaries[] = array( 'bnd' => $bnd, 'bndreg' => $bndreg);
-        $messageheader = false;
-        $messageheaderstart=false;
-        $mimepart=false;
-        if ($entStr=='') {
-            $entStr='0';
-        } else {
-            $entStr = CalcEntity("$entStr",1);
-        }
+	$boundaries[] = array( 'bnd' => $bnd, 'bndreg' => $bndreg);
+	$messageheader = false;
+	$messageheaderstart=false;
+	$mimepart=false;
+	if ($entStr=='') {
+	    $entStr='0';
+	} else {
+	    $entStr = CalcEntity("$entStr",1);
+	}
     }
     
     if (($line != '' && $line{0} == '-' || $header)  && isset($boundaries[0])) {
@@ -180,27 +176,26 @@ for ($i=1; $i < $count; $i++) {
 		    $bndend = true;
 	    }
 	    if ($bndend) {
-            $entStr = CalcEntity("$entStr",-1);
-            array_pop($boundaries);
-            $pre .= '<b><font color ='."$color[2]>";
-            $end .= '</font></b>';
-            $header = true;
-            $mimepart = false;
-            $bnd_end = true;
-            $encoding = '';
+		$entStr = CalcEntity("$entStr",-1);
+		array_pop($boundaries);
+		$pre .= '<b><font color ='."$color[2]>";
+		$end .= '</font></b>';
+		$header = true;
+		$mimepart = false;
+		$bnd_end = true;
+		$encoding = '';
 	    } else {
-            $header = true;
-            $bnd_end = false;
-            $entStr = CalcEntity("$entStr",0);
-            $content_indx++;
-            $content[$content_indx]=array();		
-            $content[$content_indx]['ent'] = '<a href="#'."$entStr \">$entStr".'</a>';
-            $pre .= "\n \n".'</div>'."\n \n".'<div class="entheader" id="'.
-                $entStr.'H"><a name="'."$entStr".'"><b><font color ='."$color[2]>";
-            $end .= '</font></b>'."\n";
-            $header = true;
-            $mimepart = false;
-            $encoding = '';
+		$header = true;
+		$bnd_end = false;
+		$entStr = CalcEntity("$entStr",0);
+		$content_indx++;
+		$content[$content_indx]=array();		
+		$content[$content_indx]['ent'] = '<A HREF="#'."$entStr \">$entStr".'</a>';
+		$pre .= "\n \n".'</div>'."\n \n".'<div class="entheader" ID="'.$entStr.'H"><a name="'."$entStr".'"><b><font color ='."$color[2]>";
+		$end .= '</font></b>'."\n";
+		$header = true;
+		$mimepart = false;
+		$encoding = '';
 	    }
 	}  else {
 	    if ($header) {
@@ -216,7 +211,7 @@ for ($i=1; $i < $count; $i++) {
 			$entities["$entStr"]['contenttype']=$reg[2].'/'.$reg[3];
 		    }	
    		} else if (!$nameset && preg_match("/^.*(name=\s*)\"(.*)\".*/i",$line,$reg)) {
-		    $name = sm_encode_html_special_chars($reg[2]);
+		    $name = htmlspecialchars($reg[2]);
 		    $content[$content_indx]['name'] = decodeHeader($name);
 		    $nameset = true;
 		    if (isset($entities["$entStr"])) {
@@ -247,13 +242,13 @@ for ($i=1; $i < $count; $i++) {
         }
     } 	
 */
-    $line = sm_encode_html_special_chars($line);
-    $message_body .= "$pre"."$line"."$end".'<br />'."\r\n";
+    $line = htmlspecialchars($line);
+    $message_body .= "$pre"."$line"."$end".'<BR>'."\r\n";
 }
-
+//echo returnTime($start).'<BR>';
 $xtra = <<<ECHO
 
-<style>
+<STYLE>
 
 <!--
 .ent_body {
@@ -270,7 +265,7 @@ $xtra = <<<ECHO
 }
 //-->
 
-</style>
+</STYLE>
 
 ECHO;
 
@@ -279,16 +274,29 @@ displayHtmlHeader( _("Message Details"), $xtra, FALSE );
 echo "<body text=\"$color[8]\" bgcolor=\"$color[4]\" link=\"$color[7]\" vlink=\"$color[7]\" alink=\"$color[7]\">\n";
 echo '<code>'."\n";
 echo '<font face = "monospace">'."\n";
-echo '<br />'."\n";
+echo '<BR>'."\n";
+
+
+//session_register("entities");
+//$keys = array_keys($entities);
+//$start = gettimeofday();
+//foreach ($keys as $key) {
+//    if (isset($entities[$key])) {
+//    if ($entities[$key]['encoding'] == 'base64') {
+//	echo '<img src="message_viewentity.php?ent='.$entities[$key]['entity'].'&amp;name='.$entities[$key]['name'].'"><br>';
+//    }
+//    }
+//}
+//session_unregister("entities");
 
 if (count($content) > 0) {
-    echo '<h2>' . _("Bodystructure") . "</h2>\n\n";
+    echo '<h2> Bodystructure </h2>'."\n\n";
     echo '<table border=1 width="98%"><thead>'.
 	  '<tr bgcolor="'."$color[7]".'">'.
-	    '<td><b><font color="'."$color[5]".'">' . _("Entity") . '</font></b></td>'.
-	    '<td><b><font color="'."$color[5]".'">' . _("Content-Type") . '</font></b></td>'.
-	    '<td><b><font color="'."$color[5]".'">' . _("Name") . '</font></b></td>'.
-	    '<td><b><font color="'."$color[5]".'">' . _("Encoding") . '</font></b></td>'.
+	    '<td><b><font color="'."$color[5]".'">Entity</font></b></td>'.
+	    '<td><b><font color="'."$color[5]".'">Content-Type</font></b></td>'.
+	    '<td><b><font color="'."$color[5]".'">Name</font></b></td>'.
+	    '<td><b><font color="'."$color[5]".'">Encoding</font></b></td>'.
 
 	  '</tr>'.
 	  '</thead><tbody>';
@@ -310,7 +318,7 @@ if (count($content) > 0) {
     }
     echo '</tbody></table><br>'."\n";
 }
-echo '<h2>' . _("RFC822 Message body") . "</h2>\n\n";
+echo '<h2> RFC822 Message body </h2>'."\n\n";
 echo '<div><div class="header">'."\n\n";
 echo $message_body;
 echo '</div></div></font></code></body></html>';
