@@ -1,47 +1,40 @@
 <?php
-
-/**
- * Message Details plugin - main setup script
- *
- * Plugin to view the RFC822 raw message output and the bodystructure of a message
- *
- * @author Marc Groot Koerkamp
- * @copyright 2002 Marc Groot Koerkamp, The Netherlands
- * @copyright 2002-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: setup.php 14800 2019-01-08 04:27:15Z pdontthink $
- * @package plugins
- * @subpackage message_details
- **/
+/** Message Source  
+*
+* Plugin to view the RFC822 raw message output and the bodystructure of a message
+*
+* Copyright (c) 2002 Marc Groot Koerkamp, The Netherlands
+* Licensed under the GNU GPL. For full terms see the file COPYING.
+* 
+* $Id: setup.php,v 1.5 2003/12/01 21:56:50 cigamit Exp $
+* @package plugins
+* @subpackage message_details
+**/
 
 /**
  * Initialize the plugin
- * @access private
  */
 function squirrelmail_plugin_init_message_details()
 {
   global $squirrelmail_plugin_hooks;
 
+  do_hook('read_body_header_right');
   $squirrelmail_plugin_hooks['read_body_header_right']['message_details'] = 'show_message_details';
 }
 
-/**
- * Add message details link in message view
- * @access private
- */
 function show_message_details() {
-    global $passed_id, $mailbox, $passed_ent_id, $color,
+    global $passed_id, $mailbox, $ent_num, $color,
            $javascript_on;
 
     if (strlen(trim($mailbox)) < 1) {
         $mailbox = 'INBOX';
     }
 
-    $params = '?passed_ent_id=' . $passed_ent_id .
+    $params = '?passed_ent_id=' . $ent_num .
               '&mailbox=' . urlencode($mailbox) .
               '&passed_id=' . $passed_id;
 
-    $print_text = _("View Message Details");
+    $print_text = _("View Message details");
 
     $result = '';
     /* Output the link. */
@@ -53,9 +46,10 @@ function show_message_details() {
                         $params . '","MessageDetails","width=800,height=600");' . "\n".
                 "  }\n" .
                 "// -->\n" .
-                "</script>" .
-                "&nbsp;| <a href=\"javascript:MessageSource();\" style=\"white-space: nowrap;\">$print_text</a>";
-    }
+                "</script>\n" .
+                "&nbsp;|&nbsp;<A HREF=\"javascript:MessageSource();\">$print_text</A>\n";
+    } 
     echo $result;
 }
-
+ 
+?>
