@@ -3,12 +3,12 @@
 /**
  * newmail.php
  *
- * Copyright (c) 1999-2019 The SquirrelMail Project Team
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.        
  *
  * Displays all options relating to new mail sounds
  *
- * $Id: newmail.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: newmail.php,v 1.12 2003/10/27 22:24:40 tassium Exp $
  * @package plugins
  * @subpackage newmail
  */
@@ -22,11 +22,10 @@ require_once(SM_PATH . 'include/load_prefs.php');
 require_once(SM_PATH . 'functions/page_header.php');
 
 sqGetGlobalVar('numnew', $numnew, SQ_GET);
-$numnew = (int)$numnew;
 
    displayHtmlHeader( _("New Mail"), '', FALSE );
 
-   echo '<body bgcolor="'.$color[4].'" topmargin="0" leftmargin="0" rightmargin="0" marginwidth="0" marginheight="0">'."\n".
+   echo "<body bgcolor=\"$color[4]\" topmargin=0 leftmargin=0 rightmargin=0 marginwidth=0 marginheight=0>\n".
         '<center>'. "\n" .
         html_tag( 'table', "\n" .
             html_tag( 'tr', "\n" .
@@ -34,14 +33,14 @@ $numnew = (int)$numnew;
             ) .
             html_tag( 'tr', "\n" .
                 html_tag( 'td',
-                    '<br /><big><font color="' . $color[2] . '">'.
-        	    sprintf( ( $numnew == 1 ?
-        	        _("You have %s new message") :
-        		_("You have %s new messages") ), $numnew ) .
-                    '</font><br /></big><br />' . "\n" .
+                    '<br><big><font color="' . $color[2] . '">' . _("You have").' '.
+		    sprintf( ( $numnew == 1 ?
+		        _("%s new message") :
+			_("%s new messages") ), $numnew ) .
+                    '</font><br></big><br>' . "\n" .
                     '<form name="nm">' . "\n".
-                    '<input type="button" name="bt" value="' . _("Close Window") .
-                    '" onClick="javascript:window.close();" />'."\n".
+                    '<input type=button name=bt value="' . _("Close Window") .
+                    '" onClick="javascript:window.close();">'."\n".
                     '</form>',
                 'center' )
             ) ,
@@ -54,4 +53,4 @@ $numnew = (int)$numnew;
         "</script>\n".
         "</body></html>\n";
 
-?>
\ No newline at end of file
+?>
