@@ -3,12 +3,12 @@
 /**
  * setup.php -- Sent Subfolders Setup File
  *
- * Copyright (c) 1999-2019 The SquirrelMail Project Team
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This is a standard Squirrelmail-1.2 API for plugins.
  *
- * $Id: setup.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: setup.php,v 1.16 2004/01/04 12:08:45 tokul Exp $
  * @package plugins
  * @subpackage sent_subfolders
  */
@@ -63,6 +63,7 @@ function sent_subfolders_check_handleAsSent() {
     global $handleAsSent_result, $sent_subfolders_base,
            $use_sent_subfolders;
 
+    $sent_subfolders_base = 'INBOX.Sent';
     $args = func_get_arg(0);
     sqgetGlobalVar('delimiter', $delimiter, SQ_SESSION);
 
@@ -85,7 +86,7 @@ function sent_subfolders_check_handleAsSent() {
  * Loads sent_subfolders settings
  */
 function sent_subfolders_load_prefs() {
-    global $use_sent_subfolders, $data_dir, $username, $sent_folder,
+    global $use_sent_subfolders, $data_dir, $username,
            $sent_subfolders_setting, $sent_subfolders_base;
 
     $use_sent_subfolders = getPref
@@ -95,21 +96,21 @@ function sent_subfolders_load_prefs() {
     ($data_dir, $username, 'sent_subfolders_setting', SMPREF_SENT_SUBFOLDERS_DISABLED);
 
     $sent_subfolders_base = getPref
-    ($data_dir, $username, 'sent_subfolders_base', $sent_folder);
+    ($data_dir, $username, 'sent_subfolders_base', SMPREF_NONE);
 }
 
 /**
  * Adds sent_subfolders options in folder preferences
  */
 function sent_subfolders_optpage_loadhook_folders() {
-    global $optpage_data, $imapServerAddress, $imapPort, $imap_stream_options;
+    global $optpage_data, $imapServerAddress, $imapPort;
 
     sqgetGlobalVar('username', $username, SQ_SESSION);
     sqgetGlobalVar('key', $key, SQ_COOKIE);
 
     /* Get some imap data we need later. */
     $imapConnection =
-        sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
+        sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
     $boxes = sqimap_mailbox_list($imapConnection);
     sqimap_logout($imapConnection);
 
@@ -129,16 +130,21 @@ function sent_subfolders_optpage_loadhook_folders() {
         'save'    => 'save_option_sent_subfolders_setting'
     );
 
-    $filtered_folders=array_filter($boxes, "filter_folders");
-    $sent_subfolders_base_values = array('whatever'=>$filtered_folders);
+    $sent_subfolders_base_values = array();
+    foreach ($boxes as $folder) {
+        if (strtolower($folder['unformatted']) != 'inbox') {
+            $real_value = $folder['unformatted-dm'];
+            $disp_value = str_replace(' ', '&nbsp;', $folder['formatted']);
+            $sent_subfolders_base_values[$real_value] = $disp_value;
+        }
+    }
 
     $optvals[] = array(
         'name'    => 'sent_subfolders_base',
         'caption' => _("Base Sent Folder"),
-        'type'    => SMOPT_TYPE_FLDRLIST,
+        'type'    => SMOPT_TYPE_STRLIST,
         'refresh' => SMOPT_REFRESH_FOLDERLIST,
-        'posvals' => $sent_subfolders_base_values,
-        'save'    => 'save_option_sent_subfolders_base',
+        'posvals' => $sent_subfolders_base_values
     );
 
     /* Add our option data to the global array. */
@@ -146,36 +152,18 @@ function sent_subfolders_optpage_loadhook_folders() {
     $optpage_data['vals'][SMOPT_GRP_SENT_SUBFOLDERS] = $optvals;
 }
 
-/**
- * Defines folder filtering rules
- *
- * Callback function that should exclude some folders from folder listing.
- * @param array $fldr list of folders. See sqimap_mailbox_list
- * @return boolean returns true, if folder has to included in folder listing
- * @access private 
- */
-function filter_folders($fldr) {
-    return strtolower($fldr['unformatted'])!='inbox';
-}
-
 /**
  * Saves sent_subfolder_options
  */
 function save_option_sent_subfolders_setting($option) {
-    global $data_dir, $username, $use_sent_subfolders, $sent_subfolders_base;
+    global $data_dir, $username, $use_sent_subfolders;
 
     /* Set use_sent_subfolders as either on or off. */
     if ($option->new_value == SMPREF_SENT_SUBFOLDERS_DISABLED) {
         setPref($data_dir, $username, 'use_sent_subfolders', SMPREF_OFF);
-        // for lack of anything better
-        setPref($data_dir, $username, 'sent_folder', $sent_subfolders_base);
     } else {
         setPref($data_dir, $username, 'use_sent_subfolders', SMPREF_ON);
         setPref($data_dir, $username, 'move_to_sent', SMPREF_ON);
-        $check_sent_subfolders_base = getPref($data_dir, $username, 'sent_subfolders_base', '');
-        if ($check_sent_subfolders_base === '') {
-            setPref($data_dir, $username, 'sent_subfolders_base', $sent_subfolders_base);
-        }
     }
 
     /* Now just save the option as normal. */
@@ -191,7 +179,7 @@ function save_option_sent_subfolders_setting($option) {
 function sent_subfolders_update_sentfolder() {
     global $sent_folder, $auto_create_special, $auto_create_done;
     global $sent_subfolders_base, $sent_subfolders_setting;
-    global $data_dir, $imapServerAddress, $imapPort, $imap_stream_options;
+    global $data_dir, $imapServerAddress, $imapPort;
     global $use_sent_subfolders, $move_to_sent, $imap_server_type;
 
     sqgetGlobalVar('username', $username, SQ_SESSION);
@@ -229,7 +217,7 @@ function sent_subfolders_update_sentfolder() {
             $sent_subfolder = $sent_subfolders_base . $cnd_delimiter 
                             . $year
                             . $delimiter . $quarter;
-            $year_folder = $sent_subfolders_base . $cnd_delimiter
+            $year_folder = $sent_subfolders_base
                             . $year;
             break;
         case SMPREF_SENT_SUBFOLDERS_MONTHLY:
@@ -237,7 +225,7 @@ function sent_subfolders_update_sentfolder() {
             $sent_subfolder = $sent_subfolders_base . $cnd_delimiter
                             . $year
                             . $delimiter . $month;
-            $year_folder = $sent_subfolders_base . $cnd_delimiter . $year;
+            $year_folder = $sent_subfolders_base . $year;
             break;
         case SMPREF_SENT_SUBFOLDERS_DISABLED:
         default:
@@ -259,16 +247,13 @@ function sent_subfolders_update_sentfolder() {
             if ($sent_folder != 'none') {
                 /* Create the imap connection. */
                 $ic = sqimap_login
-                ($username, $key, $imapServerAddress, $imapPort, 10, $imap_stream_options);
+                ($username, $key, $imapServerAddress, $imapPort, 10);
 
-                /* Auto-create the year folder, if it does not yet exist.
-                   (only for monthly/quarterly modes */
-                if ($sent_subfolders_setting != SMPREF_SENT_SUBFOLDERS_YEARLY) {
-                    if (!sqimap_mailbox_exists($ic, $year_folder)) {
-                        sqimap_mailbox_create($ic, $year_folder, ($level==1)?'':'noselect');
-                    } else if (!sqimap_mailbox_is_subscribed($ic, $year_folder)) {
-                        sqimap_subscribe($ic, $year_folder);
-                    }
+                /* Auto-create the year folder, if it does not yet exist. */
+                if (!sqimap_mailbox_exists($ic, $year_folder)) {
+                    sqimap_mailbox_create($ic, $year_folder, ($level==1)?'':'noselect');
+                } else if (!sqimap_mailbox_is_subscribed($ic, $year_folder)) {
+                    sqimap_subscribe($ic, $year_folder);
                 }
 
                 /* Auto-create the subfolder, if it does not yet exist. */
@@ -285,17 +270,6 @@ function sent_subfolders_update_sentfolder() {
     }
 }
 
-/**
- * Update the folder settings/auto-create new subfolder
- */
-function save_option_sent_subfolders_base($option) {
-    // first save the option as normal
-    save_option($option);
-
-    // now update folder settings and auto-create first subfolder if needed
-    sent_subfolders_update_sentfolder();
-}
-
 /**
  * Sets quarter subfolder names
  *
@@ -339,25 +313,16 @@ function sent_subfolder_getQuarter($month) {
  * @return boolean 1 - is part of sent_subfolders, 0 - is not part of sent_subfolders
  */
 function sent_subfolders_special_mailbox($mb) {
-    global $data_dir, $username, $sent_folder;
-
-    sqgetGlobalVar('delimiter', $delimiter, SQ_SESSION);
-/*
-    if( $imap_server_type == 'uw' ) {
-        $cnd_delimiter = '';
-    } else {
-        $cnd_delimiter = $delimiter;
-    }
-*/        
-    $cnd_delimiter = $delimiter;
+    global $data_dir, $username;
 
     $use_sent_subfolders = getPref
         ($data_dir, $username, 'use_sent_subfolders', SMPREF_OFF);
-    $sent_subfolders_base = getPref($data_dir, $username, 'sent_subfolders_base', $sent_folder);
+    $sent_subfolders_base = getPref($data_dir, $username, 'sent_subfolders_base', 'na');
 
     if ($use_sent_subfolders == SMPREF_ON && 
-    ($mb == $sent_subfolders_base || stristr($mb,$sent_subfolders_base. $cnd_delimiter) ) ) {
+    ($mb == $sent_subfolders_base || stristr($mb,$sent_subfolders_base) ) ) {
 	return 1;
     }
     return 0;
 }
+?>
