@@ -2,25 +2,29 @@
    /** 
     **  spamcop.php -- SpamCop plugin           
     **
-    **  Copyright (c) 1999-2019 The SquirrelMail Project Team
+    **  Copyright (c) 1999-2003 The SquirrelMail development team
     **  Licensed under the GNU GPL. For full terms see the file COPYING.
     **  
-    **  $Id: spamcop.php 14800 2019-01-08 04:27:15Z pdontthink $                                                         
+    **  $Id: spamcop.php,v 1.21 2003/12/26 08:39:17 tokul Exp $
+    * @package plugins
+    * @subpackage spamcop
     **/
 
+/** @ignore */
 define('SM_PATH','../../');
 
  /* SquirrelMail required files. */
 require_once(SM_PATH . 'include/validate.php');
 require_once(SM_PATH . 'functions/imap.php');
 
+/**
+ * Stores message in attachment directory, when email based reports are used
+ */
 function getMessage_RFC822_Attachment($message, $composeMessage, $passed_id, 
                                       $passed_ent_id='', $imapConnection) {
     global $attachments, $attachment_dir, $username, $data_dir, $uid_support;
-    
+
     $hashed_attachment_dir = getHashedDir($username, $attachment_dir);
-    $localfilename = GenerateRandomString(32, 'FILE', 7);
-        
     if (!$passed_ent_id) {
         $body_a = sqimap_run_command($imapConnection, 
                                     'FETCH '.$passed_id.' RFC822',
@@ -36,13 +40,22 @@ function getMessage_RFC822_Attachment($message, $composeMessage, $passed_id,
         $subject = encodeHeader($message->rfc822_header->subject);
         array_shift($body_a);
         $body = implode('', $body_a) . "\r\n";
-        
+                
+        $localfilename = GenerateRandomString(32, 'FILE', 7);
         $full_localfilename = "$hashed_attachment_dir/$localfilename";
         $fp = fopen( $full_localfilename, 'w');
         fwrite ($fp, $body);
         fclose($fp);
+	
+        /* dirty relative dir fix */
+        if (substr($attachment_dir,0,3) == '../') {
+	   $attachment_dir = substr($attachment_dir,3);
+	   $hashed_attachment_dir = getHashedDir($username, $attachment_dir);
+        }
+	$full_localfilename = "$hashed_attachment_dir/$localfilename";
 
-        $composeMessage->initAttachment('message/rfc822','email.txt', $localfilename);
+	$composeMessage->initAttachment('message/rfc822','email.txt', 
+	                 $full_localfilename);
     }
     return $composeMessage;
 }
@@ -56,6 +69,7 @@ sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
 
 sqgetGlobalVar('mailbox', $mailbox, SQ_GET);
 sqgetGlobalVar('passed_id', $passed_id, SQ_GET);
+sqgetGlobalVar('js_web', $js_web, SQ_GET);
 
 if (! sqgetGlobalVar('startMessage', $startMessage, SQ_GET) ) {
     $startMessage = 1;
@@ -63,6 +77,9 @@ if (! sqgetGlobalVar('startMessage', $startMessage, SQ_GET) ) {
 if (! sqgetGlobalVar('passed_ent_id', $passed_ent_id, SQ_GET) ) {
     $passed_ent_id = 0;
 }
+if (! sqgetGlobalVar('js_web', $js_web, SQ_GET) ) {
+    $js_web = 0;
+}
 
 sqgetGlobalVar('compose_messages', $compose_messages, SQ_SESSION);
 
@@ -70,14 +87,19 @@ if(! sqgetGlobalVar('composesession', $composesession, SQ_SESSION) ) {
     $composesession = 0;
     sqsession_register($composesession, 'composesession');
 }
-global $imap_stream_options; // in case not defined in config
 /* END GLOBALS */
 
-    
-    displayPageHeader($color, $mailbox);
+// js_web variable is 1 only when link opens web based report page in new window
+// and in new window menu line or extra javascript code is not needed.
+if ($js_web) {
+  displayHTMLHeader('SpamCop reporting');
+  echo "<body text=\"$color[8]\" bgcolor=\"$color[4]\" link=\"$color[7]\" vlink=\"$color[7]\" alink=\"$color[7]\">\n";
+} else {
+  displayPageHeader($color,$mailbox);
+}
 
     $imap_stream = sqimap_login($username, $key, $imapServerAddress, 
-       $imapPort, 0, $imap_stream_options);
+       $imapPort, 0);
     sqimap_mailbox_select($imap_stream, $mailbox);
 
     if ($spamcop_method == 'quick_email' || 
@@ -104,21 +126,21 @@ global $imap_stream_options; // in case not defined in config
         $message = sqimap_get_message($imap_stream, $passed_id, $mailbox);
         $composeMessage = getMessage_RFC822_Attachment($message, $composeMessage, $passed_id, 
                                       $passed_ent_id, $imap_stream);
-                                      
-        $compose_messages[$session] = $composeMessage;
-        sqsession_register($compose_messages, 'compose_messages');
+
+    	$compose_messages[$session] = $composeMessage;
+	sqsession_register($compose_messages, 'compose_messages');
 
         $fn = getPref($data_dir, $username, 'full_name');
         $em = getPref($data_dir, $username, 'email_address');
 
         $HowItLooks = $fn . ' ';
         if ($em != '')
-            $HowItLooks .= '<' . $em . '>';
+          $HowItLooks .= '<' . $em . '>';
      }
 
 
 echo "<p>";
-echo _("Sending this spam report will give you back a reply with URLs that you can click on to properly report this spam message to the proper authorities. This is a free service. By pressing the \"Send Spam Report\" button, you agree to follow SpamCop's rules/terms of service/etc.");
+echo _("Sending this spam report will give you back a reply with URLs that you can click on to properly report this spam message to the proper authorities. This is a free service.  By pressing the \"Send Spam Report\" button, you agree to follow SpamCop's rules/terms of service/etc.");
 echo "</p>";
 
 ?>
@@ -126,58 +148,64 @@ echo "</p>";
 <table align="center" width="75%" border="0" cellpadding="0" cellspacing="0">
 <tr>
 <td align="left" valign="top">
-<?php if (isset($js_web) && $js_web) {
-  echo "<form method=\"post\" action=\"javascript:return false\">\n";
-  echo '<input type="button" value="' . _("Close Window") . "\" onClick=\"window.close(); return true;\" />\n";
+<?PHP if (isset($js_web) && $js_web) {
+   ?><form method="post" action="javascript:return false">
+  <input type="button" value="Close Window" 
+  onClick="window.close(); return true;">
+   <?PHP
 } else {
-   ?><form method="post" action="<?php echo sqm_baseuri(); ?>src/right_main.php">
-  <input type="hidden" name="mailbox" value="<?php echo sm_encode_html_special_chars($mailbox) ?>" />
-  <input type="hidden" name="startMessage" value="<?php echo sm_encode_html_special_chars($startMessage) ?>" />
-   <?php
-  echo '<input type="submit" value="' . _("Cancel / Done") . "\" />\n";
+   ?><form method="post" action="../../src/right_main.php">
+  <input type="hidden" name="mailbox" value="<?PHP echo htmlspecialchars($mailbox) ?>">
+  <input type="hidden" name="startMessage" value="<?PHP echo htmlspecialchars($startMessage) ?>">
+  <input type="submit" value="Cancel / Done">
+   <?PHP
 }
   ?></form>
 </td>
 <td align="right" valign="top">
-<?php if ($spamcop_method == 'thorough_email' ||
+<?PHP if ($spamcop_method == 'thorough_email' ||
           $spamcop_method == 'quick_email') {
    if ($spamcop_method == 'thorough_email')
       $report_email = 'submit.' . $spamcop_id . '@spam.spamcop.net';
    else
       $report_email = 'quick.' . $spamcop_id . '@spam.spamcop.net';
-   $form_action = sqm_baseuri() . 'src/compose.php';
-?>  <form method="post" action="<?php echo $form_action?>">
-  <input type="hidden" name="smtoken" value="<?php echo sm_generate_security_token(); ?>" />
-  <input type="hidden" name="mailbox" value="<?php echo sm_encode_html_special_chars($mailbox) ?>" />
-  <input type="hidden" name="spamcop_is_composing" value="<?php echo sm_encode_html_special_chars($passed_id) ?>" />
-  <input type="hidden" name="send_to" value="<?php echo sm_encode_html_special_chars($report_email)?>" />
-  <input type="hidden" name="subject" value="reply anyway" />
-  <input type="hidden" name="identity" value="0" />
-  <input type="hidden" name="session" value="<?php echo $session?>" />
-<?php  
-  echo '<input type="submit" name="send" value="' . _("Send Spam Report") . "\" />\n";
- } else {
+   $form_action = SM_PATH . 'src/compose.php';
+?>  <form method="post" action="<?PHP echo $form_action?>">
+  <input type="hidden" name="mailbox" value="<?PHP echo htmlspecialchars($mailbox) ?>">
+  <input type="hidden" name="spamcop_is_composing" value="<?PHP echo htmlspecialchars($passed_id) ?>">
+  <input type="hidden" name="send_to" value="<?PHP echo $report_email?>">
+  <input type="hidden" name="subject" value="reply anyway">
+  <input type="hidden" name="identity" value="0">
+  <input type="hidden" name="session" value="<?PHP echo $session?>">
+  <input type="submit" name="send" value="Send Spam Report">
+<?PHP } else {
    $spam_message = mime_fetch_body ($imap_stream, $passed_id, $passed_ent_id, 50000);
 
    if (strlen($spam_message) == 50000) {
       $Warning = "\n[truncated by SpamCop]\n";
       $spam_message = substr($spam_message, 0, 50000 - strlen($Warning)) . $Warning;
    }
-   if (isset($js_web) && $js_web) {
-?>  <form method="post" action="http://members.spamcop.net/sc" name="submitspam"
-    enctype="multipart/form-data"><?php
+   if ($spamcop_type=='member') {
+     $action_url="http://members.spamcop.net/sc";
    } else {
-?>  <form method="post" action="http://members.spamcop.net/sc" name="submitspam"
-    enctype="multipart/form-data" target="_top"><?php
+     $action_url="http://www.spamcop.net/sc";
+   }
+   if (isset($js_web) && $js_web) {
+     echo "<form method=\"post\" action=\"$action_url\" name=\"submitspam\"".
+       " enctype=\"multipart/form-data\">\n";
+   } else {
+     echo "<form method=\"post\" action=\"$action_url\" name=\"submitspam\"".
+       " enctype=\"multipart/form-data\" target=\"_blank\">\n";
    } ?>
-  <input type="hidden" name="action" value="submit" />
-  <input type="hidden" name="oldverbose" value="1" />
-  <input type="hidden" name="spam" value="<?php echo sm_encode_html_special_chars($spam_message); ?>" />
-<?php
-  echo '<input type="submit" name="x1" value="' . _("Send Spam Report") . "\" />";
- }
-?>
-</form>
-</td></tr>
+  <input type="hidden" name="action" value="submit">
+  <input type="hidden" name="oldverbose" value="1">
+  <input type="hidden" name="code" value="<?PHP echo $spamcop_id ?>">
+  <input type="hidden" name="spam" value="<?PHP echo htmlspecialchars($spam_message); ?>">
+  <input type="submit" name="x1" value="Send Spam Report">
+<?PHP }
+?>  </form>
+</td>
+</tr>
 </table>
-</body></html>
+  </body>
+</html>
