@@ -3,18 +3,16 @@
 /**
  * delete_message.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Deletes a meesage from the IMAP server
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: delete_message.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: delete_message.php,v 1.48 2004/01/30 06:59:47 ebullient Exp $
  * @package squirrelmail
  */
 
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -29,9 +27,9 @@ sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
 
 sqgetGlobalVar('message', $message, SQ_GET);
 sqgetGlobalVar('mailbox', $mailbox, SQ_GET);
-if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_GET)) {
-    $submitted_token = '';
-}
+
+sqgetGlobalVar('bypass_trash', $bypass_trash, SQ_GET);
+
 /* end globals */
 
 if (isset($_GET['saved_draft'])) {
@@ -40,33 +38,29 @@ if (isset($_GET['saved_draft'])) {
 if (isset($_GET['mail_sent'])) {
     $mail_sent = urlencode($_GET['mail_sent']);
 }
-if (isset($_GET['where'])) {
+if (isset($_GET['sort'])) {
+	$sort = (int) $_GET['sort'];
+}
+
+if (isset($_GET['startMessage'])) {
+	$startMessage = (int) $_GET['startMessage'];
+}
+
+if(isset($_GET['where'])) {
     $where = urlencode($_GET['where']);
 }
-if (isset($_GET['what'])) {
+if(isset($_GET['what'])) {
     $what = urlencode($_GET['what']);
 }
-if (isset($_GET['sort'])) {
-    $sort = (int) $_GET['sort'];
-}
-if (isset($_GET['startMessage'])) {
-    $startMessage = (int) $_GET['startMessage'];
-}
 
-// first, validate security token
-sm_validate_security_token($submitted_token, -1, TRUE);
-
-global $imap_stream_options; // in case not defined in config
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
+$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 
 sqimap_mailbox_select($imapConnection, $mailbox);
 
-sqimap_msgs_list_delete($imapConnection, $mailbox, $message);
+sqimap_messages_delete($imapConnection, $message, $message, $mailbox,$bypass_trash);
 if ($auto_expunge) {
     sqimap_mailbox_expunge($imapConnection, $mailbox, true);
 }
-sqimap_logout($imapConnection);
-
 if (!isset($saved_draft)) {
     $saved_draft = '';
 }
@@ -79,14 +73,10 @@ $location = get_location();
 
 if (isset($where) && isset($what)) {
     header("Location: $location/search.php?where=" . $where .
-           '&smtoken=' . sm_generate_security_token() .
            '&what=' . $what . '&mailbox=' . urlencode($mailbox));
 } else {
     if (!empty($saved_draft) || !empty($mail_sent)) {
-          if ($compose_new_win == '1')
-              header("Location: $location/compose.php?mail_sent=$mail_sent&saved_draft=$saved_draft");
-          else
-              header("Location: $location/right_main.php?mail_sent=$mail_sent&saved_draft=$saved_draft");
+          header("Location: $location/compose.php?mail_sent=$mail_sent&saved_draft=$saved_draft");
     }
     else {
         header("Location: $location/right_main.php?sort=$sort&startMessage=$startMessage&mailbox=" .
@@ -94,4 +84,6 @@ if (isset($where) && isset($what)) {
     }
 }
 
+sqimap_logout($imapConnection);
 
+?>
