@@ -3,22 +3,17 @@
 /**
  * download.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Handles attachment downloads to the users computer.
  * Also allows displaying of attachments when possible.
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: download.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: download.php,v 1.116 2003/12/10 23:56:40 alex-brainstorm Exp $
  * @package squirrelmail
  */
 
-/** This is the download page */
-define('PAGE_NAME', 'download');
-
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -38,33 +33,23 @@ sqgetGlobalVar('mailbox',    $mailbox,      SQ_GET);
 sqgetGlobalVar('ent_id',     $ent_id,       SQ_GET);
 sqgetGlobalVar('absolute_dl',$absolute_dl,  SQ_GET);
 if ( sqgetGlobalVar('passed_id', $temp, SQ_GET) ) {
-    $passed_id = (int) $temp;
+  $passed_id = (int) $temp;
 }
 
-global $default_charset;
-set_my_charset();
-
 /* end globals */
 
 global $uid_support;
 
-global $imap_stream_options; // in case not defined in config
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
+$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 $mbx_response =  sqimap_mailbox_select($imapConnection, $mailbox);
 
-$message = '';
-
-if (isset($messages[$mbx_response['UIDVALIDITY']]["$passed_id"])) {
-    $message = $messages[$mbx_response['UIDVALIDITY']]["$passed_id"];
-}
-
+$message = &$messages[$mbx_response['UIDVALIDITY']]["$passed_id"];
 if (!is_object($message)) {
     $message = sqimap_get_message($imapConnection,$passed_id, $mailbox);
 }
-
 $subject = $message->rfc822_header->subject;
 if ($ent_id) {
-    $message = $message->getEntity($ent_id);
+    $message = &$message->getEntity($ent_id);
     $header = $message->header;
 
     if ($message->rfc822_header) {
@@ -79,7 +64,7 @@ if ($ent_id) {
     /* raw message */
     $type0 = 'message';
     $type1 = 'rfc822';
-    $encoding = '7bit';
+    $encoding = 'US-ASCII';
     $header = $message->header;
 }
 
@@ -108,13 +93,11 @@ if (is_object($message->header->disposition)) {
     $filename = $header->getParameter('name');
 }
 
-$filename = decodeHeader($filename,true,false);
-$filename = charset_encode($filename,$default_charset,false);
-
-// If name is not set, use subject of email
+//$filename = decodeHeader($filename, false, false);	//Don't want html output nor utf8 because it will return html output
+$filename = decodeHeader($filename, true, false);   //Don't want html output
 if (strlen($filename) < 1) {
-    $filename = decodeHeader($subject, true, true);
-    $filename = charset_encode($filename,$default_charset,false);
+    //$filename = decodeHeader($subject, false, false);	//Don't want html output nor utf8 because it will return html output
+    $filename = decodeHeader($subject, true, false);   //Don't want html output
     if ($type1 == 'plain' && $type0 == 'text')
         $suffix = 'txt';
     else if ($type1 == 'richtext' && $type0 == 'text')
@@ -131,15 +114,6 @@ if (strlen($filename) < 1) {
     $filename = $filename . '.' . $suffix;
 }
 
-/**
- * Close session in order to prevent script locking on larger 
- * downloads. SendDownloadHeaders() and mime_print_body_lines() 
- * don't write information to session. mime_print_body_lines() 
- * call duration depends on size of attachment and script can 
- * cause interface lockups, if session is not closed.
- */
-session_write_close();
-
 /*
  * Note:
  *    The following sections display the attachment in different
@@ -163,3 +137,5 @@ if (isset($absolute_dl) && $absolute_dl) {
 /* be aware that any warning caused by download.php will corrupt the
  * attachment in case of ERROR reporting = E_ALL and the output is the screen */
 mime_print_body_lines ($imapConnection, $passed_id, $ent_id, $encoding);
+
+?>
