@@ -3,22 +3,17 @@
 /**
  * empty_trash.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Handles deleting messages from the trash folder without
  * deleting subfolders.
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: empty_trash.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: empty_trash.php,v 1.48 2003/12/01 21:56:55 cigamit Exp $
  * @package squirrelmail
  */
 
-/** This is the empty_trash page */
-define('PAGE_NAME', 'empty_trash');
-
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -36,15 +31,7 @@ sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
 
 /* finished globals */
 
-// first do a security check
-if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_FORM))
-    $submitted_token = '';
-sm_validate_security_token($submitted_token, -1, TRUE);
-
-global $imap_stream_options; // in case not defined in config
-$imap_stream = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
-
-sqimap_mailbox_list($imap_stream);
+$imap_stream = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 
 $mailbox = $trash_folder;
 $boxes = sqimap_mailbox_list($imap_stream);
@@ -57,7 +44,6 @@ $boxes = sqimap_mailbox_list($imap_stream);
 
 /** First create the top node in the tree **/
 $numboxes = count($boxes);
-$foldersTree = array();
 for ($i = 0; $i < $numboxes; $i++) {
     if (($boxes[$i]['unformatted'] == $mailbox) && (strlen($boxes[$i]['unformatted']) == strlen($mailbox))) {
         $foldersTree[0]['value'] = $mailbox;
@@ -79,12 +65,9 @@ for ($i = 0; $i < $numboxes; $i++) {
 
 // now lets go through the tree and delete the folders
 walkTreeInPreOrderEmptyTrash(0, $imap_stream, $foldersTree);
-sqimap_logout($imap_stream);
-
-// close session properly before redirecting
-session_write_close();
 
 $location = get_location();
-// force_refresh = 1 in case trash contains deleted mailboxes
-header ("Location: $location/left_main.php?force_refresh=1");
+header ("Location: $location/left_main.php");
 
+sqimap_logout($imap_stream);
+?>
