@@ -3,23 +3,18 @@
 /**
  * folders.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Handles all interaction between the user and the other folder
  * scripts which do most of the work. Also handles the Special
  * Folders.
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: folders.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: folders.php,v 1.121 2003/12/01 21:56:55 cigamit Exp $
  * @package squirrelmail
  */
 
-/** This is the folders page */
-define('PAGE_NAME', 'folders');
-
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -27,7 +22,6 @@ require_once(SM_PATH . 'include/validate.php');
 require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'functions/plugin.php');
 require_once(SM_PATH . 'functions/html.php');
-require_once(SM_PATH . 'functions/forms.php');
 
 displayPageHeader($color, 'None');
 
@@ -42,7 +36,7 @@ sqgetGlobalVar('success', $success, SQ_GET);
 
 /* end of get globals */
 
-echo '<br />' .
+echo '<br>' .
     html_tag( 'table', '', 'center', $color[0], 'width="95%" cellpadding="1" cellspacing="0" border="0"' ) .
         html_tag( 'tr' ) .
             html_tag( 'td', '', 'center' ) . '<b>' . _("Folders") . '</b>' .
@@ -57,45 +51,42 @@ if ( isset($success) && $success ) {
     switch ($success)
     {
         case 'subscribe':
-            $td_str .=  _("Subscribed successfully.");
+            $td_str .=  _("Subscribed successfully!");
             break;
         case 'unsubscribe':
-            $td_str .=  _("Unsubscribed successfully.");
+            $td_str .=  _("Unsubscribed successfully!");
             break;
         case 'delete':
-            $td_str .=  _("Deleted folder successfully.");
+            $td_str .=  _("Deleted folder successfully!");
             break;
         case 'create':
-            $td_str .=  _("Created folder successfully.");
+            $td_str .=  _("Created folder successfully!");
             break;
         case 'rename':
-            $td_str .=  _("Renamed successfully.");
+            $td_str .=  _("Renamed successfully!");
             break;
         case 'subscribe-doesnotexist':
             $td_str .=  _("Subscription Unsuccessful - Folder does not exist.");
             break;
     }
 
-    $td_str .= '</b><br />';
+    $td_str .= '</b><br>';        
 
 
     echo html_tag( 'table',
                 html_tag( 'tr',
                      html_tag( 'td', $td_str .
-                               '<a href="../src/left_main.php" target="left">' .
+                               '<a href="../src/left_main.php" target=left>' .
                                _("refresh folder list") . '</a>' ,
                      'center' )
                 ) ,
             'center', '', 'width="100%" cellpadding="4" cellspacing="0" border="0"' );
 }
 
-echo "\n<br />";
+echo "\n<br>";
 
-global $imap_stream_options; // in case not defined in config
-$imapConnection = sqimap_login ($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
-
-// force retrieval of a non cached folderlist
-$boxes = sqimap_mailbox_list($imapConnection,true);
+$imapConnection = sqimap_login ($username, $key, $imapServerAddress, $imapPort, 0);
+$boxes = sqimap_mailbox_list($imapConnection);
 
 /** CREATING FOLDERS **/
 echo html_tag( 'table', '', 'center', '', 'width="70%" cellpadding="4" cellspacing="0" border="0"' ) .
@@ -104,29 +95,27 @@ echo html_tag( 'table', '', 'center', '', 'width="70%" cellpadding="4" cellspaci
             ) .
             html_tag( 'tr' ) .
                 html_tag( 'td', '', 'center', $color[0] ) .
-     addForm('folders_create.php', 'POST', 'cf', '', '', '', TRUE).
-     addInput('folder_name', '', 25).
-     "<br />\n". _("as a subfolder of"). '<br />'.
-     "<tt><select name=\"subfolder\">\n";
+
+     "<FORM NAME=cf ACTION=\"folders_create.php\" METHOD=\"POST\">\n".
+     "<input type=TEXT SIZE=25 NAME=folder_name><BR>\n".
+     _("as a subfolder of").
+     '<BR>'.
+     "<TT><SELECT NAME=subfolder>\n";
 
 $show_selected = array();
 $skip_folders = array();
 $server_type = strtolower($imap_server_type);
 if ( $server_type == 'courier' ) {
+  array_push($skip_folders, 'inbox.trash');
   if ( $default_folder_prefix == 'INBOX.' ) {
-    array_push($skip_folders, 'INBOX');
+    array_push($skip_folders, 'inbox');
   }
-} elseif ( $server_type == 'bincimap' ) {
-    if ( $default_folder_prefix == 'INBOX/' ) {
-        // We don't need INBOX, since it is top folder
-        array_push($skip_folders, 'INBOX');
-    }
 }
 
 if ( $default_sub_of_inbox == false ) {
-    echo '<option selected="selected" value="">[ '._("None")." ]</option>\n";
+    echo '<OPTION SELECTED VALUE="">[ '._("None")." ]\n";
 } else {
-    echo '<option value="">[ '._("None")." ]</option>\n";
+    echo '<OPTION VALUE="">[ '._("None")." ]\n";
     $show_selected = array('inbox');
 }
 
@@ -136,27 +125,65 @@ if ( $default_sub_of_inbox == false ) {
 // use the long format to show subfolders in an intelligible way if parent is missing (special folder)
 echo sqimap_mailbox_option_list($imapConnection, $show_selected, $skip_folders, $boxes, 'noinferiors', true);
 
-echo "</select></tt>\n";
+echo "</SELECT></TT>\n";
 if ($show_contain_subfolders_option) {
-    echo '<br />'.
-         addCheckBox('contain_subs', FALSE, '1') .' &nbsp;'
+    echo '<br><input type=CHECKBOX NAME="contain_subs"> &nbsp;'
        . _("Let this folder contain subfolders")
-       . '<br />';
+       . '<BR>';
 }
-echo "<input type=\"submit\" value=\""._("Create")."\" />\n";
-echo "</form></td></tr>\n";
+echo "<input type=SUBMIT VALUE=\""._("Create")."\">\n";
+echo "</FORM></td></tr>\n";
 
 echo html_tag( 'tr',
             html_tag( 'td', '&nbsp;', 'left', $color[4] )
         ) ."\n";
 
 /** count special folders **/
-foreach ($boxes as $index => $aBoxData) {
-    if (! in_array($aBoxData['unformatted'],$skip_folders) && 
-        isSpecialMailbox($aBoxData['unformatted'],false) ) {
-        $skip_folders[] = $aBoxData['unformatted'];
-    }
+
+// FIX ME, why not check if the folders are defined IMHO move_to_sent, move_to_trash has nothing todo with it
+$count_special_folders = 0;
+$num_max = 1;
+if (strtolower($imap_server_type) == "courier" || $move_to_trash) {
+    $num_max++;
 }
+if ($move_to_sent) {
+    $num_max++;
+}
+if ($save_as_draft) {
+    $num_max++;
+}
+
+// What if move_to_sent = false and $sent_folder is set? Should it still be skipped?
+
+for ($p = 0, $cnt = count($boxes); $p < $cnt && $count_special_folders < $num_max; $p++) {
+    switch ($boxes[$p]['unformatted'])
+    {
+       case (strtoupper($boxes[$p]['unformatted']) == 'INBOX'):
+          ++$count_special_folders;
+	  $skip_folders[] = $boxes[$p]['unformatted'];
+	  break;
+       // FIX ME inbox.trash should be set in conf.pl
+       case 'inbox.trash':
+          if (strtolower($imap_server_type) == 'courier') {
+	      ++$count_special_folders;
+	  }
+	  break;
+       case $trash_folder:
+           ++$count_special_folders;
+           $skip_folders[] = $trash_folder;
+	   break;
+       case $sent_folder:
+           ++$count_special_folders;
+           $skip_folders[] = $sent_folder;
+	   break;
+       case $draft_folder:
+           ++$count_special_folders;
+           $skip_folders[] = $draft_folder;
+	   break;
+       default: break;
+    }	  
+}
+
 
 /** RENAMING FOLDERS **/
 echo html_tag( 'tr',
@@ -165,10 +192,10 @@ echo html_tag( 'tr',
         html_tag( 'tr' ) .
         html_tag( 'td', '', 'center', $color[0] );
 
-if (count($skip_folders) < count($boxes)) {
-    echo addForm('folders_rename_getname.php')
-       . "<tt><select name=\"old\">\n"
-       . '         <option value="">[ ' . _("Select a folder") . " ]</option>\n";
+if ($count_special_folders < count($boxes)) {
+    echo "<FORM ACTION=\"folders_rename_getname.php\" METHOD=\"POST\">\n"
+       . "<TT><SELECT NAME=old>\n"
+       . '         <OPTION VALUE="">[ ' . _("Select a folder") . " ]</OPTION>\n";
 
     // use existing IMAP connection, we have no special values to show, 
     // but we do include values to skip. Use the pre-created $boxes to save an IMAP query.
@@ -176,13 +203,13 @@ if (count($skip_folders) < count($boxes)) {
     // use long format to make sure folder names make sense when parents may be missing.
     echo sqimap_mailbox_option_list($imapConnection, 0, $skip_folders, $boxes, NULL, true);
 
-    echo "</select></tt>\n".
-         '<input type="submit" value="'.
+    echo "</SELECT></TT>\n".
+         "<input type=SUBMIT VALUE=\"".
          _("Rename").
-         "\" />\n".
-         "</form></td></tr>\n";
+         "\">\n".
+         "</FORM></td></tr>\n";
 } else {
-    echo _("No folders found") . '<br /><br /></td></tr>';
+    echo _("No folders found") . '<br><br></td></tr>';
 }
 $boxes_sub = $boxes;
 
@@ -197,22 +224,22 @@ echo html_tag( 'tr',
         html_tag( 'tr' ) .
         html_tag( 'td', '', 'center', $color[0] );
 
-if (count($skip_folders) < count($boxes)) {
-    echo addForm('folders_delete.php')
-       . "<tt><select name=\"mailbox\">\n"
-       . '         <option value="">[ ' . _("Select a folder") . " ]</option>\n";
+if ($count_special_folders < count($boxes)) {
+    echo "<FORM ACTION=\"folders_delete.php\" METHOD=\"POST\">\n"
+       . "<TT><SELECT NAME=mailbox>\n"
+       . '         <OPTION VALUE="">[ ' . _("Select a folder") . " ]</OPTION>\n";
 
     // send NULL for the flag - ALL folders are eligible for delete (except what we've got in skiplist)
     // use long format to make sure folder names make sense when parents may be missing.
     echo sqimap_mailbox_option_list($imapConnection, 0, $skip_folders, $boxes, NULL, true);
 
-    echo "</select></tt>\n"
-       . '<input type="submit" value="'
+    echo "</SELECT></TT>\n"
+       . '<input type=SUBMIT VALUE="'
        . _("Delete")
-       . "\" />\n"
+       . "\">\n"
        . "</form></td></tr>\n";
 } else {
-    echo _("No folders found") . "<br /><br /></td></tr>";
+    echo _("No folders found") . "<br><br></td></tr>";
 }
 
 echo html_tag( 'tr',
@@ -228,23 +255,26 @@ echo html_tag( 'table', '', 'center', '', 'width="70%" cellpadding="4" cellspaci
             html_tag( 'tr' ) .
                 html_tag( 'td', '', 'center', $color[0], 'width="50%"' );
 
-if (count($skip_folders) < count($boxes)) {
-    echo addForm('folders_subscribe.php?method=unsub', 'post', '', '', '', '', TRUE)
-       . "<tt><select name=\"mailbox[]\" multiple=\"multiple\" size=\"8\">\n";
+if ($count_special_folders < count($boxes)) {
+    echo "<FORM ACTION=\"folders_subscribe.php?method=unsub\" METHOD=\"POST\">\n"
+       . "<TT><SELECT NAME=\"mailbox[]\" multiple size=8>\n";
     for ($i = 0; $i < count($boxes); $i++) {
         $use_folder = true;
-        if (! isSpecialMailbox($boxes[$i]["unformatted"],false)) {
-            $box = $boxes[$i]["unformatted-dm"];
-            $box2 = str_replace(array(' ','<','>'), array('&nbsp;','&lt;','&gt;'),
-                                imap_utf7_decode_local($boxes[$i]["unformatted-disp"]));
-            echo "         <option value=\"$box\">$box2</option>\n";
+        if ((strtolower($boxes[$i]["unformatted"]) != "inbox") &&
+            ($boxes[$i]["unformatted"] != $trash_folder) &&
+            ($boxes[$i]["unformatted"] != $sent_folder) &&
+            ($boxes[$i]["unformatted"] != $draft_folder)) {
+            $box = htmlspecialchars($boxes[$i]["unformatted-dm"]);
+            $box2 = str_replace(' ', '&nbsp;',
+                                htmlspecialchars(imap_utf7_decode_local($boxes[$i]["unformatted-disp"])));
+            echo "         <OPTION VALUE=\"$box\">$box2\n";
         }
     }
-    echo "</select></tt><br /><br />\n"
-       . '<input type="submit" value="'
+    echo "</SELECT></TT><br><br>\n"
+       . '<input type=SUBMIT VALUE="'
        . _("Unsubscribe")
-       . "\" />\n"
-       . "</form></td>\n";
+       . "\">\n"
+       . "</FORM></td>\n";
 } else {
     echo _("No folders were found to unsubscribe from!") . '</td>';
 }
@@ -255,7 +285,8 @@ echo html_tag( 'td', '', 'center', $color[0], 'width="50%"' );
 if(!$no_list_for_subscribe) {
   $boxes_all = sqimap_mailbox_list_all ($imapConnection);
 
-  $box = $box2 = array();
+  $box = '';
+  $box2 = '';
   for ($i = 0, $q = 0; $i < count($boxes_all); $i++) {
     $use_folder = true;
     for ($p = 0; $p < count ($boxes); $p++) {
@@ -267,43 +298,44 @@ if(!$no_list_for_subscribe) {
         }
     }
     if ($use_folder == true) {
-        $box[$q] = $boxes_all[$i]['unformatted-dm'];
-        $box2[$q] = imap_utf7_decode_local($boxes_all[$i]['unformatted-disp']);
+        $box[$q] = htmlspecialchars($boxes_all[$i]['unformatted-dm']);
+        $box2[$q] = htmlspecialchars(imap_utf7_decode_local($boxes_all[$i]['unformatted-disp']));
         $q++;
     }
   }
-  
-  if (count($box) > 0) {
-    echo addForm('folders_subscribe.php?method=sub', 'post', '', '', '', '', TRUE)
-       . '<tt><select name="mailbox[]" multiple="multiple" size="8">';
+  if ($box && $box2) {
+    echo "<FORM ACTION=\"folders_subscribe.php?method=sub\" METHOD=\"POST\">\n"
+       . '<tt><select name="mailbox[]" multiple size=8>';
 
     for ($q = 0; $q < count($box); $q++) {      
-        echo '         <option value="' . $box[$q] . '">' .
-            str_replace(array(' ','<','>'),array('&nbsp;','&lt;','&gt;'),$box2[$q])."</option>\n";
+       echo "         <OPTION VALUE=\"$box[$q]\">".$box2[$q]."\n";
     }      
-    echo '</select></tt><br /><br />'
-       . '<input type="submit" value="'. _("Subscribe") . "\" />\n"
-       . "</form></td></tr></table><br />\n";
+    echo '</select></tt><br><br>'
+       . '<input type=SUBMIT VALUE="'. _("Subscribe") . "\">\n"
+       . "</FORM></td></tr></table><BR>\n";
   } else {
     echo _("No folders were found to subscribe to!") . '</td></tr></table>';
   }
 } else {
   /* don't perform the list action -- this is much faster */
-  echo addForm('folders_subscribe.php?method=sub', 'post', '', '', '', '', TRUE)
-     . _("Subscribe to:") . '<br />'
-     . '<tt><input type="text" name="mailbox[]" size="35" />'
-     . '<input type="submit" value="'. _("Subscribe") . "\" />\n"
-     . "</form></td></tr></table>\n";
+  echo "<FORM ACTION=\"folders_subscribe.php?method=sub\" METHOD=\"POST\">\n"
+     . _("Subscribe to:") . '<br>'
+     . '<tt><input type="text" name="mailbox[]" size=35>'
+     . '<INPUT TYPE=SUBMIT VALUE="'. _("Subscribe") . "\">\n"
+     . "</FORM></TD></TR></TABLE><BR>\n";
 }
-echo "\n<br /><br />\n";
 
 do_hook('folders_bottom');
 ?>
+
     </td></tr>
     </table>
+
 </td></tr>
 </table>
+
 <?php
    sqimap_logout($imapConnection);
 ?>
+
 </body></html>
