@@ -3,22 +3,17 @@
 /**
  * folders_create.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Creates folders on the IMAP server.
  * Called from folders.php
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: folders_create.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: folders_create.php,v 1.65 2003/10/29 15:25:10 tassium Exp $
  * @package squirrelmail
  */
 
-/** This is the folders_create page */
-define('PAGE_NAME', 'folders_create');
-
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -34,25 +29,17 @@ sqgetGlobalVar('onetimepad',   $onetimepad,    SQ_SESSION);
 sqgetGlobalVar('delimiter',    $delimiter,     SQ_SESSION);
 sqgetGlobalVar('folder_name',  $folder_name,   SQ_POST);
 sqgetGlobalVar('subfolder',    $subfolder,     SQ_POST);
-if (! sqgetGlobalVar('contain_subs', $contain_subs,  SQ_POST)) {
-    unset($contain_subs);
-}
-if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_POST)) {
-    $submitted_token = '';
-}
+sqgetGlobalVar('contain_subs', $contain_subs,  SQ_POST);
 /* end of get globals */
 
-// first, validate security token
-sm_validate_security_token($submitted_token, -1, TRUE);
-
 $folder_name = trim($folder_name);
 
 if (substr_count($folder_name, '"') || substr_count($folder_name, "\\") ||
     substr_count($folder_name, $delimiter) || ($folder_name == '')) {
     displayPageHeader($color, 'None');
 
-    plain_error_message(_("Illegal folder name. Please select a different name.").
-        '<br /><a href="../src/folders.php">'._("Click here to go back").'</a>.', $color);
+    plain_error_message(_("Illegal folder name.  Please select a different name.").
+        '<BR><A HREF="../src/folders.php">'._("Click here to go back").'</A>.', $color);
 
     exit;
 }
@@ -60,9 +47,7 @@ if (substr_count($folder_name, '"') || substr_count($folder_name, "\\") ||
 $folder_name = imap_utf7_encode_local($folder_name);
 
 if (isset($contain_subs) && $contain_subs ) {
-    $folder_type = 'noselect';
-} else {
-    $folder_type = '';
+    $folder_name = $folder_name . $delimiter;
 }
 
 if ($folder_prefix && (substr($folder_prefix, -1) != $delimiter)) {
@@ -75,13 +60,12 @@ if ($folder_prefix && (substr($subfolder, 0, strlen($folder_prefix)) != $folder_
     $subfolder_orig = $subfolder;
 }
 
-global $imap_stream_options; // in case not defined in config
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
+$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 
 if (trim($subfolder_orig) == '') {
-    sqimap_mailbox_create ($imapConnection, $folder_prefix.$folder_name, $folder_type);
+    sqimap_mailbox_create ($imapConnection, $folder_prefix.$folder_name, '');
 } else {
-    sqimap_mailbox_create ($imapConnection, $subfolder.$delimiter.$folder_name, $folder_type);
+    sqimap_mailbox_create ($imapConnection, $subfolder.$delimiter.$folder_name, '');
 }
 
 sqimap_logout($imapConnection);
@@ -89,3 +73,4 @@ sqimap_logout($imapConnection);
 $location = get_location();
 header ("Location: $location/folders.php?success=create");
 
+?>
