@@ -3,22 +3,17 @@
 /**
  * folders_delete.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Deletes folders from the IMAP server. 
  * Called from the folders.php
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: folders_delete.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: folders_delete.php,v 1.62 2003/10/29 15:25:10 tassium Exp $
  * @package squirrelmail
  */
 
-/** This is the folders_delete page */
-define('PAGE_NAME', 'folders_delete');
-
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -28,7 +23,6 @@ require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'functions/tree.php');
 require_once(SM_PATH . 'functions/display_messages.php');
 require_once(SM_PATH . 'functions/html.php');
-require_once(SM_PATH . 'functions/forms.php');
 
 /*
  *  Incoming values:
@@ -41,16 +35,13 @@ sqgetGlobalVar('username',  $username,      SQ_SESSION);
 sqgetGlobalVar('onetimepad',$onetimepad,    SQ_SESSION);
 sqgetGlobalVar('delimiter', $delimiter,     SQ_SESSION);
 sqgetGlobalVar('mailbox',   $mailbox,       SQ_POST);
-if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_POST)) {
-    $submitted_token = '';
-}
 /* end globals */
 
 if ($mailbox == '') {
     displayPageHeader($color, 'None');
 
     plain_error_message(_("You have not selected a folder to delete. Please do so.").
-        '<br /><a href="../src/folders.php">'._("Click here to go back").'</a>.', $color);
+	'<BR><A HREF="../src/folders.php">'._("Click here to go back").'</A>.', $color);
     exit;
 }
 
@@ -63,36 +54,25 @@ if ( sqgetGlobalVar('backingout', $tmp, SQ_POST) ) {
 if( !sqgetGlobalVar('confirmed', $tmp, SQ_POST) ) {
     displayPageHeader($color, 'None');
 
-    // get displayable mailbox format
-    global $folder_prefix;
-    if (substr($mailbox,0,strlen($folder_prefix))==$folder_prefix) {
-        $mailbox_unformatted_disp = substr($mailbox, strlen($folder_prefix));
-    } else {
-        $mailbox_unformatted_disp = $mailbox;
-    }
-
-    echo '<br />' .
+    echo '<br>' .
         html_tag( 'table', '', 'center', '', 'width="95%" border="0"' ) .
         html_tag( 'tr',
             html_tag( 'td', '<b>' . _("Delete Folder") . '</b>', 'center', $color[0] )
         ) .
         html_tag( 'tr' ) .
         html_tag( 'td', '', 'center', $color[4] ) .
-        sprintf(_("Are you sure you want to delete %s?"), str_replace(array(' ','<','>'),array('&nbsp;','&lt;','&gt;'),imap_utf7_decode_local($mailbox_unformatted_disp))).
-        addForm('folders_delete.php', 'post', '', '', '', '', TRUE)."<p>\n".
-        addHidden('mailbox', $mailbox).
-        addSubmit(_("Yes"), 'confirmed').
-        addSubmit(_("No"), 'backingout').
-        '</p></form><br /></td></tr></table>';
+        sprintf(_("Are you sure you want to delete %s?"), imap_utf7_decode_local($mailbox)).
+        '<FORM ACTION="folders_delete.php" METHOD="POST"><p>'.
+
+        '<INPUT TYPE=HIDDEN NAME="mailbox" VALUE="' . htmlspecialchars($mailbox) . "\">\n" .
+        '<INPUT TYPE=SUBMIT NAME="confirmed" VALUE="'._("Yes")."\">\n".
+        '<INPUT TYPE=SUBMIT NAME="backingout" VALUE="'._("No")."\">\n".
+        '</p></FORM><BR></td></tr></table>';
 
     exit;
 }
 
-// first, validate security token
-sm_validate_security_token($submitted_token, -1, TRUE);
-
-global $imap_stream_options; // in case not defined in config
-$imap_stream = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
+$imap_stream = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 
 $boxes = sqimap_mailbox_list ($imap_stream);
 $numboxes = count($boxes);
@@ -106,8 +86,14 @@ else
 
 /** lets see if we CAN move folders to the trash.. otherwise,
     ** just delete them **/
-if ((isset($delete_folder) && $delete_folder) ||
-    preg_match('/^' . preg_quote($trash_folder, '/') . '.+/i', $mailbox) ) {
+
+/* Courier IMAP doesn't like subfolders of Trash
+ * If global options say we can't move it into Trash
+ * If it's already a subfolder of trash, we'll have to delete it */
+if (strtolower($imap_server_type) == 'courier' || 
+    (isset($delete_folder) && $delete_folder) ||
+    eregi('^'.$trash_folder.'.+', $mailbox) )
+{
     $can_move_to_trash = FALSE;
 }
 
@@ -152,3 +138,4 @@ sqimap_logout($imap_stream);
 $location = get_location();
 header ("Location: $location/folders.php?success=delete");
 
+?>
