@@ -3,22 +3,17 @@
 /**
  * folders_rename_do.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Does the actual renaming of files on the IMAP server.
  * Called from the folders.php
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: folders_rename_do.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: folders_rename_do.php,v 1.50 2003/10/29 15:25:10 tassium Exp $
  * @package squirrelmail
  */
 
-/** This is the folders_rename_do page */
-define('PAGE_NAME', 'folders_rename_do');
-
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -35,22 +30,16 @@ sqgetGlobalVar('onetimepad',$onetimepad,    SQ_SESSION);
 sqgetGlobalVar('orig',      $orig,          SQ_POST);
 sqgetGlobalVar('old_name',  $old_name,      SQ_POST);
 sqgetGlobalVar('new_name',  $new_name,      SQ_POST);
-if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_POST)) {
-    $submitted_token = '';
-}
 /* end globals */
 
-// first, validate security token
-sm_validate_security_token($submitted_token, -1, TRUE);
-
 $new_name = trim($new_name);
 
 if (substr_count($new_name, '"') || substr_count($new_name, "\\") ||
     substr_count($new_name, $delimiter) || ($new_name == '')) {
     displayPageHeader($color, 'None');
 
-    plain_error_message(_("Illegal folder name. Please select a different name.").
-        '<br /><a href="../src/folders.php">'._("Click here to go back").'</a>.', $color);
+    plain_error_message(_("Illegal folder name.  Please select a different name.").
+        '<BR><A HREF="../src/folders.php">'._("Click here to go back").'</A>.', $color);
 
     exit;
 }
@@ -61,8 +50,7 @@ $new_name = imap_utf7_encode_local($new_name);
 
 if ($old_name <> $new_name) {
 
-    global $imap_stream_options; // in case not defined in config
-    $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
+    $imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 
     if (strpos($orig, $delimiter)) {
         $old_dir = substr($orig, 0, strrpos($orig, $delimiter));
@@ -91,3 +79,4 @@ if ($old_name <> $new_name) {
 
 header ('Location: ' . get_location() . '/folders.php?success=rename');
 
+?>
