@@ -3,22 +3,17 @@
 /**
  * folders_rename_getname.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Gets folder names and enables renaming
  * Called from folders.php
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: folders_rename_getname.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: folders_rename_getname.php,v 1.49 2003/10/29 15:25:10 tassium Exp $
  * @package squirrelmail
  */
 
-/** This is the folders_rename_getname page */
-define('PAGE_NAME', 'folders_rename_getname');
-
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -27,7 +22,6 @@ require_once(SM_PATH . 'functions/global.php');
 require_once(SM_PATH . 'functions/imap_mailbox.php');
 require_once(SM_PATH . 'functions/html.php');
 require_once(SM_PATH . 'functions/display_messages.php');
-require_once(SM_PATH . 'functions/forms.php');
 
 /* get globals we may need */
 sqgetGlobalVar('key',       $key,           SQ_COOKIE);
@@ -41,7 +35,7 @@ if ($old == '') {
     displayPageHeader($color, 'None');
 
     plain_error_message(_("You have not selected a folder to rename. Please do so.").
-        '<br /><a href="../src/folders.php">'._("Click here to go back").'</a>.', $color);
+        '<BR><A HREF="../src/folders.php">'._("Click here to go back").'</A>.', $color);
     exit;
 }
 
@@ -54,43 +48,33 @@ if (substr($old, strlen($old) - strlen($delimiter)) == $delimiter) {
 
 $old = imap_utf7_decode_local($old);
 
-// displayable mailbox format is without folder prefix on front
-global $folder_prefix;
-if (substr($old, 0, strlen($folder_prefix)) == $folder_prefix) {
-    $displayable_old = substr($old, strlen($folder_prefix));
+if (strpos($old, $delimiter)) {
+    $old_name = substr($old, strrpos($old, $delimiter)+1, strlen($old));
+    $old_parent = substr($old, 0, strrpos($old, $delimiter));
 } else {
-    $displayable_old = $old;
-}
-
-if (strpos($displayable_old, $delimiter)) {
-    $old_name = substr($displayable_old, strrpos($displayable_old, $delimiter)+1);
-    $parent = sm_encode_html_special_chars(substr($displayable_old, 
-                                      0, 
-                                      strrpos($displayable_old, $delimiter))
-            . ' ' . $delimiter);
-} else {
-    $old_name = $displayable_old;
-    $parent = '';
+    $old_name = $old;
+    $old_parent = '';
 }
 
 
 displayPageHeader($color, 'None');
-echo '<br />' .
+echo '<br>' .
     html_tag( 'table', '', 'center', '', 'width="95%" border="0"' ) .
         html_tag( 'tr',
             html_tag( 'td', '<b>' . _("Rename a folder") . '</b>', 'center', $color[0] )
         ) .
         html_tag( 'tr' ) .
             html_tag( 'td', '', 'center', $color[4] ) .
-            addForm('folders_rename_do.php', 'post', '', '', '', '', TRUE).
+            '<FORM ACTION="folders_rename_do.php" METHOD="POST">'.
      _("New name:").
-     '<br /><b>'. $parent . '</b>'.
-     addInput('new_name', $old_name, 25) . '<br />' . "\n";
+     '<br><b>' . htmlspecialchars($old_parent) . ' ' . htmlspecialchars($delimiter) . '</b>' .
+     '<INPUT TYPE="TEXT" SIZE="25" NAME="new_name" VALUE="' . htmlspecialchars($old_name) . '"><BR>' . "\n";
 if ( $isfolder ) {
-    echo addHidden('isfolder', 'true');
+    echo '<INPUT TYPE=HIDDEN NAME="isfolder" VALUE="true">';
 }
-echo addHidden('orig', $old).
-     addHidden('old_name', $old_name).
-     '<input type="submit" value="'._("Submit")."\" />\n".
-     '</form><br /></td></tr></table>';
+printf("<INPUT TYPE=HIDDEN NAME=\"orig\" VALUE=\"%s\">\n", htmlspecialchars($old));
+printf("<INPUT TYPE=HIDDEN NAME=\"old_name\" VALUE=\"%s\">\n", htmlspecialchars($old_name));
+echo '<INPUT TYPE=SUBMIT VALUE="'._("Submit")."\">\n".
+     '</FORM><BR></td></tr></table>';
 
+?>
