@@ -3,22 +3,17 @@
 /**
  * folders_subscribe.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Subscribe and unsubcribe from folders. 
  * Called from folders.php
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: folders_subscribe.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: folders_subscribe.php,v 1.29 2003/10/29 15:25:10 tassium Exp $
  * @package squirrelmail
  */
 
-/** This is the folders_subscribe page */
-define('PAGE_NAME', 'folders_subscribe');
-
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -33,14 +28,8 @@ sqgetGlobalVar('username',  $username,      SQ_SESSION);
 sqgetGlobalVar('onetimepad',$onetimepad,    SQ_SESSION);
 sqgetGlobalVar('method',    $method,        SQ_GET);
 sqgetGlobalVar('mailbox',   $mailbox,       SQ_POST);
-if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_POST)) {
-    $submitted_token = '';
-}
 /* end globals */
 
-// first, validate security token
-sm_validate_security_token($submitted_token, -1, TRUE);
-
 $location = get_location();
 
 if (!isset($mailbox) || !isset($mailbox[0]) || $mailbox[0] == '') {
@@ -49,13 +38,12 @@ if (!isset($mailbox) || !isset($mailbox[0]) || $mailbox[0] == '') {
     exit(0);
 }
 
-global $imap_stream_options; // in case not defined in config
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
+$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 
 if ($method == 'sub') {
     if($no_list_for_subscribe && $imap_server_type == 'cyrus') {
        /* Cyrus, atleast, does not typically allow subscription to
-        * nonexistent folders (this is an optional part of IMAP),
+	* nonexistent folders (this is an optional part of IMAP),
         * lets catch it here and report back cleanly. */
        if(!sqimap_mailbox_exists($imapConnection, $mailbox[0])) {
           header("Location: $location/folders.php?success=subscribe-doesnotexist");
@@ -79,3 +67,4 @@ if ($method == 'sub') {
 sqimap_logout($imapConnection);
 header("Location: $location/folders.php?success=$success");
 
+?>
