@@ -3,21 +3,16 @@
 /**
  * image.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * This file shows an attached image
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: image.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: image.php,v 1.22 2003/12/01 21:56:55 cigamit Exp $
  * @package squirrelmail
  */
 
-/** This is the image page */
-define('PAGE_NAME', 'image');
-
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -39,11 +34,11 @@ sqgetGlobalVar('ent_id',        $ent_id,        SQ_GET);
 sqgetGlobalVar('QUERY_STRING',  $QUERY_STRING,  SQ_SERVER);
 /* end globals */
 
-echo '<br />' . 
-    '<table width="100%" border="0" cellspacing="0" cellpadding="2" align="center">' .
+echo '<BR>' . 
+    '<TABLE WIDTH="100%" BORDER=0 CELLSPACING=0 CELLPADDING=2 ALIGN=CENTER>' .
     "\n" .
-    '<tr><td bgcolor="' . $color[0] . '">' .
-    '<b><center>' .
+    '<TR><TD BGCOLOR="' . $color[0] . '">' .
+    '<B><CENTER>' .
     _("Viewing an image attachment") . " - ";
 
 $msg_url = 'read_body.php?' . $QUERY_STRING;
@@ -54,15 +49,18 @@ echo '<a href="'.$msg_url.'">'. _("View message") . '</a>';
 $DownloadLink = '../src/download.php?passed_id=' . $passed_id .
                '&amp;mailbox=' . urlencode($mailbox) . 
                '&amp;ent_id=' . urlencode($ent_id) . '&amp;absolute_dl=true';
+
+echo '</b></td></tr>' . "\n" .
+    '<tr><td align=center><A HREF="' . $DownloadLink . '">' .
+    _("Download this as a file") .
+    '</A></B><BR>&nbsp;' . "\n" .
+    '</TD></TR></TABLE>' . "\n" .
+
+    '<TABLE BORDER=0 CELLSPACING=0 CELLPADDING=2 ALIGN=CENTER>' . "\n" .
+    '<TR><TD BGCOLOR="' . $color[4] . '">' .
+    '<img src="' . $DownloadLink . '">' .
+
+    '</TD></TR></TABLE>' . "\n";
+    '</body></html>' . "\n";
+
 ?>
-</b></td></tr>
-<tr><td align="center">
-<a href="<?php echo $DownloadLink; ?>"><?php echo _("Download this as a file"); ?></a>
-<br />&nbsp;</td></tr></table>
-
-<table border="0" cellspacing="0" cellpadding="2" align="center">
-<tr><td bgcolor="<?php echo $color[4]; ?>">
-<img src="<?php echo $DownloadLink; ?>" />
-
-</td></tr></table>
-</body></html>
\ No newline at end of file
