@@ -3,18 +3,16 @@
 /**
  * move_messages.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Enables message moving between folders on the IMAP server.
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: move_messages.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: move_messages.php,v 1.93 2003/12/01 21:56:57 cigamit Exp $
  * @package squirrelmail
  */
 
-/** This is the move_messages page */
-define('PAGE_NAME', 'move_messages');
-
-/* Path for SquirrelMail required files. */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -27,32 +25,27 @@ require_once(SM_PATH . 'functions/html.php');
 global $compose_new_win;
 
 if ( !sqgetGlobalVar('composesession', $composesession, SQ_SESSION) ) {
-  $composesession = 0;
+    $composesession = 0;
 }
 
 function attachSelectedMessages($msg, $imapConnection) {
     global $username, $attachment_dir, $startMessage,
-           $data_dir, $composesession, $uid_support, $mailbox,
-       $msgs, $thread_sort_messages, $allow_server_sort, $show_num;
+           $data_dir, $composesession, $uid_support,
+           $msgs, $show_num, $compose_messages;
+
+    if (!isset($compose_messages)) {
+        $compose_messages = array();
+        sqsession_register($compose_messages,'compose_messages');
+    }
 
     if (!$composesession) {
         $composesession = 1;
-            sqsession_register($composesession,'composesession');
+        sqsession_register($composesession,'composesession');
     } else {
         $composesession++;
         sqsession_register($composesession,'composesession');
     }
 
-    $hashed_attachment_dir = getHashedDir($username, $attachment_dir, $composesession);
-
-    if ($thread_sort_messages || $allow_server_sort) {
-       $start_index=0;
-    } else {
-       $start_index = ($startMessage-1) * $show_num;
-    }
-
-    $i = 0;
-    $j = 0;
     $hashed_attachment_dir = getHashedDir($username, $attachment_dir);
 
     $composeMessage = new Message();
@@ -60,64 +53,36 @@ function attachSelectedMessages($msg, $imapConnection) {
     $composeMessage->rfc822_header = $rfc822_header;
     $composeMessage->reply_rfc822_header = '';
 
-    while ($j < count($msg)) {
-        if (isset($msg[$i])) {
-            $id = $msg[$i];
-            
-            $body_a = sqimap_run_command($imapConnection, "FETCH $id RFC822",true, $response, $readmessage, $uid_support);
-            
-            if ($response == 'OK') {
-                $message = sqimap_get_message($imapConnection, $id, $mailbox);
+    foreach($msg as $id) {
+        $body_a = sqimap_run_command($imapConnection, "FETCH $id RFC822", true, $response, $readmessage, $uid_support);
 
-                // fetch the subject for the message from the object
-                //
-                $subject = $message->rfc822_header->subject;
+        if ($response == 'OK') {
 
-                // use subject for file name
-                //
-                if ( empty($subject) )
-                    $filename = "untitled-".$message->entity_id;
-                else
-                    $filename = $subject;
-                $filename .= '.eml';
-
-                // figure out a subject for new message
-                //
-                $subject = decodeHeader($subject, false, false, true);
-                $subject = trim($subject);
-                if (substr(strtolower($subject), 0, 4) != 'fwd:') {
-                    $subject = 'Fwd: ' . $subject;
+            // fetch the subject for the message with $id from msgs.
+            // is there a more efficient way to do this?
+            foreach($msgs as $k => $vals) {
+                if($vals['ID'] == $id) {
+                    $subject = $msgs[$k]['SUBJECT'];
+                    break;
                 }
-
-                array_shift($body_a);
-                array_pop($body_a);
-                $body = implode('', $body_a);
-                $body .= "\r\n";
-
-                $localfilename = GenerateRandomString(32, 'FILE', 7);
-                $full_localfilename = "$hashed_attachment_dir/$localfilename";
-                while (file_exists($full_localfilename)) {
-                    $localfilename = GenerateRandomString(32, 'FILE', 7);
-                    $full_localfilename = "$hashed_attachment_dir/$localfilename";
-                }
-
-                $fp = fopen( $full_localfilename, 'wb');
-                fwrite ($fp, $body);
-                fclose($fp);
-                $composeMessage->initAttachment('message/rfc822',$filename,
-                     $localfilename);
-                $composeMessage->rfc822_header->subject = $subject;
             }
-            $j++;
+
+            array_shift($body_a);
+            array_pop($body_a);
+            $body = implode('', $body_a);
+            $body .= "\r\n";
+
+            $localfilename = GenerateRandomString(32, 'FILE', 7);
+            $full_localfilename = "$hashed_attachment_dir/$localfilename";
+
+            $fp = fopen( $full_localfilename, 'wb');
+            fwrite ($fp, $body);
+            fclose($fp);
+            $composeMessage->initAttachment('message/rfc822',$subject.'.msg',
+                 $full_localfilename);
         }
-        $i++;
     }
 
-    sqgetGlobalVar('compose_messages', $compose_messages, SQ_SESSION);
-    if (!isset($compose_messages)
-     || !is_array($compose_messages)) {
-        $compose_messages = array();
-    }
     $compose_messages[$composesession] = $composeMessage;
     sqsession_register($compose_messages,'compose_messages');
     session_write_close();
@@ -150,26 +115,16 @@ sqgetGlobalVar('markRead',        $markRead,        SQ_POST);
 sqgetGlobalVar('markUnread',      $markUnread,      SQ_POST);
 sqgetGlobalVar('attache',         $attache,         SQ_POST);
 sqgetGlobalVar('location',        $location,        SQ_POST);
+sqgetGlobalVar('bypass_trash',    $bypass_trash,    SQ_POST);
 
-if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_FORM)) {
-    $submitted_token = '';
-}
 /* end of get globals */
 
-// security check
-sm_validate_security_token($submitted_token, -1, TRUE);
-
-global $imap_stream_options; // in case not defined in config
-$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
+$imapConnection = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 $mbx_response=sqimap_mailbox_select($imapConnection, $mailbox);
 
 $location = set_url_var($location,'composenew',0,false);
 $location = set_url_var($location,'composesession',0,false);
 $location = set_url_var($location,'session',0,false);
-$location = set_url_var($location,'preselected',NULL,false,true);
-
-// make sure that cache is not used
-$location = set_url_var($location,'use_mailbox_cache',0,false);
 
 /* remember changes to mailbox setting */
 if (!isset($lastTargetMailbox)) {
@@ -218,48 +173,30 @@ if(isset($expungeButton)) {
     if (count($id)) {
         $cnt = count($id);
         if (!isset($attache)) {
+            $button_action = concat_hook_function('move_messages_button_action');
             if (isset($markRead)) {
                 sqimap_toggle_flag($imapConnection, $id, '\\Seen',true,true);
             } else if (isset($markUnread)) {
                 sqimap_toggle_flag($imapConnection, $id, '\\Seen',false,true);
             } else  {
-                sqimap_msgs_list_delete($imapConnection, $mailbox, $id);
-                if ($auto_expunge) {
-                    $cnt = sqimap_mailbox_expunge($imapConnection, $mailbox, true);
-                }
-                if (($startMessage+$cnt-1) >= $mbx_response['EXISTS']) {
-                    if ($startMessage > $show_num) {
-                        $location = set_url_var($location,'startMessage',$startMessage-$show_num, false);
-                    } else {
-                        $location = set_url_var($location,'startMessage',1, false);
+                if (!$button_action) {
+                    sqimap_msgs_list_delete($imapConnection, $mailbox, $id,$bypass_trash);
+                    if ($auto_expunge) {
+                        $cnt = sqimap_mailbox_expunge($imapConnection, $mailbox, true);
                     }
                 }
             }
-        } else {
+        }
+        if (isset($attache)) {
             $composesession = attachSelectedMessages($id, $imapConnection);
             $location = set_url_var($location, 'session', $composesession, false);
-            $location = set_url_var($location, 'forward_as_attachment_init', 1, false);
             if ($compose_new_win) {
                 $location = set_url_var($location, 'composenew', 1, false);
             } else {
                 $location = str_replace('search.php','compose.php',$location);
                 $location = str_replace('right_main.php','compose.php',$location);
             }
-        }
-    } else {
-        $exception = true;
-    }
-} else {    // Move messages
-    if (count($id)) {
-        // move messages only when target mailbox is not the same as source mailbox
-        if ($mailbox!=$targetMailbox) {
-            sqimap_msgs_list_move($imapConnection,$id,$targetMailbox);
-            if ($auto_expunge) {
-                $cnt = sqimap_mailbox_expunge($imapConnection, $mailbox, true);
-            } else {
-                $cnt = 0;
-            }
-
+        } else {
             if (($startMessage+$cnt-1) >= $mbx_response['EXISTS']) {
                 if ($startMessage > $show_num) {
                     $location = set_url_var($location,'startMessage',$startMessage-$show_num, false);
@@ -271,6 +208,26 @@ if(isset($expungeButton)) {
     } else {
         $exception = true;
     }
+} else {    // Move messages
+
+    if (count($id)) {
+        sqimap_msgs_list_move($imapConnection,$id,$targetMailbox);
+        if ($auto_expunge) {
+            $cnt = sqimap_mailbox_expunge($imapConnection, $mailbox, true);
+        } else {
+            $cnt = 0;
+        }
+
+        if (($startMessage+$cnt-1) >= $mbx_response['EXISTS']) {
+            if ($startMessage > $show_num) {
+                $location = set_url_var($location,'startMessage',$startMessage-$show_num, false);
+            } else {
+                $location = set_url_var($location,'startMessage',1, false);
+            }
+        }
+    } else {
+        $exception = true;
+    }
 }
 // Log out this session
 sqimap_logout($imapConnection);
@@ -282,4 +239,4 @@ if ($exception) {
     exit;
 }
 ?>
-</body></html>
+</BODY></HTML>
