@@ -3,23 +3,17 @@
 /**
  * options.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Displays the options page. Pulls from proper user preference files
  * and config.php. Displays preferences as selected and other options.
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: options.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: options.php,v 1.128 2003/12/01 21:56:57 cigamit Exp $
  * @package squirrelmail
- * @subpackage prefs
  */
 
-/** This is the options page */
-define('PAGE_NAME', 'options');
-
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -30,7 +24,6 @@ require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'functions/options.php');
 require_once(SM_PATH . 'functions/strings.php');
 require_once(SM_PATH . 'functions/html.php');
-require_once(SM_PATH . 'functions/forms.php');
 
 /*********************************/
 /*** Build the resultant page. ***/
@@ -47,19 +40,6 @@ define('SMOPT_PAGE_HIGHLIGHT', 'highlight');
 define('SMOPT_PAGE_FOLDER', 'folder');
 define('SMOPT_PAGE_ORDER', 'order');
 
-/**
-  * Save submitted options and calculate the most 
-  * we need to refresh the page
-  *
-  * @param string $optpage      The name of the page being submitted
-  * @param array  $optpage_data An array of all the submitted options
-  *
-  * @return int The highest level of screen refresh needed per
-  *             the options that were changed.  This value will
-  *             correspond to the SMOPT_REFRESH_* constants found
-  *             in functions/options.php.
-  *
-  */
 function process_optionmode_submit($optpage, $optpage_data) {
     /* Initialize the maximum option refresh level. */
     $max_refresh = SMOPT_REFRESH_NONE;
@@ -71,7 +51,7 @@ function process_optionmode_submit($optpage, $optpage_data) {
             echo "name = '$option->name', "
                . "value = '$option->value', "
                . "new_value = '$option->new_value'\n";
-            echo "<br />";
+            echo "<br>";
             */
             if ($option->changed()) {
                 $option->save();
@@ -143,9 +123,6 @@ sqgetGlobalVar('delimiter', $delimiter,     SQ_SESSION);
 sqgetGlobalVar('optpage',     $optpage);
 sqgetGlobalVar('optmode',     $optmode,      SQ_FORM);
 sqgetGlobalVar('optpage_data',$optpage_data, SQ_POST);
-if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_FORM)) {
-    $submitted_token = '';
-}
 /* end of getting globals */
 
 /* Make sure we have an Option Page set. Default to main. */
@@ -229,15 +206,6 @@ if ( !@is_file( $optpage_file ) ) {
 /*** Next, process anything that needs to be processed. ***/
 /***********************************************************/
 
-// security check before saving anything...
-//FIXME: what about SMOPT_MODE_LINK??
-if ($optmode == SMOPT_MODE_SUBMIT) {
-   sm_validate_security_token($submitted_token, -1, TRUE);
-}
-
-// set empty error message
-$optpage_save_error=array();
-
 if ( isset( $optpage_data ) ) {
     switch ($optmode) {
         case SMOPT_MODE_SUBMIT:
@@ -289,7 +257,6 @@ if ($optmode == SMOPT_MODE_SUBMIT) {
 
 if ($optmode == SMOPT_MODE_SUBMIT) {
     $optpage = SMOPT_PAGE_MAIN;
-    $optpage_title = _("Options");
 }
 
 /***************************************************************/
@@ -301,7 +268,7 @@ displayPageHeader($color, 'None', (isset($optpage_data['xtra']) ? $optpage_data[
 echo html_tag( 'table', '', 'center', $color[0], 'width="95%" cellpadding="1" cellspacing="0" border="0"' ) . "\n" .
         html_tag( 'tr' ) . "\n" .
             html_tag( 'td', '', 'center' ) .
-                "<b>$optpage_title</b><br />\n".
+                "<b>$optpage_title</b><br>\n".
                 html_tag( 'table', '', '', '', 'width="100%" cellpadding="5" cellspacing="0" border="0"' ) . "\n" .
                     html_tag( 'tr' ) . "\n" .
                         html_tag( 'td', '', 'center', $color[4] ) . "\n";
@@ -318,27 +285,15 @@ if ($optpage == SMOPT_PAGE_MAIN) {
         if (!isset($frame_top)) {
             $frame_top = '_top';
         }
-
-        if (isset($optpage_save_error) && $optpage_save_error!=array()) {
-            echo "<font color=\"$color[2]\"><b>" . _("Error(s) occurred while saving your options") . "</b></font><br />\n";
-            echo "<ul>\n";
-            foreach ($optpage_save_error as $error_message) {
-                echo '<li><small>' . $error_message . "</small></li>\n";
-            }
-            echo "</ul>\n";
-            echo '<b>' . _("Some of your preference changes were not applied.") . "</b><br />\n";
-        } else {
-            /* Display a message indicating a successful save. */
-            // i18n: The %s represents the name of the option page saving the options
-            echo '<b>' . sprintf(_("Successfully Saved Options: %s"), $optpage_name) . "</b><br />\n";
-        }
+        /* Display a message indicating a successful save. */
+        echo '<b>' . _("Successfully Saved Options") . ": $optpage_name</b><br>\n";
 
         /* If $max_refresh != SMOPT_REFRESH_NONE, provide a refresh link. */
         if ( !isset( $max_refresh ) ) {
         } else if ($max_refresh == SMOPT_REFRESH_FOLDERLIST) {
-            echo '<a href="../src/left_main.php" target="left">' . _("Refresh Folder List") . '</a><br />';
+            echo '<a href="../src/left_main.php" target="left">' . _("Refresh Folder List") . '</a><br>';
         } else if ($max_refresh) {
-            echo '<a href="../src/webmail.php?right_frame=options.php" target="' . $frame_top . '">' . _("Refresh Page") . '</a><br />';
+            echo '<a href="../src/webmail.php?right_frame=options.php" target="' . $frame_top . '">' . _("Refresh Page") . '</a><br>';
         }
     }
     /******************************************/
@@ -366,7 +321,7 @@ if ($optpage == SMOPT_PAGE_MAIN) {
     $optpage_blocks[] = array(
         'name' =>_("Message Highlighting"),
         'url'  => 'options_highlight.php',
-        'desc' =>_("Based upon given criteria, incoming messages can have different background colors in the message list. This helps to easily distinguish who the messages are from, especially for mailing lists."),
+        'desc' =>_("Based upon given criteria, incoming messages can have different background colors in the message list.  This helps to easily distinguish who the messages are from, especially for mailing lists."),
         'js'   => false
     );
 
@@ -435,7 +390,7 @@ if ($optpage == SMOPT_PAGE_MAIN) {
 /* If we are not looking at the main option page, display the page here. */
 /*************************************************************************/
 } else {
-    echo addForm('options.php', 'POST', 'f', '', '', '', TRUE)
+    echo '<form name="f" action="options.php" method="post"><br>' . "\n"
        . create_optpage_element($optpage)
        . create_optmode_element(SMOPT_MODE_SUBMIT)
        . html_tag( 'table', '', '', '', 'width="100%" cellpadding="2" cellspacing="0" border="0"' ) . "\n"
@@ -474,7 +429,7 @@ if ($optpage == SMOPT_PAGE_MAIN) {
             break;
         default:
             $inside_hook_name = '';
-            $bottom_hook_name = 'options_generic_bottom';
+            $bottom_hook_name = '';
             $submit_name = 'submit';
     }
 
@@ -492,9 +447,11 @@ if ($optpage == SMOPT_PAGE_MAIN) {
         do_hook($bottom_hook_name);    
     }
 }
+
+echo        '</td></tr>' .
+        '</table>'.
+        '</td></tr>'.
+     '</table>' .
+     '</body></html>';
+
 ?>
-</td></tr>
-</table>
-</td></tr>
-</table>
-</body></html>
