@@ -3,22 +3,16 @@
 /**
  * options_highlight.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Displays message highlighting options
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: options_highlight.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: options_highlight.php,v 1.53 2003/12/01 21:56:57 cigamit Exp $
  * @package squirrelmail
- * @subpackage prefs
  */
 
-/** This is the options_highlight page */
-define('PAGE_NAME', 'options_highlight');
-
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -28,27 +22,39 @@ require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'functions/plugin.php');
 require_once(SM_PATH . 'functions/strings.php');
 require_once(SM_PATH . 'functions/html.php');
-require_once(SM_PATH . 'functions/forms.php');
 
 /* get globals */
-sqGetGlobalVar('action', $action);
-sqGetGlobalVar('theid', $theid);
-sqGetGlobalVar('identname', $identname);
-sqGetGlobalVar('newcolor_choose', $newcolor_choose);
-sqGetGlobalVar('newcolor_input', $newcolor_input);
-sqGetGlobalVar('color_type', $color_type);
-sqGetGlobalVar('match_type', $match_type);
-sqGetGlobalVar('value', $value);
-
-if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_FORM)) {
-    $submitted_token = '';
+if (isset($_GET['action'])) {
+    $action = $_GET['action'];
 }
+if (isset($_GET['theid'])) {
+    $theid = $_GET['theid'];
+}
+if (isset($_GET['identname'])) {
+    $identname = $_GET['identname'];
+}
+if (isset($_GET['newcolor_choose'])) {
+    $newcolor_choose = $_GET['newcolor_choose'];
+}
+if (isset($_GET['newcolor_input'])) {
+    $newcolor_input = $_GET['newcolor_input'];
+}
+if (isset($_GET['color_type'])) {
+    $color_type = $_GET['color_type'];
+}
+if (isset($_GET['match_type'])) {
+    $match_type = $_GET['match_type'];
+}
+if (isset($_GET['value'])) {
+    $value = $_GET['value'];
+}
+
 /* end of get globals */
  
 function oh_opt( $val, $sel, $tit ) {
     echo "<option value=\"$val\"";
     if ( $sel )
-        echo ' selected="selected"';
+        echo ' selected';
     echo  ">$tit</option>\n";
 }
 
@@ -62,10 +68,6 @@ if (! isset($message_highlight_list)) {
 if (isset($theid) && ($action == 'delete') ||
                      ($action == 'up')     ||
                      ($action == 'down')) {
-
-    // security check
-    sm_validate_security_token($submitted_token, -1, TRUE);
-
     $new_rules = array();
     switch($action) {
         case('delete'):
@@ -92,17 +94,14 @@ if (isset($theid) && ($action == 'delete') ||
             $new_rules = $message_highlight_list;
             break;
     }
-    $message_highlight_list = $new_rules;
+    $message_highlight_list = $new_rules;    
 
     setPref($data_dir, $username, 'hililist', serialize($message_highlight_list));
 
-    header( 'Location: options_highlight.php' );
+    header( 'Location: ' .get_location(). '/options_highlight.php' );
     exit;
 } else if ($action == 'save') {
 
-    // security check
-    sm_validate_security_token($submitted_token, -1, TRUE);
-
     if ($color_type == 1) $newcolor = $newcolor_choose;
     elseif ($color_type == 2) $newcolor = $newcolor_input;
     else $newcolor = $color_type;
@@ -131,17 +130,16 @@ html_tag( 'table', "\n" .
     html_tag( 'tr', "\n" .
         html_tag( 'td', '<center><b>' . _("Options") . ' - ' . _("Message Highlighting") . '</b></center>', 'left')
     ),
-    'center', $color[9], 'width="95%" border="0" cellpadding="1" cellspacing="0"' ) . "<br />\n" .
+    'center', $color[9], 'width="95%" border="0" cellpadding="1" cellspacing="0"' ) . "<br>\n" .
 html_tag( 'table', '', '', '', 'width="100%" border="0" cellpadding="1" cellspacing="0"' ) . 
      html_tag( 'tr' ) . "\n" .
          html_tag( 'td', '', 'left' );
 
 echo '<center>[<a href="options_highlight.php?action=add">' . _("New") . '</a>]'.
-        ' - [<a href="options.php">'._("Done").'</a>]</center><br />'."\n";
+        ' - [<a href="options.php">'._("Done").'</a>]</center><br>'."\n";
 $mhl_count = count($message_highlight_list);
 if ($mhl_count > 0) {
     echo html_tag( 'table', '', 'center', '', 'width="80%" border="0" cellpadding="3" cellspacing="0"' ) . "\n";
-    $token = sm_generate_security_token();
     for ($i=0; $i < $mhl_count; $i++) {
         $match_type = '';
         switch ($message_highlight_list[$i]['match_type'] ) {
@@ -164,13 +162,13 @@ if ($mhl_count > 0) {
 
         $links = '<small>[<a href="options_highlight.php?action=edit&amp;theid=' . $i . '">' .
                  _("Edit") .
-                 '</a>]&nbsp;[<a href="options_highlight.php?action=delete&amp;smtoken=' . $token . '&amp;theid='.  $i . '">' .
+                 '</a>]&nbsp;[<a href="options_highlight.php?action=delete&amp;theid='.  $i . '">' .
                  _("Delete");
         if($i > 0) {
-            $links .= '</a>]&nbsp;[<a href="options_highlight.php?action=up&amp;smtoken=' . $token . '&amp;theid='.  $i . '">' .  _("Up");
+            $links .= '</a>]&nbsp;[<a href="options_highlight.php?action=up&amp;theid='.  $i . '">' .  _("Up");
         }
         if($i+1 < $mhl_count) {
-            $links .= '</a>]&nbsp;[<a href="options_highlight.php?action=down&amp;smtoken=' . $token . '&amp;theid='.  $i . '">' .  _("Down");
+            $links .= '</a>]&nbsp;[<a href="options_highlight.php?action=down&amp;theid='.  $i . '">' .  _("Down");
         }
         $links .= '</a>]</small>';
 
@@ -179,19 +177,19 @@ if ($mhl_count > 0) {
                         $links,
                     'left', $color[4], 'width="20%" nowrap' ) .
                     html_tag( 'td',
-                        sm_encode_html_special_chars($message_highlight_list[$i]['name']) ,
+                        htmlspecialchars($message_highlight_list[$i]['name']) ,
                     'left' ) .
                     html_tag( 'td',
                         $match_type . ' = ' .
-                        sm_encode_html_special_chars($message_highlight_list[$i]['value']) ,
+                        htmlspecialchars($message_highlight_list[$i]['value']) ,
                     'left' ) ,
-                '', '#' . $message_highlight_list[$i]['color'] ) . "\n";
+                '', $message_highlight_list[$i]['color'] ) . "\n";
     }
     echo "</table>\n".
-        "<br />\n";
+        "<br>\n";
 } else {
-    echo '<center>' . _("No highlighting is defined") . "</center><br />\n".
-        "<br />\n";
+    echo '<center>' . _("No highlighting is defined") . "</center><br>\n".
+        "<br>\n";
 }
 if ($action == 'edit' || $action == 'add') {
 
@@ -331,10 +329,8 @@ if ($action == 'edit' || $action == 'add') {
     $new_color_list["18,3"] = 'ff33ff';
     $new_color_list["18,4"] = 'ff00ff';
 
-    $selected_input = FALSE;
-    $selected_i = null;
-    $selected_choose = FALSE;
-    $selected_predefined = FALSE;
+    $selected_input = '';
+    $selected_choose = '';
 
     for ($i=0; $i < 14; $i++) {
         ${"selected".$i} = '';
@@ -342,8 +338,8 @@ if ($action == 'edit' || $action == 'add') {
     if ($action == 'edit' && isset($theid) && isset($message_highlight_list[$theid]['color'])) {
         for ($i=0; $i < 14; $i++) {
             if ($color_list[$i] == $message_highlight_list[$theid]['color']) {
-                $selected_choose = TRUE;
-                $selected_i = $color_list[$i];
+                $selected_choose = ' checked';
+                ${"selected".$i} = ' selected';
                 continue;
             }
         }
@@ -368,18 +364,17 @@ if ($action == 'edit' || $action == 'add') {
         }
     }
 
-    if (isset($theid) && !isset($message_highlight_list[$theid]['color']))
-        $selected_choose = TRUE;
+    if (!isset($message_highlight_list[$theid]['color']))
+        $selected_choose = ' checked';
     else if ($pre_defined_color)
-        $selected_predefined = TRUE;
+        $selected_predefined = ' checked';
     else if ($selected_choose == '')
-        $selected_input = TRUE;
+        $selected_input = ' checked';
 
-    echo addForm('options_highlight.php', 'POST', 'f', '', '', '', TRUE).
-         addHidden('action', 'save');
-    if($action == 'edit') {
-        echo addHidden('theid', (isset($theid)?$theid:''));
-    }
+    echo '<form name="f" action="options_highlight.php">' . "\n";
+    echo '<input type="hidden" value="save" name="action">' . "\n";
+    if($action == 'edit')
+        echo '<input type="hidden" value="'.(isset($theid)?$theid:'').'" name="theid">' . "\n";
     echo html_tag( 'table', '', 'center', '', 'width="80%" cellpadding="3" cellspacing="0" border="0"' ) . "\n";
     echo html_tag( 'tr', '', '', $color[0] ) . "\n";
     echo html_tag( 'td', '', 'right', '', 'nowrap' ) . "<b>\n";
@@ -390,56 +385,48 @@ if ($action == 'edit' || $action == 'add') {
         $disp = $message_highlight_list[$theid]['name'];
     else
         $disp = '';
-    echo "         ".addInput('identname', $disp);
+    $disp = htmlspecialchars($disp);
+    echo "         <input type=\"text\" value=\"".$disp."\" name=\"identname\">";
     echo "      </td>\n";
     echo "   </tr>\n";
     echo html_tag( 'tr', html_tag( 'td', '<small><small>&nbsp;</small></small>', 'left' ) ) ."\n";
     echo html_tag( 'tr', '', '', $color[0] ) . "\n";
     echo html_tag( 'td', '<b>'. _("Color") . ':</b>', 'right' );
     echo html_tag( 'td', '', 'left' );
-    echo '         '.addRadioBox('color_type', $selected_choose, '1');
-
-    $selops = array (
-        $color_list[0] => _("Dark Blue"),
-        $color_list[1] => _("Dark Green"),
-        $color_list[2] => _("Dark Yellow"),
-        $color_list[3] => _("Dark Cyan"),
-        $color_list[4] => _("Dark Magenta"),
-        $color_list[5] => _("Light Blue"),
-        $color_list[6] => _("Light Green"),
-        $color_list[7] => _("Light Yellow"),
-        $color_list[8] => _("Light Cyan"),
-        $color_list[9] => _("Light Magenta"),
-        $color_list[10] => _("Dark Gray"),
-        $color_list[11] => _("Medium Gray"),
-        $color_list[12] => _("Light Gray"),
-        $color_list[13] => _("White") );
-
-    echo addSelect('newcolor_choose', $selops, $selected_i, TRUE);
-    echo "<br />\n";
-
-    echo '         '.addRadioBox('color_type', $selected_input, 2).
-        ' &nbsp;'. _("Other:") .
-        addInput('newcolor_input',
-            (($selected_input && isset($theid)) ? $message_highlight_list[$theid]['color'] : ''),
-            '7');
-    // i18n: This is an example on how to write a color in RGB, literally meaning "For example: 63aa7f".
-    echo _("Ex: 63aa7f")."<br />\n";
+    echo "         <input type=\"radio\" name=color_type value=1$selected_choose> &nbsp;<select name=newcolor_choose>\n";
+    echo "            <option value=\"$color_list[0]\"$selected0>" . _("Dark Blue") . "\n";
+    echo "            <option value=\"$color_list[1]\"$selected1>" . _("Dark Green") . "\n";
+    echo "            <option value=\"$color_list[2]\"$selected2>" . _("Dark Yellow") . "\n";
+    echo "            <option value=\"$color_list[3]\"$selected3>" . _("Dark Cyan") . "\n";
+    echo "            <option value=\"$color_list[4]\"$selected4>" . _("Dark Magenta") . "\n";
+    echo "            <option value=\"$color_list[5]\"$selected5>" . _("Light Blue") . "\n";
+    echo "            <option value=\"$color_list[6]\"$selected6>" . _("Light Green") . "\n";
+    echo "            <option value=\"$color_list[7]\"$selected7>" . _("Light Yellow") . "\n";
+    echo "            <option value=\"$color_list[8]\"$selected8>" . _("Light Cyan") . "\n";
+    echo "            <option value=\"$color_list[9]\"$selected9>" . _("Light Magenta") . "\n";
+    echo "            <option value=\"$color_list[10]\"$selected10>" . _("Dark Gray") . "\n";
+    echo "            <option value=\"$color_list[11]\"$selected11>" . _("Medium Gray") . "\n";
+    echo "            <option value=\"$color_list[12]\"$selected12>" . _("Light Gray") . "\n";
+    echo "            <option value=\"$color_list[13]\"$selected13>" . _("White") . "\n";
+    echo "         </select><br>\n";
+    echo "         <input type=\"radio\" name=color_type value=2$selected_input> &nbsp;". _("Other:") ."<input type=\"text\" value=\"";
+    if ($selected_input && isset($theid)) echo $message_highlight_list[$theid]["color"];
+    echo '" name="newcolor_input" size="7"> '._("Ex: 63aa7f")."<br>\n";
     echo "      </td>\n";
     echo "   </tr>\n";
 
     # Show grid of color choices
     echo html_tag( 'tr', '', '', $color[0] ) . "\n";
     echo html_tag( 'td', '', 'left', '', 'colspan="2"' );
-    echo html_tag( 'table', '', 'center', '', 'border="0" cellpadding="2" cellspacing="1"' ) . "\n";
+    echo html_tag( 'table', '', 'center', '', 'border=0 cellpadding="2" cellspacing="1"' ) . "\n";
 
     for($x = 0; $x < 5; $x++) {
         echo html_tag( 'tr' ) . "\n";
         for($y = 0; $y < 19; $y++) {
         $gridindex = "$y,$x";
         $gridcolor = $new_color_list[$gridindex];
-        echo html_tag( 'td', addRadioBox('color_type', ($gridcolor == $current_color), '#'.$gridcolor),
-            'left', '#' . $gridcolor, 'colspan="2"' );
+        $selected = ($gridcolor == $current_color) ? ' checked' : '' ;
+        echo html_tag( 'td', '<input type="radio" name="color_type" value="#' . $gridcolor .'"' . $selected . '>', 'left', $gridcolor, 'colspan="2"' );
         }
         echo "</tr>\n";
     }
@@ -449,7 +436,7 @@ if ($action == 'edit' || $action == 'add') {
     echo html_tag( 'tr', html_tag( 'td', '<small><small>&nbsp;</small></small>', 'left' ) ) . "\n";
     echo html_tag( 'tr', '', '', $color[0] ) . "\n";
     echo html_tag( 'td', '', 'center', '', 'colspan="2"' ) . "\n";
-    echo "         <select name=\"match_type\">\n";
+    echo "         <select name=match_type>\n";
     oh_opt( 'from',
             (isset($theid)?$message_highlight_list[$theid]['match_type'] == 'from':1),
             _("From") );
@@ -471,11 +458,13 @@ if ($action == 'edit' || $action == 'add') {
         $disp = $message_highlight_list[$theid]['value'];
     else
         $disp = '';
-    echo '         '.addInput('value', $disp, 40);
+    $disp = htmlspecialchars($disp);
+    echo '         <input type="text" value="' . $disp .
+        '" name="value" size=40>';
     echo "        </td>\n";
     echo "   </tr>\n";
     echo "</table>\n";
-    echo '<center><input type="submit" value="' . _("Submit") . "\" /></center>\n";
+    echo '<center><input type="submit" value="' . _("Submit") . "\"></center>\n";
     echo "</form>\n";
 }
 do_hook('options_highlight_bottom');
