@@ -3,22 +3,16 @@
 /**
  * options_order.php
  *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
  * Displays messagelist column order options
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: options_order.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: options_order.php,v 1.31 2003/12/01 21:56:58 cigamit Exp $
  * @package squirrelmail
- * @subpackage prefs
  */
 
-/** This is the options_order page */
-define('PAGE_NAME', 'options_order');
-
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -28,21 +22,13 @@ require_once(SM_PATH . 'functions/display_messages.php');
 require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'functions/plugin.php');
 require_once(SM_PATH . 'functions/html.php');
-require_once(SM_PATH . 'functions/forms.php');
 
 /* get globals */
-if (sqgetGlobalVar('num', $num, SQ_GET))  
-   $num = (int)$num;
-else
-   $num = 0;
-
+sqgetGlobalVar('num',       $num,       SQ_GET);  
 sqgetGlobalVar('add',       $add,       SQ_POST);
 
 sqgetGlobalVar('submit',    $submit);
 sqgetGlobalVar('method',    $method);
-if (!sqgetGlobalVar('smtoken',$submitted_token, SQ_FORM)) {
-    $submitted_token = '';
-}
 /* end of get globals */
 
 displayPageHeader($color, 'None');
@@ -65,21 +51,17 @@ displayPageHeader($color, 'None');
     
     if (! isset($method)) { $method = ''; }
  
-    if ($method == 'up' && $num > 0 && $num > 1) {
+    if ($method == 'up' && $num > 1) {
         $prev = $num-1;
         $tmp = $index_order[$prev];
         $index_order[$prev] = $index_order[$num];
         $index_order[$num] = $tmp;
-    } else if ($method == 'down' && $num > 0 && $num < count($index_order)) {
+    } else if ($method == 'down' && $num < count($index_order)) {
         $next = $num++;
         $tmp = $index_order[$next];
         $index_order[$next] = $index_order[$num];
         $index_order[$num] = $tmp;
-    } else if ($method == 'remove' && $num > 0) {
-
-        // first do a security check
-        sm_validate_security_token($submitted_token, -1, TRUE);
-
+    } else if ($method == 'remove' && $num) {
         for ($i=1; $i < 8; $i++) {
             removePref($data_dir, $username, "order$i"); 
         }
@@ -92,16 +74,12 @@ displayPageHeader($color, 'None');
         $index_order = array();
         $index_order = $new_ary;
         if (count($index_order) < 1) {
-           include_once(SM_PATH . 'include/load_prefs.php');
+           include_once('../src/load_prefs.php');
         }
     } else if ($method == 'add' && $add) {
-
-        // first do a security check
-        sm_validate_security_token($submitted_token, -1, TRUE);
-
         /* User should not be able to insert PHP-code here */
         $add = str_replace ('<?', '..', $add);
-        $add = preg_replace ('/<.*script.*language.*php.*>/', '..', $add);
+        $add = ereg_replace ('<.*script.*language.*php.*>', '..', $add);
         $add = str_replace ('<%', '..', $add);
         $index_order[count($index_order)+1] = $add;
     }
@@ -114,10 +92,10 @@ displayPageHeader($color, 'None');
     echo html_tag( 'table',
                 html_tag( 'tr',
                     html_tag( 'td',
-                        _("The index order is the order that the columns are arranged in the message index. You can add, remove, and move columns around to customize them to fit your needs.")
+                        _("The index order is the order that the columns are arranged in the message index.  You can add, remove, and move columns around to customize them to fit your needs.")
                     )
                 ) ,
-            '', '', '', 'width="65%" border="0" cellpadding="0" cellspacing="0"' ) . "<br />\n";
+            '', '', '', 'width="65%" border="0" cellpadding="0" cellspacing="0"' ) . "<br>\n";
  
     if (count($index_order))
     {
@@ -132,7 +110,7 @@ displayPageHeader($color, 'None');
             echo html_tag( 'td' );
             /* Always show the subject */
             if ($tmp != 4)
-               echo '<small><a href="options_order.php?method=remove&amp;num=' . $i . '&smtoken=' . sm_generate_security_token() . '">' . _("remove") . '</a></small>';
+               echo '<small><a href="options_order.php?method=remove&amp;num=' . $i . '">' . _("remove") . '</a></small>';
             else
                echo '&nbsp;'; 
             echo '</td>';
@@ -144,9 +122,8 @@ displayPageHeader($color, 'None');
     }
     
     if (count($index_order) != count($available)) {
-        echo '<form name="f" method="post" action="options_order.php">' . "\n"
-           . addHidden('smtoken', sm_generate_security_token())
-           . '<select name="add">' . "\n";
+        echo '<form name="f" method="post" action="options_order.php">';
+        echo '<select name="add">';
         for ($i=1; $i <= count($available); $i++) {
             $found = false;
             for ($j=1; $j <= count($index_order); $j++) {
@@ -159,12 +136,12 @@ displayPageHeader($color, 'None');
             }
         }
         echo '</select>';
-        echo '<input type="hidden" value="add" name="method" />';
-        echo '<input type="submit" value="'._("Add").'" name="submit" />';
+        echo '<input type="hidden" value="add" name="method">';
+        echo '<input type="submit" value="'._("Add").'" name="submit">';
         echo '</form>';
     }
  
-    echo html_tag( 'p', '<a href="../src/options.php">' . _("Return to options page") . '</a></p><br />' );
+    echo html_tag( 'p', '<a href="../src/options.php">' . _("Return to options page") . '</a></p><br>' );
 
 ?>
     </td></tr>
