@@ -1,28 +1,28 @@
 <?php
 
 /**
- * printer_friendly top frame
+ * printer_friendly_top.php
+ *
+ * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * top frame of printer_friendly_main.php
  * displays some javascript buttons for printing & closing
  *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: printer_friendly_top.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * $Id: printer_friendly_top.php,v 1.15 2003/10/29 15:25:11 tassium Exp $
  * @package squirrelmail
  */
 
-/** This is the printer_friendly_top page */
-define('PAGE_NAME', 'printer_friendly_top');
-
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
 require_once(SM_PATH . 'include/validate.php');
+require_once(SM_PATH . 'functions/strings.php');
+require_once(SM_PATH . 'config/config.php');
+require_once(SM_PATH . 'include/load_prefs.php');
+require_once(SM_PATH . 'functions/page_header.php');
+require_once(SM_PATH . 'functions/html.php');
 
 displayHtmlHeader( _("Printer Friendly"),
              "<script language=\"javascript\" type=\"text/javascript\">\n".
@@ -35,7 +35,7 @@ displayHtmlHeader( _("Printer Friendly"),
              "</script>\n", FALSE );
 
 
-echo '<body text="'.$color[8].'" bgcolor="'.$color[3].'" link="'.$color[7].'" vlink="'.$color[7].'" alink="'.$color[7]."\">\n" .
+echo "<body text='$color[8]' bgcolor='$color[3]' link='$color[7]' vlink='$color[7]' alink='$color[7]'>\n" .
      html_tag( 'div',
          '<b>'.
          '<form>'.
@@ -44,5 +44,6 @@ echo '<body text="'.$color[8].'" bgcolor="'.$color[3].'" link="'.$color[7].'" vl
          '</form>'.
          '</b>',
      'right' );
+     '</body></html>'. "\n";
+
 ?>
-</body></html>
\ No newline at end of file
