@@ -1,42 +1,43 @@
 <?php
 
 /**
- * Prevents users from reposting their form data after a successful logout.
- *
- * Derived from webmail.php by Ralf Kraudelt <kraude@wiwi.uni-rostock.de>
- *
- * @copyright 1999-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: redirect.php 14800 2019-01-08 04:27:15Z pdontthink $
- * @package squirrelmail
- */
+* redirect.php
+* Derived from webmail.php by Ralf Kraudelt <kraude@wiwi.uni-rostock.de>
+*
+* Copyright (c) 1999-2003 The SquirrelMail Project Team
+* Licensed under the GNU GPL. For full terms see the file COPYING.
+*
+* Prevents users from reposting their form data after a successful logout.
+*
+* $Id: redirect.php,v 1.79 2003/12/01 21:56:58 cigamit Exp $
+* @package squirrelmail
+*/
 
-/** This is the redirect page */
-define('PAGE_NAME', 'redirect');
-
-/**
- * Path for SquirrelMail required files.
- * @ignore
- */
+/** Path for SquirrelMail required files. */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
 require_once(SM_PATH . 'functions/global.php');
 require_once(SM_PATH . 'functions/i18n.php');
 require_once(SM_PATH . 'functions/strings.php');
+require_once(SM_PATH . 'config/config.php');
 require_once(SM_PATH . 'functions/prefs.php');
 require_once(SM_PATH . 'functions/imap.php');
 require_once(SM_PATH . 'functions/plugin.php');
 require_once(SM_PATH . 'functions/constants.php');
 require_once(SM_PATH . 'functions/page_header.php');
 
-// Disable Browser Caching
-//
-header('Cache-Control: no-cache, no-store, must-revalidate');
+/* Before starting the session, the base URI must be known. Assuming */
+/* that this file is in the src/ subdirectory (or something).        */
+if (!function_exists('sqm_baseuri')){
+    require_once(SM_PATH . 'functions/display_messages.php');
+}
+$base_uri = sqm_baseuri();
+
 header('Pragma: no-cache');
-header('Expires: Sat, 1 Jan 2000 00:00:00 GMT');
 $location = get_location();
 
+session_set_cookie_params (0, $base_uri);
 sqsession_is_active();
 
 sqsession_unregister ('user_is_logged_in');
@@ -47,49 +48,28 @@ sqGetGlobalVar('login_username', $login_username);
 sqGetGlobalVar('secretkey', $secretkey);
 sqGetGlobalVar('js_autodetect_results', $js_autodetect_results);
 if(!sqGetGlobalVar('squirrelmail_language', $squirrelmail_language) || $squirrelmail_language == '') {
-    $squirrelmail_language = $squirrelmail_default_language;
+	$squirrelmail_language = $squirrelmail_default_language;
 }
-
-if (!sqgetGlobalVar('mailtodata', $mailtodata)) {
-    $mailtodata = '';
+if (!sqgetGlobalVar('mailto', $mailto)) {
+    $mailto = '';
 }
 
-
 /* end of get globals */
 
 set_up_language($squirrelmail_language, true);
 /* Refresh the language cookie. */
-sqsetcookie('squirrelmail_language', $squirrelmail_language, time()+2592000, $base_uri);
+setcookie('squirrelmail_language', $squirrelmail_language, time()+2592000, 
+          $base_uri);
 
 if (!isset($login_username)) {
     include_once(SM_PATH .  'functions/display_messages.php' );
-    logout_error( _("You must be logged in to access this page.") );
+    logout_error( _("You must be logged in to access this page.") );    
     exit;
 }
 
 if (!sqsession_is_registered('user_is_logged_in')) {
     do_hook ('login_before');
 
-    /**
-     * Regenerate session id to make sure that authenticated session uses
-     * different ID than one used before user authenticated.  This is a
-     * countermeasure against session fixation attacks.
-     * NB: session_regenerate_id() was added in PHP 4.3.2 (and new session
-     *     cookie is only sent out in this call as of PHP 4.3.3), but PHP 4
-     *     is not vulnerable to session fixation problems in SquirrelMail
-     *     because it prioritizes $base_uri subdirectory cookies differently
-     *     than PHP 5, which is otherwise vulnerable.  If we really want to,
-     *     we could define our own session_regenerate_id() when one does not
-     *     exist, but there seems to be no reason to do so.
-     */
-    if (function_exists('session_regenerate_id')) {
-        session_regenerate_id();
-
-        // re-send session cookie so we get the right parameters on it
-        // (such as HTTPOnly, if necessary - PHP doesn't do this itself
-        sqsetcookie(session_name(),session_id(),false,$base_uri);
-    }
-
     $onetimepad = OneTimePadCreate(strlen($secretkey));
     $key = OneTimePadEncrypt($secretkey, $onetimepad);
     sqsession_register($onetimepad, 'onetimepad');
@@ -102,8 +82,7 @@ if (!sqsession_is_registered('user_is_logged_in')) {
         $login_username = strtolower($login_username);
     }
 
-    global $imap_stream_options; // in case not defined in config
-    $imapConnection = sqimap_login($login_username, $key, $imapServerAddress, $imapPort, 0, $imap_stream_options);
+    $imapConnection = sqimap_login($login_username, $key, $imapServerAddress, $imapPort, 0);
 
     $sqimap_capabilities = sqimap_capability($imapConnection);
     sqsession_register($sqimap_capabilities, 'sqimap_capabilities');
@@ -114,11 +93,8 @@ if (!sqsession_is_registered('user_is_logged_in')) {
 
     $username = $login_username;
     sqsession_register ($username, 'username');
-    sqsetcookie('key', $key, 0, $base_uri);
-
-    $is_login_verified_hook = TRUE;
+    setcookie('key', $key, 0, $base_uri);
     do_hook ('login_verified');
-    $is_login_verified_hook = FALSE;
 
 }
 
@@ -136,10 +112,11 @@ $attachment_common_types_parsed = array();
 sqsession_register($attachment_common_types, 'attachment_common_types');
 sqsession_register($attachment_common_types_parsed, 'attachment_common_types_parsed');
 
+$debug = false;
 
 if ( sqgetGlobalVar('HTTP_ACCEPT', $http_accept, SQ_SERVER) &&
     !isset($attachment_common_types_parsed[$http_accept]) ) {
-    attachment_common_parse($http_accept);
+    attachment_common_parse($http_accept, $debug);
 }
 
 /* Complete autodetection of Javascript. */
@@ -162,50 +139,42 @@ if ($javascript_setting != SMPREF_JS_ON){
 setPref($data_dir, $username, 'javascript_on', $js_pref);
 
 /* Compute the URL to forward the user to. */
-$redirect_url = 'webmail.php';
+$redirect_url = $location . '/webmail.php';
 
 if ( sqgetGlobalVar('session_expired_location', $session_expired_location, SQ_SESSION) ) {
     sqsession_unregister('session_expired_location');
-    if ( $session_expired_location == 'compose' ) {
-        $compose_new_win = getPref($data_dir, $username, 'compose_new_win', 0);
-        if ($compose_new_win) {
-            // do not prefix $location here because $session_expired_location is set to the PAGE_NAME
-            // of the last page
-            $redirect_url = $session_expired_location . '.php';
-        } else {
-            $redirect_url = 'webmail.php?right_frame=' . urlencode($session_expired_location . '.php');
-        }
-    } else if ($session_expired_location != 'webmail'
-            && $session_expired_location != 'left_main') {
-        $redirect_url = 'webmail.php?right_frame=' . urlencode($session_expired_location . '.php');
+    $compose_new_win = getPref($data_dir, $username, 'compose_new_win', 0);
+    if ($compose_new_win) {
+        // do not prefix $location here because $session_expired_location is set to PHP_SELF
+        // of the last page
+        $redirect_url = $session_expired_location;
+    } elseif ( strpos($session_expired_location, 'webmail.php') === FALSE ) {
+        $redirect_url = $location.'/webmail.php?right_frame='.urldecode($session_expired_location);
     }
     unset($session_expired_location);
 }
-
-if($mailtodata != '') {
-    $redirect_url  = $location . '/webmail.php?right_frame=compose.php&mailtodata=';
-    $redirect_url .= urlencode($mailtodata);
+if($mailto != '') {
+    $redirect_url  = $location . '/webmail.php?right_frame=compose.php&mailto=';
+    $redirect_url .= $mailto;
 }
 
-
-
 /* Write session data and send them off to the appropriate page. */
 session_write_close();
 header("Location: $redirect_url");
 
 /* --------------------- end main ----------------------- */
 
-function attachment_common_parse($str) {
+function attachment_common_parse($str, $debug) {
     global $attachment_common_types, $attachment_common_types_parsed;
 
     $attachment_common_types_parsed[$str] = true;
-
-    /*
-     * Replace ", " with "," and explode on that as Mozilla 1.x seems to
+    
+    /* 
+     * Replace ", " with "," and explode on that as Mozilla 1.x seems to  
      * use "," to seperate whilst IE, and earlier versions of Mozilla use
      * ", " to seperate
      */
-
+    
     $str = str_replace( ', ' , ',' , $str );
     $types = explode(',', $str);
 
@@ -218,6 +187,8 @@ function attachment_common_parse($str) {
             $attachment_common_types[$val] = true;
         }
     }
-    sqsession_register($attachment_common_types, 'attachment_common_types');
+    $_SESSION['attachment_common_types'] = $attachment_common_types;
 }
 
+
+?>
