@@ -3,13 +3,14 @@
 /**
  * dompie_theme.php
  * Name:    Dompie
+ * @author M.J. Prinsen
  * Date:    November 19, 2001
  * Comment: Has a dark blue left-bar and a white/grey right frame.
  *
- * @author M.J. Prinsen
- * @copyright 2001-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: dompie_theme.php 14800 2019-01-08 04:27:15Z pdontthink $
+ * Copyright (c) 2001-2003 The SquirrelMail Project Team
+ * Licensed under the GNU GPL. For full terms see the file COPYING.
+ *
+ * $Id: dompie_theme.php,v 1.5 2003/10/28 20:58:30 tassium Exp $
  * @package squirrelmail
  * @subpackage themes
  */
@@ -17,15 +18,17 @@
 global $color;
 $color[0]   = '#999999'; // (middle grey)    TitleBar
 $color[1]   = '#800000'; // (red)
-$color[2]   = '#cc0000'; // (light red)      Warning/Error Messages
+$color[2]   = '#CC0000'; // (light red)      Warning/Error Messages
 $color[3]   = '#294763'; // (dark blue)      Left Bar Background
-$color[4]   = '#ffffff'; // (white)          Normal Background
+$color[4]   = '#FFFFFF'; // (white)          Normal Background
 $color[5]   = '#c0c0c0'; // (light grey)     Table Headers
-$color[6]   = '#ffffff'; // (white)          Text on left bar
+$color[6]   = '#FFFFFF'; // (white)          Text on left bar
 $color[7]   = '#000000'; // (black)          Links
 $color[8]   = '#000000'; // (black)          Normal text
 $color[9]   = '#c0c0c0'; // (light grey)     Darker version of #0
 $color[10]  = '#c0c0c0'; // (light grey)     Darker version of #9
-$color[11]  = '#a7c5f3'; // (light blue)     Special Folders color
+$color[11]  = '#A7C5F3'; // (light blue)     Special Folders color
 $color[12]  = '#c0c0c0'; //
-$color[15]  = '#788dd0'; // (darkish blue)   Unselectable folders
+$color[15]  = '#788DD0'; // (darkish blue)   Unselectable folders
+
+?>
