@@ -1,35 +1,31 @@
 <?php
-
 /**
+ * @author Tomas Kuliavas
  * Date:         July 26, 2003
  * Theme Name:   'Minimal BW Theme'
- *
+ *    
  * This theme uses black color for text and white for background.
- *
+ * 
  * Problem: $color[9] is used for background and for disabled links.
- *
- * @author Tomas Kuliavas
- * @copyright 2003-2019 The SquirrelMail Project Team
- * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: minimal_bw.php 14800 2019-01-08 04:27:15Z pdontthink $
  * @package squirrelmail
  * @subpackage themes
  */
 
     global $color;
-    $color[0]   = '#ffffff'; // (white)   TitleBar
+    $color[0]   = '#FFFFFF'; // (white)   TitleBar
     $color[1]   = '#000000'; // (black)   (unused)
     $color[2]   = '#000000'; // (black)   Warning/Error Messages
-    $color[3]   = '#ffffff'; // (white)   Left Bar Background
-    $color[4]   = '#ffffff'; // (white)   Normal Background
-    $color[5]   = '#ffffff'; // (white)   Table Headers
+    $color[3]   = '#FFFFFF'; // (white)   Left Bar Background
+    $color[4]   = '#FFFFFF'; // (white)   Normal Background
+    $color[5]   = '#FFFFFF'; // (white)   Table Headers
     $color[6]   = '#000000'; // (black)   Text on left bar
     $color[7]   = '#000000'; // (black)   Links
     $color[8]   = '#000000'; // (black)   Normal text
-    $color[9]   = '#ffffff'; // (white)   Darker version of #0
-    $color[10]  = '#ffffff'; // (white)   Darker version of #9
+    $color[9]   = '#FFFFFF'; // (white)   Darker version of #0
+    $color[10]  = '#FFFFFF'; // (white)   Darker version of #9
     $color[11]  = '#000000'; // (black)   Special Folders color
-    $color[12]  = '#ffffff'; // (white)   Alternate color for message list
+    $color[12]  = '#FFFFFF'; // (white)   Alternate color for message list
     $color[13]  = '#000000'; // (black)   Color for quoted text -- > 1 quote
     $color[14]  = '#000000'; // (black)   Color for quoted text -- >> 2 or more
     $color[15]  = '#000000'; // (black)   Unselectable folders
+?>
